<?php

return [
    '🧑🏻‍❤‍💋‍🧑🏼' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '🧑🏻‍❤‍💋‍🧑🏽' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '🧑🏻‍❤‍💋‍🧑🏾' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '🧑🏻‍❤‍💋‍🧑🏿' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '🧑🏼‍❤‍💋‍🧑🏻' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '🧑🏼‍❤‍💋‍🧑🏽' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '🧑🏼‍❤‍💋‍🧑🏾' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '🧑🏼‍❤‍💋‍🧑🏿' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '🧑🏽‍❤‍💋‍🧑🏻' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '🧑🏽‍❤‍💋‍🧑🏼' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '🧑🏽‍❤‍💋‍🧑🏾' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '🧑🏽‍❤‍💋‍🧑🏿' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '🧑🏾‍❤‍💋‍🧑🏻' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '🧑🏾‍❤‍💋‍🧑🏼' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '🧑🏾‍❤‍💋‍🧑🏽' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '🧑🏾‍❤‍💋‍🧑🏿' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '🧑🏿‍❤‍💋‍🧑🏻' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '🧑🏿‍❤‍💋‍🧑🏼' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '🧑🏿‍❤‍💋‍🧑🏽' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '🧑🏿‍❤‍💋‍🧑🏾' => 'gusomana: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏻‍❤‍💋‍👨🏻' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rwera',
    '👨🏻‍❤‍💋‍👨🏼' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '👨🏻‍❤‍💋‍👨🏽' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '👨🏻‍❤‍💋‍👨🏾' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏻‍❤‍💋‍👨🏿' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '👨🏼‍❤‍💋‍👨🏻' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '👨🏼‍❤‍💋‍👨🏼' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rwera gahoro',
    '👨🏼‍❤‍💋‍👨🏽' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '👨🏼‍❤‍💋‍👨🏾' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏼‍❤‍💋‍👨🏿' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '👨🏽‍❤‍💋‍👨🏻' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '👨🏽‍❤‍💋‍👨🏼' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '👨🏽‍❤‍💋‍👨🏽' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rw’inzobe',
    '👨🏽‍❤‍💋‍👨🏾' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏽‍❤‍💋‍👨🏿' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '👨🏾‍❤‍💋‍👨🏻' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '👨🏾‍❤‍💋‍👨🏼' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '👨🏾‍❤‍💋‍👨🏽' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '👨🏾‍❤‍💋‍👨🏾' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏾‍❤‍💋‍👨🏿' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '👨🏿‍❤‍💋‍👨🏻' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '👨🏿‍❤‍💋‍👨🏼' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '👨🏿‍❤‍💋‍👨🏽' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '👨🏿‍❤‍💋‍👨🏾' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍❤‍💋‍👨🏿' => 'gusomana: umugabo, umugabo, ibara ry’uruhu rwirabura',
    '👩🏻‍❤‍💋‍👨🏻' => 'gusomana: umugore, umugabo, ibara ry’uruhu rwera',
    '👩🏻‍❤‍💋‍👨🏼' => 'gusomana: umugore, umugabo, ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '👩🏻‍❤‍💋‍👨🏽' => 'gusomana: umugore, umugabo, ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '👩🏻‍❤‍💋‍👨🏾' => 'gusomana: umugore, umugabo, ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏻‍❤‍💋‍👨🏿' => 'gusomana: umugore, umugabo, ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '👩🏼‍❤‍💋‍👨🏻' => 'gusomana: umugore, umugabo, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '👩🏼‍❤‍💋‍👨🏼' => 'gusomana: umugore, umugabo, ibara ry’uruhu rwera gahoro',
    '👩🏼‍❤‍💋‍👨🏽' => 'gusomana: umugore, umugabo, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '👩🏼‍❤‍💋‍👨🏾' => 'gusomana: umugore, umugabo, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏼‍❤‍💋‍👨🏿' => 'gusomana: umugore, umugabo, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '👩🏽‍❤‍💋‍👨🏻' => 'gusomana: umugore, umugabo, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '👩🏽‍❤‍💋‍👨🏼' => 'gusomana: umugore, umugabo, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '👩🏽‍❤‍💋‍👨🏽' => 'gusomana: umugore, umugabo, ibara ry’uruhu rw’inzobe',
    '👩🏽‍❤‍💋‍👨🏾' => 'gusomana: umugore, umugabo, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏽‍❤‍💋‍👨🏿' => 'gusomana: umugore, umugabo, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '👩🏾‍❤‍💋‍👨🏻' => 'gusomana: umugore, umugabo, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '👩🏾‍❤‍💋‍👨🏼' => 'gusomana: umugore, umugabo, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '👩🏾‍❤‍💋‍👨🏽' => 'gusomana: umugore, umugabo, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '👩🏾‍❤‍💋‍👨🏾' => 'gusomana: umugore, umugabo, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏾‍❤‍💋‍👨🏿' => 'gusomana: umugore, umugabo, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '👩🏿‍❤‍💋‍👨🏻' => 'gusomana: umugore, umugabo, ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '👩🏿‍❤‍💋‍👨🏼' => 'gusomana: umugore, umugabo, ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '👩🏿‍❤‍💋‍👨🏽' => 'gusomana: umugore, umugabo, ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '👩🏿‍❤‍💋‍👨🏾' => 'gusomana: umugore, umugabo, ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍❤‍💋‍👨🏿' => 'gusomana: umugore, umugabo, ibara ry’uruhu rwirabura',
    '👩🏻‍❤‍💋‍👩🏻' => 'gusomana: umugore, umugore, ibara ry’uruhu rwera',
    '👩🏻‍❤‍💋‍👩🏼' => 'gusomana: umugore, umugore, ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '👩🏻‍❤‍💋‍👩🏽' => 'gusomana: umugore, umugore, ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '👩🏻‍❤‍💋‍👩🏾' => 'gusomana: umugore, umugore, ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏻‍❤‍💋‍👩🏿' => 'gusomana: umugore, umugore, ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '👩🏼‍❤‍💋‍👩🏻' => 'gusomana: umugore, umugore, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '👩🏼‍❤‍💋‍👩🏼' => 'gusomana: umugore, umugore, ibara ry’uruhu rwera gahoro',
    '👩🏼‍❤‍💋‍👩🏽' => 'gusomana: umugore, umugore, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '👩🏼‍❤‍💋‍👩🏾' => 'gusomana: umugore, umugore, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏼‍❤‍💋‍👩🏿' => 'gusomana: umugore, umugore, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '👩🏽‍❤‍💋‍👩🏻' => 'gusomana: umugore, umugore, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '👩🏽‍❤‍💋‍👩🏼' => 'gusomana: umugore, umugore, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '👩🏽‍❤‍💋‍👩🏽' => 'gusomana: umugore, umugore, ibara ry’uruhu rw’inzobe',
    '👩🏽‍❤‍💋‍👩🏾' => 'gusomana: umugore, umugore, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏽‍❤‍💋‍👩🏿' => 'gusomana: umugore, umugore, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '👩🏾‍❤‍💋‍👩🏻' => 'gusomana: umugore, umugore, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '👩🏾‍❤‍💋‍👩🏼' => 'gusomana: umugore, umugore, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '👩🏾‍❤‍💋‍👩🏽' => 'gusomana: umugore, umugore, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '👩🏾‍❤‍💋‍👩🏾' => 'gusomana: umugore, umugore, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏾‍❤‍💋‍👩🏿' => 'gusomana: umugore, umugore, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '👩🏿‍❤‍💋‍👩🏻' => 'gusomana: umugore, umugore, ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '👩🏿‍❤‍💋‍👩🏼' => 'gusomana: umugore, umugore, ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '👩🏿‍❤‍💋‍👩🏽' => 'gusomana: umugore, umugore, ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '👩🏿‍❤‍💋‍👩🏾' => 'gusomana: umugore, umugore, ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍❤‍💋‍👩🏿' => 'gusomana: umugore, umugore, ibara ry’uruhu rwirabura',
    '🧑🏻‍🫯‍🧑🏼' => 'umuntu uri gukirana: ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '🧑🏻‍🫯‍🧑🏽' => 'umuntu uri gukirana: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '🧑🏻‍🫯‍🧑🏾' => 'umuntu uri gukirana: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '🧑🏻‍🫯‍🧑🏿' => 'umuntu uri gukirana: ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '🧑🏼‍🫯‍🧑🏻' => 'umuntu uri gukirana: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '🧑🏼‍🫯‍🧑🏽' => 'umuntu uri gukirana: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '🧑🏼‍🫯‍🧑🏾' => 'umuntu uri gukirana: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '🧑🏼‍🫯‍🧑🏿' => 'umuntu uri gukirana: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '🧑🏽‍🫯‍🧑🏻' => 'umuntu uri gukirana: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '🧑🏽‍🫯‍🧑🏼' => 'umuntu uri gukirana: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '🧑🏽‍🫯‍🧑🏾' => 'umuntu uri gukirana: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '🧑🏽‍🫯‍🧑🏿' => 'umuntu uri gukirana: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '🧑🏾‍🫯‍🧑🏻' => 'umuntu uri gukirana: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '🧑🏾‍🫯‍🧑🏼' => 'umuntu uri gukirana: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '🧑🏾‍🫯‍🧑🏽' => 'umuntu uri gukirana: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '🧑🏾‍🫯‍🧑🏿' => 'umuntu uri gukirana: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '🧑🏿‍🫯‍🧑🏻' => 'umuntu uri gukirana: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '🧑🏿‍🫯‍🧑🏼' => 'umuntu uri gukirana: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '🧑🏿‍🫯‍🧑🏽' => 'umuntu uri gukirana: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '🧑🏿‍🫯‍🧑🏾' => 'umuntu uri gukirana: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '🧑🏻‍❤‍🧑🏼' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '🧑🏻‍❤‍🧑🏽' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '🧑🏻‍❤‍🧑🏾' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '🧑🏻‍❤‍🧑🏿' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '🧑🏼‍❤‍🧑🏻' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '🧑🏼‍❤‍🧑🏽' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '🧑🏼‍❤‍🧑🏾' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '🧑🏼‍❤‍🧑🏿' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '🧑🏽‍❤‍🧑🏻' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '🧑🏽‍❤‍🧑🏼' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '🧑🏽‍❤‍🧑🏾' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '🧑🏽‍❤‍🧑🏿' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '🧑🏾‍❤‍🧑🏻' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '🧑🏾‍❤‍🧑🏼' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '🧑🏾‍❤‍🧑🏽' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '🧑🏾‍❤‍🧑🏿' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '🧑🏿‍❤‍🧑🏻' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '🧑🏿‍❤‍🧑🏼' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '🧑🏿‍❤‍🧑🏽' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '🧑🏿‍❤‍🧑🏾' => 'ikupule n’umutima: umuntu mukuru, umuntu mukuru, ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '🧑🏻‍🐰‍🧑🏼' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '🧑🏻‍🐰‍🧑🏽' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '🧑🏻‍🐰‍🧑🏾' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '🧑🏻‍🐰‍🧑🏿' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '🧑🏼‍🐰‍🧑🏻' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '🧑🏼‍🐰‍🧑🏽' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '🧑🏼‍🐰‍🧑🏾' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '🧑🏼‍🐰‍🧑🏿' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '🧑🏽‍🐰‍🧑🏻' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '🧑🏽‍🐰‍🧑🏼' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '🧑🏽‍🐰‍🧑🏾' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '🧑🏽‍🐰‍🧑🏿' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '🧑🏾‍🐰‍🧑🏻' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '🧑🏾‍🐰‍🧑🏼' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '🧑🏾‍🐰‍🧑🏽' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '🧑🏾‍🐰‍🧑🏿' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '🧑🏿‍🐰‍🧑🏻' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '🧑🏿‍🐰‍🧑🏼' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '🧑🏿‍🐰‍🧑🏽' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '🧑🏿‍🐰‍🧑🏾' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏻‍🫯‍👨🏼' => 'abagabo barushanwa: ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '👨🏻‍🫯‍👨🏽' => 'abagabo barushanwa: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '👨🏻‍🫯‍👨🏾' => 'abagabo barushanwa: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏻‍🫯‍👨🏿' => 'abagabo barushanwa: ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '👨🏼‍🫯‍👨🏻' => 'abagabo barushanwa: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '👨🏼‍🫯‍👨🏽' => 'abagabo barushanwa: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '👨🏼‍🫯‍👨🏾' => 'abagabo barushanwa: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏼‍🫯‍👨🏿' => 'abagabo barushanwa: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '👨🏽‍🫯‍👨🏻' => 'abagabo barushanwa: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '👨🏽‍🫯‍👨🏼' => 'abagabo barushanwa: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '👨🏽‍🫯‍👨🏾' => 'abagabo barushanwa: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏽‍🫯‍👨🏿' => 'abagabo barushanwa: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '👨🏾‍🫯‍👨🏻' => 'abagabo barushanwa: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '👨🏾‍🫯‍👨🏼' => 'abagabo barushanwa: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '👨🏾‍🫯‍👨🏽' => 'abagabo barushanwa: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '👨🏾‍🫯‍👨🏿' => 'abagabo barushanwa: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '👨🏿‍🫯‍👨🏻' => 'abagabo barushanwa: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '👨🏿‍🫯‍👨🏼' => 'abagabo barushanwa: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '👨🏿‍🫯‍👨🏽' => 'abagabo barushanwa: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '👨🏿‍🫯‍👨🏾' => 'abagabo barushanwa: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏻‍❤‍👨🏻' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rwera',
    '👨🏻‍❤‍👨🏼' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '👨🏻‍❤‍👨🏽' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '👨🏻‍❤‍👨🏾' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏻‍❤‍👨🏿' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '👨🏼‍❤‍👨🏻' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '👨🏼‍❤‍👨🏼' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rwera gahoro',
    '👨🏼‍❤‍👨🏽' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '👨🏼‍❤‍👨🏾' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏼‍❤‍👨🏿' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '👨🏽‍❤‍👨🏻' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '👨🏽‍❤‍👨🏼' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '👨🏽‍❤‍👨🏽' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rw’inzobe',
    '👨🏽‍❤‍👨🏾' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏽‍❤‍👨🏿' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '👨🏾‍❤‍👨🏻' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '👨🏾‍❤‍👨🏼' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '👨🏾‍❤‍👨🏽' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '👨🏾‍❤‍👨🏾' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏾‍❤‍👨🏿' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '👨🏿‍❤‍👨🏻' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '👨🏿‍❤‍👨🏼' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '👨🏿‍❤‍👨🏽' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '👨🏿‍❤‍👨🏾' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍❤‍👨🏿' => 'ikupule n’umutima: umugabo, umugabo, ibara ry’uruhu rwirabura',
    '👨🏻‍🐰‍👨🏼' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '👨🏻‍🐰‍👨🏽' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '👨🏻‍🐰‍👨🏾' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏻‍🐰‍👨🏿' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '👨🏼‍🐰‍👨🏻' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '👨🏼‍🐰‍👨🏽' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '👨🏼‍🐰‍👨🏾' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏼‍🐰‍👨🏿' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '👨🏽‍🐰‍👨🏻' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '👨🏽‍🐰‍👨🏼' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '👨🏽‍🐰‍👨🏾' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏽‍🐰‍👨🏿' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '👨🏾‍🐰‍👨🏻' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '👨🏾‍🐰‍👨🏼' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '👨🏾‍🐰‍👨🏽' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '👨🏾‍🐰‍👨🏿' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '👨🏿‍🐰‍👨🏻' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '👨🏿‍🐰‍👨🏼' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '👨🏿‍🐰‍👨🏽' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '👨🏿‍🐰‍👨🏾' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏻‍🫯‍👩🏼' => 'abagore barushanwa: ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '👩🏻‍🫯‍👩🏽' => 'abagore barushanwa: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '👩🏻‍🫯‍👩🏾' => 'abagore barushanwa: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏻‍🫯‍👩🏿' => 'abagore barushanwa: ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '👩🏼‍🫯‍👩🏻' => 'abagore barushanwa: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '👩🏼‍🫯‍👩🏽' => 'abagore barushanwa: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '👩🏼‍🫯‍👩🏾' => 'abagore barushanwa: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏼‍🫯‍👩🏿' => 'abagore barushanwa: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '👩🏽‍🫯‍👩🏻' => 'abagore barushanwa: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '👩🏽‍🫯‍👩🏼' => 'abagore barushanwa: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '👩🏽‍🫯‍👩🏾' => 'abagore barushanwa: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏽‍🫯‍👩🏿' => 'abagore barushanwa: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '👩🏾‍🫯‍👩🏻' => 'abagore barushanwa: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '👩🏾‍🫯‍👩🏼' => 'abagore barushanwa: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '👩🏾‍🫯‍👩🏽' => 'abagore barushanwa: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '👩🏾‍🫯‍👩🏿' => 'abagore barushanwa: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '👩🏿‍🫯‍👩🏻' => 'abagore barushanwa: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '👩🏿‍🫯‍👩🏼' => 'abagore barushanwa: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '👩🏿‍🫯‍👩🏽' => 'abagore barushanwa: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '👩🏿‍🫯‍👩🏾' => 'abagore barushanwa: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏻‍❤‍👨🏻' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rwera',
    '👩🏻‍❤‍👨🏼' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '👩🏻‍❤‍👨🏽' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '👩🏻‍❤‍👨🏾' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏻‍❤‍👨🏿' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '👩🏼‍❤‍👨🏻' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '👩🏼‍❤‍👨🏼' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rwera gahoro',
    '👩🏼‍❤‍👨🏽' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '👩🏼‍❤‍👨🏾' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏼‍❤‍👨🏿' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '👩🏽‍❤‍👨🏻' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '👩🏽‍❤‍👨🏼' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '👩🏽‍❤‍👨🏽' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rw’inzobe',
    '👩🏽‍❤‍👨🏾' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏽‍❤‍👨🏿' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '👩🏾‍❤‍👨🏻' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '👩🏾‍❤‍👨🏼' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '👩🏾‍❤‍👨🏽' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '👩🏾‍❤‍👨🏾' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏾‍❤‍👨🏿' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '👩🏿‍❤‍👨🏻' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '👩🏿‍❤‍👨🏼' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '👩🏿‍❤‍👨🏽' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '👩🏿‍❤‍👨🏾' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍❤‍👨🏿' => 'ikupule n’umutima: umugore, umugabo, ibara ry’uruhu rwirabura',
    '👩🏻‍❤‍👩🏻' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rwera',
    '👩🏻‍❤‍👩🏼' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '👩🏻‍❤‍👩🏽' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '👩🏻‍❤‍👩🏾' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏻‍❤‍👩🏿' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '👩🏼‍❤‍👩🏻' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '👩🏼‍❤‍👩🏼' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rwera gahoro',
    '👩🏼‍❤‍👩🏽' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '👩🏼‍❤‍👩🏾' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏼‍❤‍👩🏿' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '👩🏽‍❤‍👩🏻' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '👩🏽‍❤‍👩🏼' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '👩🏽‍❤‍👩🏽' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rw’inzobe',
    '👩🏽‍❤‍👩🏾' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏽‍❤‍👩🏿' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '👩🏾‍❤‍👩🏻' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '👩🏾‍❤‍👩🏼' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '👩🏾‍❤‍👩🏽' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '👩🏾‍❤‍👩🏾' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏾‍❤‍👩🏿' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '👩🏿‍❤‍👩🏻' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '👩🏿‍❤‍👩🏼' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '👩🏿‍❤‍👩🏽' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '👩🏿‍❤‍👩🏾' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍❤‍👩🏿' => 'ikupule n’umutima: umugore, umugore, ibara ry’uruhu rwirabura',
    '👩🏻‍🐰‍👩🏼' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '👩🏻‍🐰‍👩🏽' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '👩🏻‍🐰‍👩🏾' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏻‍🐰‍👩🏿' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '👩🏼‍🐰‍👩🏻' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '👩🏼‍🐰‍👩🏽' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '👩🏼‍🐰‍👩🏾' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏼‍🐰‍👩🏿' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '👩🏽‍🐰‍👩🏻' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '👩🏽‍🐰‍👩🏼' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '👩🏽‍🐰‍👩🏾' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏽‍🐰‍👩🏿' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '👩🏾‍🐰‍👩🏻' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '👩🏾‍🐰‍👩🏼' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '👩🏾‍🐰‍👩🏽' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '👩🏾‍🐰‍👩🏿' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '👩🏿‍🐰‍👩🏻' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '👩🏿‍🐰‍👩🏼' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '👩🏿‍🐰‍👩🏽' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '👩🏿‍🐰‍👩🏾' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏻‍🤝‍👩🏼' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '👩🏻‍🤝‍👩🏽' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '👩🏻‍🤝‍👩🏾' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏻‍🤝‍👩🏿' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '👩🏼‍🤝‍👩🏻' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '👩🏼‍🤝‍👩🏽' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '👩🏼‍🤝‍👩🏾' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏼‍🤝‍👩🏿' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '👩🏽‍🤝‍👩🏻' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '👩🏽‍🤝‍👩🏼' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '👩🏽‍🤝‍👩🏾' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏽‍🤝‍👩🏿' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '👩🏾‍🤝‍👩🏻' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '👩🏾‍🤝‍👩🏼' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '👩🏾‍🤝‍👩🏽' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '👩🏾‍🤝‍👩🏿' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '👩🏿‍🤝‍👩🏻' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '👩🏿‍🤝‍👩🏼' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '👩🏿‍🤝‍👩🏽' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '👩🏿‍🤝‍👩🏾' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏻‍🤝‍👨🏼' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '👩🏻‍🤝‍👨🏽' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '👩🏻‍🤝‍👨🏾' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏻‍🤝‍👨🏿' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '👩🏼‍🤝‍👨🏻' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '👩🏼‍🤝‍👨🏽' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '👩🏼‍🤝‍👨🏾' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏼‍🤝‍👨🏿' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '👩🏽‍🤝‍👨🏻' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '👩🏽‍🤝‍👨🏼' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '👩🏽‍🤝‍👨🏾' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '👩🏽‍🤝‍👨🏿' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '👩🏾‍🤝‍👨🏻' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '👩🏾‍🤝‍👨🏼' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '👩🏾‍🤝‍👨🏽' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '👩🏾‍🤝‍👨🏿' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '👩🏿‍🤝‍👨🏻' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '👩🏿‍🤝‍👨🏼' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '👩🏿‍🤝‍👨🏽' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '👩🏿‍🤝‍👨🏾' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏻‍🤝‍👨🏼' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '👨🏻‍🤝‍👨🏽' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '👨🏻‍🤝‍👨🏾' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏻‍🤝‍👨🏿' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '👨🏼‍🤝‍👨🏻' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '👨🏼‍🤝‍👨🏽' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '👨🏼‍🤝‍👨🏾' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏼‍🤝‍👨🏿' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '👨🏽‍🤝‍👨🏻' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '👨🏽‍🤝‍👨🏼' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '👨🏽‍🤝‍👨🏾' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '👨🏽‍🤝‍👨🏿' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '👨🏾‍🤝‍👨🏻' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '👨🏾‍🤝‍👨🏼' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '👨🏾‍🤝‍👨🏽' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '👨🏾‍🤝‍👨🏿' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '👨🏿‍🤝‍👨🏻' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '👨🏿‍🤝‍👨🏼' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '👨🏿‍🤝‍👨🏽' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '👨🏿‍🤝‍👨🏾' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '👩‍❤‍💋‍👨' => 'gusomana: umugore, umugabo',
    '👨‍❤‍💋‍👨' => 'gusomana: umugabo, umugabo',
    '👩‍❤‍💋‍👩' => 'gusomana: umugore, umugore',
    '👨‍👩‍👧‍👦' => 'umuryango: umugabo, umugore, umukobwa, umuhungu',
    '👨‍👩‍👦‍👦' => 'umuryango: umugabo, umugore, umuhungu, umuhungu',
    '👨‍👩‍👧‍👧' => 'umuryango: umugabo, umugore, umukobwa, umukobwa',
    '👨‍👨‍👧‍👦' => 'umuryango: umugabo, umugabo, umukobwa, umuhungu',
    '👨‍👨‍👦‍👦' => 'umuryango: umugabo, umugabo, umuhungu, umuhungu',
    '👨‍👨‍👧‍👧' => 'umuryango: umugabo, umugabo, umukobwa, umukobwa',
    '👩‍👩‍👧‍👦' => 'umuryango: umugore, umugore, umukobwa, umuhungu',
    '👩‍👩‍👦‍👦' => 'umuryango: umugore, umugore, umuhungu, umuhungu',
    '👩‍👩‍👧‍👧' => 'umuryango: umugore, umugore, umukobwa, umukobwa',
    '🫱🏻‍🫲🏼' => 'gusuhuzanya: ibara ry’uruhu rwera, ibara ry’uruhu rwera gahoro',
    '🫱🏻‍🫲🏽' => 'gusuhuzanya: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe',
    '🫱🏻‍🫲🏾' => 'gusuhuzanya: ibara ry’uruhu rwera, ibara ry’uruhu rw’inzobe yirabura',
    '🫱🏻‍🫲🏿' => 'gusuhuzanya: ibara ry’uruhu rwera, ibara ry’uruhu rwirabura',
    '🫱🏼‍🫲🏻' => 'gusuhuzanya: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwera',
    '🫱🏼‍🫲🏽' => 'gusuhuzanya: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe',
    '🫱🏼‍🫲🏾' => 'gusuhuzanya: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rw’inzobe yirabura',
    '🫱🏼‍🫲🏿' => 'gusuhuzanya: ibara ry’uruhu rwera gahoro, ibara ry’uruhu rwirabura',
    '🫱🏽‍🫲🏻' => 'gusuhuzanya: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera',
    '🫱🏽‍🫲🏼' => 'gusuhuzanya: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwera gahoro',
    '🫱🏽‍🫲🏾' => 'gusuhuzanya: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rw’inzobe yirabura',
    '🫱🏽‍🫲🏿' => 'gusuhuzanya: ibara ry’uruhu rw’inzobe, ibara ry’uruhu rwirabura',
    '🫱🏾‍🫲🏻' => 'gusuhuzanya: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera',
    '🫱🏾‍🫲🏼' => 'gusuhuzanya: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwera gahoro',
    '🫱🏾‍🫲🏽' => 'gusuhuzanya: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rw’inzobe',
    '🫱🏾‍🫲🏿' => 'gusuhuzanya: ibara ry’uruhu rw’inzobe yirabura, ibara ry’uruhu rwirabura',
    '🫱🏿‍🫲🏻' => 'gusuhuzanya: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera',
    '🫱🏿‍🫲🏼' => 'gusuhuzanya: ibara ry’uruhu rwirabura, ibara ry’uruhu rwera gahoro',
    '🫱🏿‍🫲🏽' => 'gusuhuzanya: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe',
    '🫱🏿‍🫲🏾' => 'gusuhuzanya: ibara ry’uruhu rwirabura, ibara ry’uruhu rw’inzobe yirabura',
    '👩‍❤‍👨' => 'ikupule n’umutima: umugore, umugabo',
    '👨‍❤‍👨' => 'ikupule n’umutima: umugabo, umugabo',
    '👩‍❤‍👩' => 'ikupule n’umutima: umugore, umugore',
    '👨‍👩‍👦' => 'umuryango: umugabo, umugore, umuhungu',
    '👨‍👩‍👧' => 'umuryango: umugabo, umugore, umukobwa',
    '👨‍👨‍👦' => 'umuryango: umugabo, umugabo, umuhungu',
    '👨‍👨‍👧' => 'umuryango: umugabo, umugabo, umukobwa',
    '👩‍👩‍👦' => 'umuryango: umugore, umugore, umuhungu',
    '👩‍👩‍👧' => 'umuryango: umugore, umugore, umukobwa',
    '👨‍👦‍👦' => 'umuryango: umugabo, umuhungu, umuhungu',
    '👨‍👧‍👦' => 'umuryango: umugabo, umukobwa, umuhungu',
    '👨‍👧‍👧' => 'umuryango: umugabo, umukobwa, umukobwa',
    '👩‍👦‍👦' => 'umuryango: umugore, umuhungu, umuhungu',
    '👩‍👧‍👦' => 'umuryango: umugore, umukobwa, umuhungu',
    '👩‍👧‍👧' => 'umuryango: umugore, umukobwa, umukobwa',
    '👱🏻‍♂' => 'umugabo ufite imisatsi yera: ibara ry’uruhu rwera',
    '👱🏼‍♂' => 'umugabo ufite imisatsi yera: ibara ry’uruhu rwera gahoro',
    '👱🏽‍♂' => 'umugabo ufite imisatsi yera: ibara ry’uruhu rw’inzobe',
    '👱🏾‍♂' => 'umugabo ufite imisatsi yera: ibara ry’uruhu rw’inzobe yirabura',
    '👱🏿‍♂' => 'umugabo ufite imisatsi yera: ibara ry’uruhu rwirabura',
    '👱🏻‍♀' => 'umugore ufite imisatsi yera: ibara ry’uruhu rwera',
    '👱🏼‍♀' => 'umugore ufite imisatsi yera: ibara ry’uruhu rwera gahoro',
    '👱🏽‍♀' => 'umugore ufite imisatsi yera: ibara ry’uruhu rw’inzobe',
    '👱🏾‍♀' => 'umugore ufite imisatsi yera: ibara ry’uruhu rw’inzobe yirabura',
    '👱🏿‍♀' => 'umugore ufite imisatsi yera: ibara ry’uruhu rwirabura',
    '🙍🏻‍♂' => 'umugabo utishimye: ibara ry’uruhu rwera',
    '🙍🏼‍♂' => 'umugabo utishimye: ibara ry’uruhu rwera gahoro',
    '🙍🏽‍♂' => 'umugabo utishimye: ibara ry’uruhu rw’inzobe',
    '🙍🏾‍♂' => 'umugabo utishimye: ibara ry’uruhu rw’inzobe yirabura',
    '🙍🏿‍♂' => 'umugabo utishimye: ibara ry’uruhu rwirabura',
    '🙍🏻‍♀' => 'umugore utishimye: ibara ry’uruhu rwera',
    '🙍🏼‍♀' => 'umugore utishimye: ibara ry’uruhu rwera gahoro',
    '🙍🏽‍♀' => 'umugore utishimye: ibara ry’uruhu rw’inzobe',
    '🙍🏾‍♀' => 'umugore utishimye: ibara ry’uruhu rw’inzobe yirabura',
    '🙍🏿‍♀' => 'umugore utishimye: ibara ry’uruhu rwirabura',
    '🙎🏻‍♂' => 'umugabo urakaye: ibara ry’uruhu rwera',
    '🙎🏼‍♂' => 'umugabo urakaye: ibara ry’uruhu rwera gahoro',
    '🙎🏽‍♂' => 'umugabo urakaye: ibara ry’uruhu rw’inzobe',
    '🙎🏾‍♂' => 'umugabo urakaye: ibara ry’uruhu rw’inzobe yirabura',
    '🙎🏿‍♂' => 'umugabo urakaye: ibara ry’uruhu rwirabura',
    '🙎🏻‍♀' => 'umugore urakaye: ibara ry’uruhu rwera',
    '🙎🏼‍♀' => 'umugore urakaye: ibara ry’uruhu rwera gahoro',
    '🙎🏽‍♀' => 'umugore urakaye: ibara ry’uruhu rw’inzobe',
    '🙎🏾‍♀' => 'umugore urakaye: ibara ry’uruhu rw’inzobe yirabura',
    '🙎🏿‍♀' => 'umugore urakaye: ibara ry’uruhu rwirabura',
    '🙅🏻‍♂' => 'umugabo werekana ikimenyetso cya OYA: ibara ry’uruhu rwera',
    '🙅🏼‍♂' => 'umugabo werekana ikimenyetso cya OYA: ibara ry’uruhu rwera gahoro',
    '🙅🏽‍♂' => 'umugabo werekana ikimenyetso cya OYA: ibara ry’uruhu rw’inzobe',
    '🙅🏾‍♂' => 'umugabo werekana ikimenyetso cya OYA: ibara ry’uruhu rw’inzobe yirabura',
    '🙅🏿‍♂' => 'umugabo werekana ikimenyetso cya OYA: ibara ry’uruhu rwirabura',
    '🙅🏻‍♀' => 'umugore werekana ikimenyetso cya OYA: ibara ry’uruhu rwera',
    '🙅🏼‍♀' => 'umugore werekana ikimenyetso cya OYA: ibara ry’uruhu rwera gahoro',
    '🙅🏽‍♀' => 'umugore werekana ikimenyetso cya OYA: ibara ry’uruhu rw’inzobe',
    '🙅🏾‍♀' => 'umugore werekana ikimenyetso cya OYA: ibara ry’uruhu rw’inzobe yirabura',
    '🙅🏿‍♀' => 'umugore werekana ikimenyetso cya OYA: ibara ry’uruhu rwirabura',
    '🙆🏻‍♂' => 'umugabo werekana ikimenyetso cya Yego: ibara ry’uruhu rwera',
    '🙆🏼‍♂' => 'umugabo werekana ikimenyetso cya Yego: ibara ry’uruhu rwera gahoro',
    '🙆🏽‍♂' => 'umugabo werekana ikimenyetso cya Yego: ibara ry’uruhu rw’inzobe',
    '🙆🏾‍♂' => 'umugabo werekana ikimenyetso cya Yego: ibara ry’uruhu rw’inzobe yirabura',
    '🙆🏿‍♂' => 'umugabo werekana ikimenyetso cya Yego: ibara ry’uruhu rwirabura',
    '🙆🏻‍♀' => 'umugore werekana ikimenyetso cya Yego: ibara ry’uruhu rwera',
    '🙆🏼‍♀' => 'umugore werekana ikimenyetso cya Yego: ibara ry’uruhu rwera gahoro',
    '🙆🏽‍♀' => 'umugore werekana ikimenyetso cya Yego: ibara ry’uruhu rw’inzobe',
    '🙆🏾‍♀' => 'umugore werekana ikimenyetso cya Yego: ibara ry’uruhu rw’inzobe yirabura',
    '🙆🏿‍♀' => 'umugore werekana ikimenyetso cya Yego: ibara ry’uruhu rwirabura',
    '💁🏻‍♂' => 'umugabo uteze ikiganza: ibara ry’uruhu rwera',
    '💁🏼‍♂' => 'umugabo uteze ikiganza: ibara ry’uruhu rwera gahoro',
    '💁🏽‍♂' => 'umugabo uteze ikiganza: ibara ry’uruhu rw’inzobe',
    '💁🏾‍♂' => 'umugabo uteze ikiganza: ibara ry’uruhu rw’inzobe yirabura',
    '💁🏿‍♂' => 'umugabo uteze ikiganza: ibara ry’uruhu rwirabura',
    '💁🏻‍♀' => 'umugore uteze ikiganza: ibara ry’uruhu rwera',
    '💁🏼‍♀' => 'umugore uteze ikiganza: ibara ry’uruhu rwera gahoro',
    '💁🏽‍♀' => 'umugore uteze ikiganza: ibara ry’uruhu rw’inzobe',
    '💁🏾‍♀' => 'umugore uteze ikiganza: ibara ry’uruhu rw’inzobe yirabura',
    '💁🏿‍♀' => 'umugore uteze ikiganza: ibara ry’uruhu rwirabura',
    '🙋🏻‍♂' => 'umugabo uzamuye ikiganza: ibara ry’uruhu rwera',
    '🙋🏼‍♂' => 'umugabo uzamuye ikiganza: ibara ry’uruhu rwera gahoro',
    '🙋🏽‍♂' => 'umugabo uzamuye ikiganza: ibara ry’uruhu rw’inzobe',
    '🙋🏾‍♂' => 'umugabo uzamuye ikiganza: ibara ry’uruhu rw’inzobe yirabura',
    '🙋🏿‍♂' => 'umugabo uzamuye ikiganza: ibara ry’uruhu rwirabura',
    '🙋🏻‍♀' => 'umugore uzamuye ikiganza: ibara ry’uruhu rwera',
    '🙋🏼‍♀' => 'umugore uzamuye ikiganza: ibara ry’uruhu rwera gahoro',
    '🙋🏽‍♀' => 'umugore uzamuye ikiganza: ibara ry’uruhu rw’inzobe',
    '🙋🏾‍♀' => 'umugore uzamuye ikiganza: ibara ry’uruhu rw’inzobe yirabura',
    '🙋🏿‍♀' => 'umugore uzamuye ikiganza: ibara ry’uruhu rwirabura',
    '🙇🏻‍♂' => 'umugabo wunamye: ibara ry’uruhu rwera',
    '🙇🏼‍♂' => 'umugabo wunamye: ibara ry’uruhu rwera gahoro',
    '🙇🏽‍♂' => 'umugabo wunamye: ibara ry’uruhu rw’inzobe',
    '🙇🏾‍♂' => 'umugabo wunamye: ibara ry’uruhu rw’inzobe yirabura',
    '🙇🏿‍♂' => 'umugabo wunamye: ibara ry’uruhu rwirabura',
    '🙇🏻‍♀' => 'umugore wunamye: ibara ry’uruhu rwera',
    '🙇🏼‍♀' => 'umugore wunamye: ibara ry’uruhu rwera gahoro',
    '🙇🏽‍♀' => 'umugore wunamye: ibara ry’uruhu rw’inzobe',
    '🙇🏾‍♀' => 'umugore wunamye: ibara ry’uruhu rw’inzobe yirabura',
    '🙇🏿‍♀' => 'umugore wunamye: ibara ry’uruhu rwirabura',
    '🤦🏻‍♂' => 'umugabo ushyize ikiganza mu maso: ibara ry’uruhu rwera',
    '🤦🏼‍♂' => 'umugabo ushyize ikiganza mu maso: ibara ry’uruhu rwera gahoro',
    '🤦🏽‍♂' => 'umugabo ushyize ikiganza mu maso: ibara ry’uruhu rw’inzobe',
    '🤦🏾‍♂' => 'umugabo ushyize ikiganza mu maso: ibara ry’uruhu rw’inzobe yirabura',
    '🤦🏿‍♂' => 'umugabo ushyize ikiganza mu maso: ibara ry’uruhu rwirabura',
    '🤦🏻‍♀' => 'umugore ushyize ikiganza mu maso: ibara ry’uruhu rwera',
    '🤦🏼‍♀' => 'umugore ushyize ikiganza mu maso: ibara ry’uruhu rwera gahoro',
    '🤦🏽‍♀' => 'umugore ushyize ikiganza mu maso: ibara ry’uruhu rw’inzobe',
    '🤦🏾‍♀' => 'umugore ushyize ikiganza mu maso: ibara ry’uruhu rw’inzobe yirabura',
    '🤦🏿‍♀' => 'umugore ushyize ikiganza mu maso: ibara ry’uruhu rwirabura',
    '🤷🏻‍♂' => 'umugabo utigisa intugu: ibara ry’uruhu rwera',
    '🤷🏼‍♂' => 'umugabo utigisa intugu: ibara ry’uruhu rwera gahoro',
    '🤷🏽‍♂' => 'umugabo utigisa intugu: ibara ry’uruhu rw’inzobe',
    '🤷🏾‍♂' => 'umugabo utigisa intugu: ibara ry’uruhu rw’inzobe yirabura',
    '🤷🏿‍♂' => 'umugabo utigisa intugu: ibara ry’uruhu rwirabura',
    '🤷🏻‍♀' => 'umugore utigisa intugu: ibara ry’uruhu rwera',
    '🤷🏼‍♀' => 'umugore utigisa intugu: ibara ry’uruhu rwera gahoro',
    '🤷🏽‍♀' => 'umugore utigisa intugu: ibara ry’uruhu rw’inzobe',
    '🤷🏾‍♀' => 'umugore utigisa intugu: ibara ry’uruhu rw’inzobe yirabura',
    '🤷🏿‍♀' => 'umugore utigisa intugu: ibara ry’uruhu rwirabura',
    '👨🏻‍⚕' => 'umugabo muzima w’umukozi: ibara ry’uruhu rwera',
    '👨🏼‍⚕' => 'umugabo muzima w’umukozi: ibara ry’uruhu rwera gahoro',
    '👨🏽‍⚕' => 'umugabo muzima w’umukozi: ibara ry’uruhu rw’inzobe',
    '👨🏾‍⚕' => 'umugabo muzima w’umukozi: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍⚕' => 'umugabo muzima w’umukozi: ibara ry’uruhu rwirabura',
    '👩🏻‍⚕' => 'umugore ukora mu by’ubuzima: ibara ry’uruhu rwera',
    '👩🏼‍⚕' => 'umugore ukora mu by’ubuzima: ibara ry’uruhu rwera gahoro',
    '👩🏽‍⚕' => 'umugore ukora mu by’ubuzima: ibara ry’uruhu rw’inzobe',
    '👩🏾‍⚕' => 'umugore ukora mu by’ubuzima: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍⚕' => 'umugore ukora mu by’ubuzima: ibara ry’uruhu rwirabura',
    '👨🏻‍🎓' => 'umugabo w’umunyeshuri: ibara ry’uruhu rwera',
    '👨🏼‍🎓' => 'umugabo w’umunyeshuri: ibara ry’uruhu rwera gahoro',
    '👨🏽‍🎓' => 'umugabo w’umunyeshuri: ibara ry’uruhu rw’inzobe',
    '👨🏾‍🎓' => 'umugabo w’umunyeshuri: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍🎓' => 'umugabo w’umunyeshuri: ibara ry’uruhu rwirabura',
    '👩🏻‍🎓' => 'umugore w’umunyeshuri: ibara ry’uruhu rwera',
    '👩🏼‍🎓' => 'umugore w’umunyeshuri: ibara ry’uruhu rwera gahoro',
    '👩🏽‍🎓' => 'umugore w’umunyeshuri: ibara ry’uruhu rw’inzobe',
    '👩🏾‍🎓' => 'umugore w’umunyeshuri: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍🎓' => 'umugore w’umunyeshuri: ibara ry’uruhu rwirabura',
    '👨🏻‍🏫' => 'umugabo w’umwarimu: ibara ry’uruhu rwera',
    '👨🏼‍🏫' => 'umugabo w’umwarimu: ibara ry’uruhu rwera gahoro',
    '👨🏽‍🏫' => 'umugabo w’umwarimu: ibara ry’uruhu rw’inzobe',
    '👨🏾‍🏫' => 'umugabo w’umwarimu: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍🏫' => 'umugabo w’umwarimu: ibara ry’uruhu rwirabura',
    '👩🏻‍🏫' => 'umwarimukazi: ibara ry’uruhu rwera',
    '👩🏼‍🏫' => 'umwarimukazi: ibara ry’uruhu rwera gahoro',
    '👩🏽‍🏫' => 'umwarimukazi: ibara ry’uruhu rw’inzobe',
    '👩🏾‍🏫' => 'umwarimukazi: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍🏫' => 'umwarimukazi: ibara ry’uruhu rwirabura',
    '👨🏻‍⚖' => 'umugabo w’umucamanza: ibara ry’uruhu rwera',
    '👨🏼‍⚖' => 'umugabo w’umucamanza: ibara ry’uruhu rwera gahoro',
    '👨🏽‍⚖' => 'umugabo w’umucamanza: ibara ry’uruhu rw’inzobe',
    '👨🏾‍⚖' => 'umugabo w’umucamanza: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍⚖' => 'umugabo w’umucamanza: ibara ry’uruhu rwirabura',
    '👩🏻‍⚖' => 'umugore w’umucamanza: ibara ry’uruhu rwera',
    '👩🏼‍⚖' => 'umugore w’umucamanza: ibara ry’uruhu rwera gahoro',
    '👩🏽‍⚖' => 'umugore w’umucamanza: ibara ry’uruhu rw’inzobe',
    '👩🏾‍⚖' => 'umugore w’umucamanza: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍⚖' => 'umugore w’umucamanza: ibara ry’uruhu rwirabura',
    '👨🏻‍🌾' => 'umugabo w’umworozi: ibara ry’uruhu rwera',
    '👨🏼‍🌾' => 'umugabo w’umworozi: ibara ry’uruhu rwera gahoro',
    '👨🏽‍🌾' => 'umugabo w’umworozi: ibara ry’uruhu rw’inzobe',
    '👨🏾‍🌾' => 'umugabo w’umworozi: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍🌾' => 'umugabo w’umworozi: ibara ry’uruhu rwirabura',
    '👩🏻‍🌾' => 'umworozikazi: ibara ry’uruhu rwera',
    '👩🏼‍🌾' => 'umworozikazi: ibara ry’uruhu rwera gahoro',
    '👩🏽‍🌾' => 'umworozikazi: ibara ry’uruhu rw’inzobe',
    '👩🏾‍🌾' => 'umworozikazi: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍🌾' => 'umworozikazi: ibara ry’uruhu rwirabura',
    '👨🏻‍🍳' => 'umugabo w’umutetsi: ibara ry’uruhu rwera',
    '👨🏼‍🍳' => 'umugabo w’umutetsi: ibara ry’uruhu rwera gahoro',
    '👨🏽‍🍳' => 'umugabo w’umutetsi: ibara ry’uruhu rw’inzobe',
    '👨🏾‍🍳' => 'umugabo w’umutetsi: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍🍳' => 'umugabo w’umutetsi: ibara ry’uruhu rwirabura',
    '👩🏻‍🍳' => 'umutetsikazi: ibara ry’uruhu rwera',
    '👩🏼‍🍳' => 'umutetsikazi: ibara ry’uruhu rwera gahoro',
    '👩🏽‍🍳' => 'umutetsikazi: ibara ry’uruhu rw’inzobe',
    '👩🏾‍🍳' => 'umutetsikazi: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍🍳' => 'umutetsikazi: ibara ry’uruhu rwirabura',
    '👨🏻‍🔧' => 'umugabo w’umukanishi: ibara ry’uruhu rwera',
    '👨🏼‍🔧' => 'umugabo w’umukanishi: ibara ry’uruhu rwera gahoro',
    '👨🏽‍🔧' => 'umugabo w’umukanishi: ibara ry’uruhu rw’inzobe',
    '👨🏾‍🔧' => 'umugabo w’umukanishi: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍🔧' => 'umugabo w’umukanishi: ibara ry’uruhu rwirabura',
    '👩🏻‍🔧' => 'umugore w’umukanishi: ibara ry’uruhu rwera',
    '👩🏼‍🔧' => 'umugore w’umukanishi: ibara ry’uruhu rwera gahoro',
    '👩🏽‍🔧' => 'umugore w’umukanishi: ibara ry’uruhu rw’inzobe',
    '👩🏾‍🔧' => 'umugore w’umukanishi: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍🔧' => 'umugore w’umukanishi: ibara ry’uruhu rwirabura',
    '👨🏻‍🏭' => 'umugabo ukora mu ruganda: ibara ry’uruhu rwera',
    '👨🏼‍🏭' => 'umugabo ukora mu ruganda: ibara ry’uruhu rwera gahoro',
    '👨🏽‍🏭' => 'umugabo ukora mu ruganda: ibara ry’uruhu rw’inzobe',
    '👨🏾‍🏭' => 'umugabo ukora mu ruganda: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍🏭' => 'umugabo ukora mu ruganda: ibara ry’uruhu rwirabura',
    '👩🏻‍🏭' => 'umugore ukora mu ruganda: ibara ry’uruhu rwera',
    '👩🏼‍🏭' => 'umugore ukora mu ruganda: ibara ry’uruhu rwera gahoro',
    '👩🏽‍🏭' => 'umugore ukora mu ruganda: ibara ry’uruhu rw’inzobe',
    '👩🏾‍🏭' => 'umugore ukora mu ruganda: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍🏭' => 'umugore ukora mu ruganda: ibara ry’uruhu rwirabura',
    '👨🏻‍💼' => 'umugabo ukorera mu biro: ibara ry’uruhu rwera',
    '👨🏼‍💼' => 'umugabo ukorera mu biro: ibara ry’uruhu rwera gahoro',
    '👨🏽‍💼' => 'umugabo ukorera mu biro: ibara ry’uruhu rw’inzobe',
    '👨🏾‍💼' => 'umugabo ukorera mu biro: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍💼' => 'umugabo ukorera mu biro: ibara ry’uruhu rwirabura',
    '👩🏻‍💼' => 'umugore ukorera mu biro: ibara ry’uruhu rwera',
    '👩🏼‍💼' => 'umugore ukorera mu biro: ibara ry’uruhu rwera gahoro',
    '👩🏽‍💼' => 'umugore ukorera mu biro: ibara ry’uruhu rw’inzobe',
    '👩🏾‍💼' => 'umugore ukorera mu biro: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍💼' => 'umugore ukorera mu biro: ibara ry’uruhu rwirabura',
    '👨🏻‍🔬' => 'umugabo w’impuguke mu bya siyansi: ibara ry’uruhu rwera',
    '👨🏼‍🔬' => 'umugabo w’impuguke mu bya siyansi: ibara ry’uruhu rwera gahoro',
    '👨🏽‍🔬' => 'umugabo w’impuguke mu bya siyansi: ibara ry’uruhu rw’inzobe',
    '👨🏾‍🔬' => 'umugabo w’impuguke mu bya siyansi: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍🔬' => 'umugabo w’impuguke mu bya siyansi: ibara ry’uruhu rwirabura',
    '👩🏻‍🔬' => 'impugukekazi mu bya siyansi: ibara ry’uruhu rwera',
    '👩🏼‍🔬' => 'impugukekazi mu bya siyansi: ibara ry’uruhu rwera gahoro',
    '👩🏽‍🔬' => 'impugukekazi mu bya siyansi: ibara ry’uruhu rw’inzobe',
    '👩🏾‍🔬' => 'impugukekazi mu bya siyansi: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍🔬' => 'impugukekazi mu bya siyansi: ibara ry’uruhu rwirabura',
    '👨🏻‍💻' => 'umugabo w’impuguke mu by’ikoranabuhanga: ibara ry’uruhu rwera',
    '👨🏼‍💻' => 'umugabo w’impuguke mu by’ikoranabuhanga: ibara ry’uruhu rwera gahoro',
    '👨🏽‍💻' => 'umugabo w’impuguke mu by’ikoranabuhanga: ibara ry’uruhu rw’inzobe',
    '👨🏾‍💻' => 'umugabo w’impuguke mu by’ikoranabuhanga: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍💻' => 'umugabo w’impuguke mu by’ikoranabuhanga: ibara ry’uruhu rwirabura',
    '👩🏻‍💻' => 'umugabo w’impuguke mu by’ikoranahanga: ibara ry’uruhu rwera',
    '👩🏼‍💻' => 'umugabo w’impuguke mu by’ikoranahanga: ibara ry’uruhu rwera gahoro',
    '👩🏽‍💻' => 'umugabo w’impuguke mu by’ikoranahanga: ibara ry’uruhu rw’inzobe',
    '👩🏾‍💻' => 'umugabo w’impuguke mu by’ikoranahanga: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍💻' => 'umugabo w’impuguke mu by’ikoranahanga: ibara ry’uruhu rwirabura',
    '👨🏻‍🎤' => 'umugabo w’umuririmbyi: ibara ry’uruhu rwera',
    '👨🏼‍🎤' => 'umugabo w’umuririmbyi: ibara ry’uruhu rwera gahoro',
    '👨🏽‍🎤' => 'umugabo w’umuririmbyi: ibara ry’uruhu rw’inzobe',
    '👨🏾‍🎤' => 'umugabo w’umuririmbyi: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍🎤' => 'umugabo w’umuririmbyi: ibara ry’uruhu rwirabura',
    '👩🏻‍🎤' => 'umuririmbyikazi: ibara ry’uruhu rwera',
    '👩🏼‍🎤' => 'umuririmbyikazi: ibara ry’uruhu rwera gahoro',
    '👩🏽‍🎤' => 'umuririmbyikazi: ibara ry’uruhu rw’inzobe',
    '👩🏾‍🎤' => 'umuririmbyikazi: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍🎤' => 'umuririmbyikazi: ibara ry’uruhu rwirabura',
    '👨🏻‍🎨' => 'umugabo w’umunyabugeni: ibara ry’uruhu rwera',
    '👨🏼‍🎨' => 'umugabo w’umunyabugeni: ibara ry’uruhu rwera gahoro',
    '👨🏽‍🎨' => 'umugabo w’umunyabugeni: ibara ry’uruhu rw’inzobe',
    '👨🏾‍🎨' => 'umugabo w’umunyabugeni: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍🎨' => 'umugabo w’umunyabugeni: ibara ry’uruhu rwirabura',
    '👩🏻‍🎨' => 'umunyabugenikazi: ibara ry’uruhu rwera',
    '👩🏼‍🎨' => 'umunyabugenikazi: ibara ry’uruhu rwera gahoro',
    '👩🏽‍🎨' => 'umunyabugenikazi: ibara ry’uruhu rw’inzobe',
    '👩🏾‍🎨' => 'umunyabugenikazi: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍🎨' => 'umunyabugenikazi: ibara ry’uruhu rwirabura',
    '👨🏻‍✈' => 'umugabo w’umuderevu: ibara ry’uruhu rwera',
    '👨🏼‍✈' => 'umugabo w’umuderevu: ibara ry’uruhu rwera gahoro',
    '👨🏽‍✈' => 'umugabo w’umuderevu: ibara ry’uruhu rw’inzobe',
    '👨🏾‍✈' => 'umugabo w’umuderevu: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍✈' => 'umugabo w’umuderevu: ibara ry’uruhu rwirabura',
    '👩🏻‍✈' => 'umupilotekazi: ibara ry’uruhu rwera',
    '👩🏼‍✈' => 'umupilotekazi: ibara ry’uruhu rwera gahoro',
    '👩🏽‍✈' => 'umupilotekazi: ibara ry’uruhu rw’inzobe',
    '👩🏾‍✈' => 'umupilotekazi: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍✈' => 'umupilotekazi: ibara ry’uruhu rwirabura',
    '👨🏻‍🚀' => 'umugabo w’ impuguke mu by’ isanzure: ibara ry’uruhu rwera',
    '👨🏼‍🚀' => 'umugabo w’ impuguke mu by’ isanzure: ibara ry’uruhu rwera gahoro',
    '👨🏽‍🚀' => 'umugabo w’ impuguke mu by’ isanzure: ibara ry’uruhu rw’inzobe',
    '👨🏾‍🚀' => 'umugabo w’ impuguke mu by’ isanzure: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍🚀' => 'umugabo w’ impuguke mu by’ isanzure: ibara ry’uruhu rwirabura',
    '👩🏻‍🚀' => 'umugore w’impuguke mu by’isanzure: ibara ry’uruhu rwera',
    '👩🏼‍🚀' => 'umugore w’impuguke mu by’isanzure: ibara ry’uruhu rwera gahoro',
    '👩🏽‍🚀' => 'umugore w’impuguke mu by’isanzure: ibara ry’uruhu rw’inzobe',
    '👩🏾‍🚀' => 'umugore w’impuguke mu by’isanzure: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍🚀' => 'umugore w’impuguke mu by’isanzure: ibara ry’uruhu rwirabura',
    '👨🏻‍🚒' => 'umugabo uzimya umuriro: ibara ry’uruhu rwera',
    '👨🏼‍🚒' => 'umugabo uzimya umuriro: ibara ry’uruhu rwera gahoro',
    '👨🏽‍🚒' => 'umugabo uzimya umuriro: ibara ry’uruhu rw’inzobe',
    '👨🏾‍🚒' => 'umugabo uzimya umuriro: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿‍🚒' => 'umugabo uzimya umuriro: ibara ry’uruhu rwirabura',
    '👩🏻‍🚒' => 'umugore uzimya umuriro: ibara ry’uruhu rwera',
    '👩🏼‍🚒' => 'umugore uzimya umuriro: ibara ry’uruhu rwera gahoro',
    '👩🏽‍🚒' => 'umugore uzimya umuriro: ibara ry’uruhu rw’inzobe',
    '👩🏾‍🚒' => 'umugore uzimya umuriro: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿‍🚒' => 'umugore uzimya umuriro: ibara ry’uruhu rwirabura',
    '👮🏻‍♂' => 'umupolisi w’umugabo: ibara ry’uruhu rwera',
    '👮🏼‍♂' => 'umupolisi w’umugabo: ibara ry’uruhu rwera gahoro',
    '👮🏽‍♂' => 'umupolisi w’umugabo: ibara ry’uruhu rw’inzobe',
    '👮🏾‍♂' => 'umupolisi w’umugabo: ibara ry’uruhu rw’inzobe yirabura',
    '👮🏿‍♂' => 'umupolisi w’umugabo: ibara ry’uruhu rwirabura',
    '👮🏻‍♀' => 'umupolisi w’umugore: ibara ry’uruhu rwera',
    '👮🏼‍♀' => 'umupolisi w’umugore: ibara ry’uruhu rwera gahoro',
    '👮🏽‍♀' => 'umupolisi w’umugore: ibara ry’uruhu rw’inzobe',
    '👮🏾‍♀' => 'umupolisi w’umugore: ibara ry’uruhu rw’inzobe yirabura',
    '👮🏿‍♀' => 'umupolisi w’umugore: ibara ry’uruhu rwirabura',
    '🕵🏻‍♂' => 'umugenzuzi w’umugabo: ibara ry’uruhu rwera',
    '🕵🏼‍♂' => 'umugenzuzi w’umugabo: ibara ry’uruhu rwera gahoro',
    '🕵🏽‍♂' => 'umugenzuzi w’umugabo: ibara ry’uruhu rw’inzobe',
    '🕵🏾‍♂' => 'umugenzuzi w’umugabo: ibara ry’uruhu rw’inzobe yirabura',
    '🕵🏿‍♂' => 'umugenzuzi w’umugabo: ibara ry’uruhu rwirabura',
    '🕵🏻‍♀' => 'umugenzuzi w’umugore: ibara ry’uruhu rwera',
    '🕵🏼‍♀' => 'umugenzuzi w’umugore: ibara ry’uruhu rwera gahoro',
    '🕵🏽‍♀' => 'umugenzuzi w’umugore: ibara ry’uruhu rw’inzobe',
    '🕵🏾‍♀' => 'umugenzuzi w’umugore: ibara ry’uruhu rw’inzobe yirabura',
    '🕵🏿‍♀' => 'umugenzuzi w’umugore: ibara ry’uruhu rwirabura',
    '💂🏻‍♂' => 'umurinzi w’ umugabo: ibara ry’uruhu rwera',
    '💂🏼‍♂' => 'umurinzi w’ umugabo: ibara ry’uruhu rwera gahoro',
    '💂🏽‍♂' => 'umurinzi w’ umugabo: ibara ry’uruhu rw’inzobe',
    '💂🏾‍♂' => 'umurinzi w’ umugabo: ibara ry’uruhu rw’inzobe yirabura',
    '💂🏿‍♂' => 'umurinzi w’ umugabo: ibara ry’uruhu rwirabura',
    '💂🏻‍♀' => 'umurinzi w’ umugore: ibara ry’uruhu rwera',
    '💂🏼‍♀' => 'umurinzi w’ umugore: ibara ry’uruhu rwera gahoro',
    '💂🏽‍♀' => 'umurinzi w’ umugore: ibara ry’uruhu rw’inzobe',
    '💂🏾‍♀' => 'umurinzi w’ umugore: ibara ry’uruhu rw’inzobe yirabura',
    '💂🏿‍♀' => 'umurinzi w’ umugore: ibara ry’uruhu rwirabura',
    '👷🏻‍♂' => 'umufundi: ibara ry’uruhu rwera',
    '👷🏼‍♂' => 'umufundi: ibara ry’uruhu rwera gahoro',
    '👷🏽‍♂' => 'umufundi: ibara ry’uruhu rw’inzobe',
    '👷🏾‍♂' => 'umufundi: ibara ry’uruhu rw’inzobe yirabura',
    '👷🏿‍♂' => 'umufundi: ibara ry’uruhu rwirabura',
    '👷🏻‍♀' => 'umugore ukora mu bwubatsi: ibara ry’uruhu rwera',
    '👷🏼‍♀' => 'umugore ukora mu bwubatsi: ibara ry’uruhu rwera gahoro',
    '👷🏽‍♀' => 'umugore ukora mu bwubatsi: ibara ry’uruhu rw’inzobe',
    '👷🏾‍♀' => 'umugore ukora mu bwubatsi: ibara ry’uruhu rw’inzobe yirabura',
    '👷🏿‍♀' => 'umugore ukora mu bwubatsi: ibara ry’uruhu rwirabura',
    '👳🏻‍♂' => 'umugabo witeze igitambaro cyo mu mutwe: ibara ry’uruhu rwera',
    '👳🏼‍♂' => 'umugabo witeze igitambaro cyo mu mutwe: ibara ry’uruhu rwera gahoro',
    '👳🏽‍♂' => 'umugabo witeze igitambaro cyo mu mutwe: ibara ry’uruhu rw’inzobe',
    '👳🏾‍♂' => 'umugabo witeze igitambaro cyo mu mutwe: ibara ry’uruhu rw’inzobe yirabura',
    '👳🏿‍♂' => 'umugabo witeze igitambaro cyo mu mutwe: ibara ry’uruhu rwirabura',
    '👳🏻‍♀' => 'umugore witeze igitambaro cyo mu mutwe: ibara ry’uruhu rwera',
    '👳🏼‍♀' => 'umugore witeze igitambaro cyo mu mutwe: ibara ry’uruhu rwera gahoro',
    '👳🏽‍♀' => 'umugore witeze igitambaro cyo mu mutwe: ibara ry’uruhu rw’inzobe',
    '👳🏾‍♀' => 'umugore witeze igitambaro cyo mu mutwe: ibara ry’uruhu rw’inzobe yirabura',
    '👳🏿‍♀' => 'umugore witeze igitambaro cyo mu mutwe: ibara ry’uruhu rwirabura',
    '🧙🏻‍♂' => 'umumajigabo: ibara ry’uruhu rwera',
    '🧙🏼‍♂' => 'umumajigabo: ibara ry’uruhu rwera gahoro',
    '🧙🏽‍♂' => 'umumajigabo: ibara ry’uruhu rw’inzobe',
    '🧙🏾‍♂' => 'umumajigabo: ibara ry’uruhu rw’inzobe yirabura',
    '🧙🏿‍♂' => 'umumajigabo: ibara ry’uruhu rwirabura',
    '🧙🏻‍♀' => 'umumajikazi: ibara ry’uruhu rwera',
    '🧙🏼‍♀' => 'umumajikazi: ibara ry’uruhu rwera gahoro',
    '🧙🏽‍♀' => 'umumajikazi: ibara ry’uruhu rw’inzobe',
    '🧙🏾‍♀' => 'umumajikazi: ibara ry’uruhu rw’inzobe yirabura',
    '🧙🏿‍♀' => 'umumajikazi: ibara ry’uruhu rwirabura',
    '🧚🏻‍♂' => 'umuzimugabo: ibara ry’uruhu rwera',
    '🧚🏼‍♂' => 'umuzimugabo: ibara ry’uruhu rwera gahoro',
    '🧚🏽‍♂' => 'umuzimugabo: ibara ry’uruhu rw’inzobe',
    '🧚🏾‍♂' => 'umuzimugabo: ibara ry’uruhu rw’inzobe yirabura',
    '🧚🏿‍♂' => 'umuzimugabo: ibara ry’uruhu rwirabura',
    '🧚🏻‍♀' => 'umuzimukazi: ibara ry’uruhu rwera',
    '🧚🏼‍♀' => 'umuzimukazi: ibara ry’uruhu rwera gahoro',
    '🧚🏽‍♀' => 'umuzimukazi: ibara ry’uruhu rw’inzobe',
    '🧚🏾‍♀' => 'umuzimukazi: ibara ry’uruhu rw’inzobe yirabura',
    '🧚🏿‍♀' => 'umuzimukazi: ibara ry’uruhu rwirabura',
    '🧛🏻‍♂' => 'ivampayagabo: ibara ry’uruhu rwera',
    '🧛🏼‍♂' => 'ivampayagabo: ibara ry’uruhu rwera gahoro',
    '🧛🏽‍♂' => 'ivampayagabo: ibara ry’uruhu rw’inzobe',
    '🧛🏾‍♂' => 'ivampayagabo: ibara ry’uruhu rw’inzobe yirabura',
    '🧛🏿‍♂' => 'ivampayagabo: ibara ry’uruhu rwirabura',
    '🧛🏻‍♀' => 'ivampayakazi: ibara ry’uruhu rwera',
    '🧛🏼‍♀' => 'ivampayakazi: ibara ry’uruhu rwera gahoro',
    '🧛🏽‍♀' => 'ivampayakazi: ibara ry’uruhu rw’inzobe',
    '🧛🏾‍♀' => 'ivampayakazi: ibara ry’uruhu rw’inzobe yirabura',
    '🧛🏿‍♀' => 'ivampayakazi: ibara ry’uruhu rwirabura',
    '🧜🏻‍♂' => 'mugabosamaki: ibara ry’uruhu rwera',
    '🧜🏼‍♂' => 'mugabosamaki: ibara ry’uruhu rwera gahoro',
    '🧜🏽‍♂' => 'mugabosamaki: ibara ry’uruhu rw’inzobe',
    '🧜🏾‍♂' => 'mugabosamaki: ibara ry’uruhu rw’inzobe yirabura',
    '🧜🏿‍♂' => 'mugabosamaki: ibara ry’uruhu rwirabura',
    '🧜🏻‍♀' => 'makobwasamaki: ibara ry’uruhu rwera',
    '🧜🏼‍♀' => 'makobwasamaki: ibara ry’uruhu rwera gahoro',
    '🧜🏽‍♀' => 'makobwasamaki: ibara ry’uruhu rw’inzobe',
    '🧜🏾‍♀' => 'makobwasamaki: ibara ry’uruhu rw’inzobe yirabura',
    '🧜🏿‍♀' => 'makobwasamaki: ibara ry’uruhu rwirabura',
    '🧝🏻‍♂' => 'ishitanigabo: ibara ry’uruhu rwera',
    '🧝🏼‍♂' => 'ishitanigabo: ibara ry’uruhu rwera gahoro',
    '🧝🏽‍♂' => 'ishitanigabo: ibara ry’uruhu rw’inzobe',
    '🧝🏾‍♂' => 'ishitanigabo: ibara ry’uruhu rw’inzobe yirabura',
    '🧝🏿‍♂' => 'ishitanigabo: ibara ry’uruhu rwirabura',
    '🧝🏻‍♀' => 'ishitanikazi: ibara ry’uruhu rwera',
    '🧝🏼‍♀' => 'ishitanikazi: ibara ry’uruhu rwera gahoro',
    '🧝🏽‍♀' => 'ishitanikazi: ibara ry’uruhu rw’inzobe',
    '🧝🏾‍♀' => 'ishitanikazi: ibara ry’uruhu rw’inzobe yirabura',
    '🧝🏿‍♀' => 'ishitanikazi: ibara ry’uruhu rwirabura',
    '💆🏻‍♂' => 'umugabo wakirira ubutumwa: ibara ry’uruhu rwera',
    '💆🏼‍♂' => 'umugabo wakirira ubutumwa: ibara ry’uruhu rwera gahoro',
    '💆🏽‍♂' => 'umugabo wakirira ubutumwa: ibara ry’uruhu rw’inzobe',
    '💆🏾‍♂' => 'umugabo wakirira ubutumwa: ibara ry’uruhu rw’inzobe yirabura',
    '💆🏿‍♂' => 'umugabo wakirira ubutumwa: ibara ry’uruhu rwirabura',
    '💆🏻‍♀' => 'umugore wakirira ubutumwa: ibara ry’uruhu rwera',
    '💆🏼‍♀' => 'umugore wakirira ubutumwa: ibara ry’uruhu rwera gahoro',
    '💆🏽‍♀' => 'umugore wakirira ubutumwa: ibara ry’uruhu rw’inzobe',
    '💆🏾‍♀' => 'umugore wakirira ubutumwa: ibara ry’uruhu rw’inzobe yirabura',
    '💆🏿‍♀' => 'umugore wakirira ubutumwa: ibara ry’uruhu rwirabura',
    '💇🏻‍♂' => 'umugabo wiyogoshesha: ibara ry’uruhu rwera',
    '💇🏼‍♂' => 'umugabo wiyogoshesha: ibara ry’uruhu rwera gahoro',
    '💇🏽‍♂' => 'umugabo wiyogoshesha: ibara ry’uruhu rw’inzobe',
    '💇🏾‍♂' => 'umugabo wiyogoshesha: ibara ry’uruhu rw’inzobe yirabura',
    '💇🏿‍♂' => 'umugabo wiyogoshesha: ibara ry’uruhu rwirabura',
    '💇🏻‍♀' => 'umugore wiyogoshesha: ibara ry’uruhu rwera',
    '💇🏼‍♀' => 'umugore wiyogoshesha: ibara ry’uruhu rwera gahoro',
    '💇🏽‍♀' => 'umugore wiyogoshesha: ibara ry’uruhu rw’inzobe',
    '💇🏾‍♀' => 'umugore wiyogoshesha: ibara ry’uruhu rw’inzobe yirabura',
    '💇🏿‍♀' => 'umugore wiyogoshesha: ibara ry’uruhu rwirabura',
    '🚶🏻‍♂' => 'umugabo ugenda n’amaguru: ibara ry’uruhu rwera',
    '🚶🏼‍♂' => 'umugabo ugenda n’amaguru: ibara ry’uruhu rwera gahoro',
    '🚶🏽‍♂' => 'umugabo ugenda n’amaguru: ibara ry’uruhu rw’inzobe',
    '🚶🏾‍♂' => 'umugabo ugenda n’amaguru: ibara ry’uruhu rw’inzobe yirabura',
    '🚶🏿‍♂' => 'umugabo ugenda n’amaguru: ibara ry’uruhu rwirabura',
    '🚶🏻‍♀' => 'umugore ugenda n’amaguru: ibara ry’uruhu rwera',
    '🚶🏼‍♀' => 'umugore ugenda n’amaguru: ibara ry’uruhu rwera gahoro',
    '🚶🏽‍♀' => 'umugore ugenda n’amaguru: ibara ry’uruhu rw’inzobe',
    '🚶🏾‍♀' => 'umugore ugenda n’amaguru: ibara ry’uruhu rw’inzobe yirabura',
    '🚶🏿‍♀' => 'umugore ugenda n’amaguru: ibara ry’uruhu rwirabura',
    '🏃🏻‍♂' => 'umugabo wirukanka: ibara ry’uruhu rwera',
    '🏃🏼‍♂' => 'umugabo wirukanka: ibara ry’uruhu rwera gahoro',
    '🏃🏽‍♂' => 'umugabo wirukanka: ibara ry’uruhu rw’inzobe',
    '🏃🏾‍♂' => 'umugabo wirukanka: ibara ry’uruhu rw’inzobe yirabura',
    '🏃🏿‍♂' => 'umugabo wirukanka: ibara ry’uruhu rwirabura',
    '🏃🏻‍♀' => 'umugore wirukanka: ibara ry’uruhu rwera',
    '🏃🏼‍♀' => 'umugore wirukanka: ibara ry’uruhu rwera gahoro',
    '🏃🏽‍♀' => 'umugore wirukanka: ibara ry’uruhu rw’inzobe',
    '🏃🏾‍♀' => 'umugore wirukanka: ibara ry’uruhu rw’inzobe yirabura',
    '🏃🏿‍♀' => 'umugore wirukanka: ibara ry’uruhu rwirabura',
    '👯🏻‍♀' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera',
    '👯🏼‍♀' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera gahoro',
    '👯🏽‍♀' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe',
    '👯🏾‍♀' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe yirabura',
    '👯🏿‍♀' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwirabura',
    '👯🏻‍♂' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera',
    '👯🏼‍♂' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwera gahoro',
    '👯🏽‍♂' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe',
    '👯🏾‍♂' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rw’inzobe yirabura',
    '👯🏿‍♂' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru: ibara ry’uruhu rwirabura',
    '🧖🏻‍♂' => 'umugabo uri muri sawuna: ibara ry’uruhu rwera',
    '🧖🏼‍♂' => 'umugabo uri muri sawuna: ibara ry’uruhu rwera gahoro',
    '🧖🏽‍♂' => 'umugabo uri muri sawuna: ibara ry’uruhu rw’inzobe',
    '🧖🏾‍♂' => 'umugabo uri muri sawuna: ibara ry’uruhu rw’inzobe yirabura',
    '🧖🏿‍♂' => 'umugabo uri muri sawuna: ibara ry’uruhu rwirabura',
    '🧖🏻‍♀' => 'umugore uri muri sawuna: ibara ry’uruhu rwera',
    '🧖🏼‍♀' => 'umugore uri muri sawuna: ibara ry’uruhu rwera gahoro',
    '🧖🏽‍♀' => 'umugore uri muri sawuna: ibara ry’uruhu rw’inzobe',
    '🧖🏾‍♀' => 'umugore uri muri sawuna: ibara ry’uruhu rw’inzobe yirabura',
    '🧖🏿‍♀' => 'umugore uri muri sawuna: ibara ry’uruhu rwirabura',
    '🧗🏻‍♂' => 'umugabo wurira: ibara ry’uruhu rwera',
    '🧗🏼‍♂' => 'umugabo wurira: ibara ry’uruhu rwera gahoro',
    '🧗🏽‍♂' => 'umugabo wurira: ibara ry’uruhu rw’inzobe',
    '🧗🏾‍♂' => 'umugabo wurira: ibara ry’uruhu rw’inzobe yirabura',
    '🧗🏿‍♂' => 'umugabo wurira: ibara ry’uruhu rwirabura',
    '🧗🏻‍♀' => 'umugore wurira: ibara ry’uruhu rwera',
    '🧗🏼‍♀' => 'umugore wurira: ibara ry’uruhu rwera gahoro',
    '🧗🏽‍♀' => 'umugore wurira: ibara ry’uruhu rw’inzobe',
    '🧗🏾‍♀' => 'umugore wurira: ibara ry’uruhu rw’inzobe yirabura',
    '🧗🏿‍♀' => 'umugore wurira: ibara ry’uruhu rwirabura',
    '🏌🏻‍♂' => 'abagabo bakina golufe: ibara ry’uruhu rwera',
    '🏌🏼‍♂' => 'abagabo bakina golufe: ibara ry’uruhu rwera gahoro',
    '🏌🏽‍♂' => 'abagabo bakina golufe: ibara ry’uruhu rw’inzobe',
    '🏌🏾‍♂' => 'abagabo bakina golufe: ibara ry’uruhu rw’inzobe yirabura',
    '🏌🏿‍♂' => 'abagabo bakina golufe: ibara ry’uruhu rwirabura',
    '🏌🏻‍♀' => 'abagore bakina golufe: ibara ry’uruhu rwera',
    '🏌🏼‍♀' => 'abagore bakina golufe: ibara ry’uruhu rwera gahoro',
    '🏌🏽‍♀' => 'abagore bakina golufe: ibara ry’uruhu rw’inzobe',
    '🏌🏾‍♀' => 'abagore bakina golufe: ibara ry’uruhu rw’inzobe yirabura',
    '🏌🏿‍♀' => 'abagore bakina golufe: ibara ry’uruhu rwirabura',
    '🏄🏻‍♂' => 'umugabo winyereza ku mazi: ibara ry’uruhu rwera',
    '🏄🏼‍♂' => 'umugabo winyereza ku mazi: ibara ry’uruhu rwera gahoro',
    '🏄🏽‍♂' => 'umugabo winyereza ku mazi: ibara ry’uruhu rw’inzobe',
    '🏄🏾‍♂' => 'umugabo winyereza ku mazi: ibara ry’uruhu rw’inzobe yirabura',
    '🏄🏿‍♂' => 'umugabo winyereza ku mazi: ibara ry’uruhu rwirabura',
    '🏄🏻‍♀' => 'umugore winyereza ku mazi: ibara ry’uruhu rwera',
    '🏄🏼‍♀' => 'umugore winyereza ku mazi: ibara ry’uruhu rwera gahoro',
    '🏄🏽‍♀' => 'umugore winyereza ku mazi: ibara ry’uruhu rw’inzobe',
    '🏄🏾‍♀' => 'umugore winyereza ku mazi: ibara ry’uruhu rw’inzobe yirabura',
    '🏄🏿‍♀' => 'umugore winyereza ku mazi: ibara ry’uruhu rwirabura',
    '🚣🏻‍♂' => 'umugabo utwaye ubwato agashya: ibara ry’uruhu rwera',
    '🚣🏼‍♂' => 'umugabo utwaye ubwato agashya: ibara ry’uruhu rwera gahoro',
    '🚣🏽‍♂' => 'umugabo utwaye ubwato agashya: ibara ry’uruhu rw’inzobe',
    '🚣🏾‍♂' => 'umugabo utwaye ubwato agashya: ibara ry’uruhu rw’inzobe yirabura',
    '🚣🏿‍♂' => 'umugabo utwaye ubwato agashya: ibara ry’uruhu rwirabura',
    '🚣🏻‍♀' => 'umugore utwaye ubwato agashya: ibara ry’uruhu rwera',
    '🚣🏼‍♀' => 'umugore utwaye ubwato agashya: ibara ry’uruhu rwera gahoro',
    '🚣🏽‍♀' => 'umugore utwaye ubwato agashya: ibara ry’uruhu rw’inzobe',
    '🚣🏾‍♀' => 'umugore utwaye ubwato agashya: ibara ry’uruhu rw’inzobe yirabura',
    '🚣🏿‍♀' => 'umugore utwaye ubwato agashya: ibara ry’uruhu rwirabura',
    '🏊🏻‍♂' => 'umugabo uri koga: ibara ry’uruhu rwera',
    '🏊🏼‍♂' => 'umugabo uri koga: ibara ry’uruhu rwera gahoro',
    '🏊🏽‍♂' => 'umugabo uri koga: ibara ry’uruhu rw’inzobe',
    '🏊🏾‍♂' => 'umugabo uri koga: ibara ry’uruhu rw’inzobe yirabura',
    '🏊🏿‍♂' => 'umugabo uri koga: ibara ry’uruhu rwirabura',
    '🏊🏻‍♀' => 'umugore uri koga: ibara ry’uruhu rwera',
    '🏊🏼‍♀' => 'umugore uri koga: ibara ry’uruhu rwera gahoro',
    '🏊🏽‍♀' => 'umugore uri koga: ibara ry’uruhu rw’inzobe',
    '🏊🏾‍♀' => 'umugore uri koga: ibara ry’uruhu rw’inzobe yirabura',
    '🏊🏿‍♀' => 'umugore uri koga: ibara ry’uruhu rwirabura',
    '⛹🏻‍♂' => 'umugabo uri gutera umupira: ibara ry’uruhu rwera',
    '⛹🏼‍♂' => 'umugabo uri gutera umupira: ibara ry’uruhu rwera gahoro',
    '⛹🏽‍♂' => 'umugabo uri gutera umupira: ibara ry’uruhu rw’inzobe',
    '⛹🏾‍♂' => 'umugabo uri gutera umupira: ibara ry’uruhu rw’inzobe yirabura',
    '⛹🏿‍♂' => 'umugabo uri gutera umupira: ibara ry’uruhu rwirabura',
    '⛹🏻‍♀' => 'umugore uri gutera umupira: ibara ry’uruhu rwera',
    '⛹🏼‍♀' => 'umugore uri gutera umupira: ibara ry’uruhu rwera gahoro',
    '⛹🏽‍♀' => 'umugore uri gutera umupira: ibara ry’uruhu rw’inzobe',
    '⛹🏾‍♀' => 'umugore uri gutera umupira: ibara ry’uruhu rw’inzobe yirabura',
    '⛹🏿‍♀' => 'umugore uri gutera umupira: ibara ry’uruhu rwirabura',
    '🏋🏻‍♂' => 'umugabo uterura ibyuma: ibara ry’uruhu rwera',
    '🏋🏼‍♂' => 'umugabo uterura ibyuma: ibara ry’uruhu rwera gahoro',
    '🏋🏽‍♂' => 'umugabo uterura ibyuma: ibara ry’uruhu rw’inzobe',
    '🏋🏾‍♂' => 'umugabo uterura ibyuma: ibara ry’uruhu rw’inzobe yirabura',
    '🏋🏿‍♂' => 'umugabo uterura ibyuma: ibara ry’uruhu rwirabura',
    '🏋🏻‍♀' => 'umugore uterura ibyuma: ibara ry’uruhu rwera',
    '🏋🏼‍♀' => 'umugore uterura ibyuma: ibara ry’uruhu rwera gahoro',
    '🏋🏽‍♀' => 'umugore uterura ibyuma: ibara ry’uruhu rw’inzobe',
    '🏋🏾‍♀' => 'umugore uterura ibyuma: ibara ry’uruhu rw’inzobe yirabura',
    '🏋🏿‍♀' => 'umugore uterura ibyuma: ibara ry’uruhu rwirabura',
    '🚴🏻‍♂' => 'umugabo utwara igare: ibara ry’uruhu rwera',
    '🚴🏼‍♂' => 'umugabo utwara igare: ibara ry’uruhu rwera gahoro',
    '🚴🏽‍♂' => 'umugabo utwara igare: ibara ry’uruhu rw’inzobe',
    '🚴🏾‍♂' => 'umugabo utwara igare: ibara ry’uruhu rw’inzobe yirabura',
    '🚴🏿‍♂' => 'umugabo utwara igare: ibara ry’uruhu rwirabura',
    '🚴🏻‍♀' => 'umugore utwara igare: ibara ry’uruhu rwera',
    '🚴🏼‍♀' => 'umugore utwara igare: ibara ry’uruhu rwera gahoro',
    '🚴🏽‍♀' => 'umugore utwara igare: ibara ry’uruhu rw’inzobe',
    '🚴🏾‍♀' => 'umugore utwara igare: ibara ry’uruhu rw’inzobe yirabura',
    '🚴🏿‍♀' => 'umugore utwara igare: ibara ry’uruhu rwirabura',
    '🚵🏻‍♂' => 'umugabo utwara igare ku musozi: ibara ry’uruhu rwera',
    '🚵🏼‍♂' => 'umugabo utwara igare ku musozi: ibara ry’uruhu rwera gahoro',
    '🚵🏽‍♂' => 'umugabo utwara igare ku musozi: ibara ry’uruhu rw’inzobe',
    '🚵🏾‍♂' => 'umugabo utwara igare ku musozi: ibara ry’uruhu rw’inzobe yirabura',
    '🚵🏿‍♂' => 'umugabo utwara igare ku musozi: ibara ry’uruhu rwirabura',
    '🚵🏻‍♀' => 'umugore utwara igare ku musozi: ibara ry’uruhu rwera',
    '🚵🏼‍♀' => 'umugore utwara igare ku musozi: ibara ry’uruhu rwera gahoro',
    '🚵🏽‍♀' => 'umugore utwara igare ku musozi: ibara ry’uruhu rw’inzobe',
    '🚵🏾‍♀' => 'umugore utwara igare ku musozi: ibara ry’uruhu rw’inzobe yirabura',
    '🚵🏿‍♀' => 'umugore utwara igare ku musozi: ibara ry’uruhu rwirabura',
    '🤸🏻‍♂' => 'umugabo umangamanga: ibara ry’uruhu rwera',
    '🤸🏼‍♂' => 'umugabo umangamanga: ibara ry’uruhu rwera gahoro',
    '🤸🏽‍♂' => 'umugabo umangamanga: ibara ry’uruhu rw’inzobe',
    '🤸🏾‍♂' => 'umugabo umangamanga: ibara ry’uruhu rw’inzobe yirabura',
    '🤸🏿‍♂' => 'umugabo umangamanga: ibara ry’uruhu rwirabura',
    '🤸🏻‍♀' => 'umugore umangamanga: ibara ry’uruhu rwera',
    '🤸🏼‍♀' => 'umugore umangamanga: ibara ry’uruhu rwera gahoro',
    '🤸🏽‍♀' => 'umugore umangamanga: ibara ry’uruhu rw’inzobe',
    '🤸🏾‍♀' => 'umugore umangamanga: ibara ry’uruhu rw’inzobe yirabura',
    '🤸🏿‍♀' => 'umugore umangamanga: ibara ry’uruhu rwirabura',
    '🤼🏻‍♀' => 'abagore barushanwa: ibara ry’uruhu rwera',
    '🤼🏼‍♀' => 'abagore barushanwa: ibara ry’uruhu rwera gahoro',
    '🤼🏽‍♀' => 'abagore barushanwa: ibara ry’uruhu rw’inzobe',
    '🤼🏾‍♀' => 'abagore barushanwa: ibara ry’uruhu rw’inzobe yirabura',
    '🤼🏿‍♀' => 'abagore barushanwa: ibara ry’uruhu rwirabura',
    '🤼🏻‍♂' => 'abagabo barushanwa: ibara ry’uruhu rwera',
    '🤼🏼‍♂' => 'abagabo barushanwa: ibara ry’uruhu rwera gahoro',
    '🤼🏽‍♂' => 'abagabo barushanwa: ibara ry’uruhu rw’inzobe',
    '🤼🏾‍♂' => 'abagabo barushanwa: ibara ry’uruhu rw’inzobe yirabura',
    '🤼🏿‍♂' => 'abagabo barushanwa: ibara ry’uruhu rwirabura',
    '🤽🏻‍♂' => 'umugabo ukina umukino wa polo wo mu mazi: ibara ry’uruhu rwera',
    '🤽🏼‍♂' => 'umugabo ukina umukino wa polo wo mu mazi: ibara ry’uruhu rwera gahoro',
    '🤽🏽‍♂' => 'umugabo ukina umukino wa polo wo mu mazi: ibara ry’uruhu rw’inzobe',
    '🤽🏾‍♂' => 'umugabo ukina umukino wa polo wo mu mazi: ibara ry’uruhu rw’inzobe yirabura',
    '🤽🏿‍♂' => 'umugabo ukina umukino wa polo wo mu mazi: ibara ry’uruhu rwirabura',
    '🤽🏻‍♀' => 'umugore ukina umukino wa polo wo mu mazi: ibara ry’uruhu rwera',
    '🤽🏼‍♀' => 'umugore ukina umukino wa polo wo mu mazi: ibara ry’uruhu rwera gahoro',
    '🤽🏽‍♀' => 'umugore ukina umukino wa polo wo mu mazi: ibara ry’uruhu rw’inzobe',
    '🤽🏾‍♀' => 'umugore ukina umukino wa polo wo mu mazi: ibara ry’uruhu rw’inzobe yirabura',
    '🤽🏿‍♀' => 'umugore ukina umukino wa polo wo mu mazi: ibara ry’uruhu rwirabura',
    '🤾🏻‍♂' => 'umugabo ukina handibali: ibara ry’uruhu rwera',
    '🤾🏼‍♂' => 'umugabo ukina handibali: ibara ry’uruhu rwera gahoro',
    '🤾🏽‍♂' => 'umugabo ukina handibali: ibara ry’uruhu rw’inzobe',
    '🤾🏾‍♂' => 'umugabo ukina handibali: ibara ry’uruhu rw’inzobe yirabura',
    '🤾🏿‍♂' => 'umugabo ukina handibali: ibara ry’uruhu rwirabura',
    '🤾🏻‍♀' => 'umugore ukina handibali: ibara ry’uruhu rwera',
    '🤾🏼‍♀' => 'umugore ukina handibali: ibara ry’uruhu rwera gahoro',
    '🤾🏽‍♀' => 'umugore ukina handibali: ibara ry’uruhu rw’inzobe',
    '🤾🏾‍♀' => 'umugore ukina handibali: ibara ry’uruhu rw’inzobe yirabura',
    '🤾🏿‍♀' => 'umugore ukina handibali: ibara ry’uruhu rwirabura',
    '🤹🏻‍♂' => 'umugabo usama ajugunya hejuru: ibara ry’uruhu rwera',
    '🤹🏼‍♂' => 'umugabo usama ajugunya hejuru: ibara ry’uruhu rwera gahoro',
    '🤹🏽‍♂' => 'umugabo usama ajugunya hejuru: ibara ry’uruhu rw’inzobe',
    '🤹🏾‍♂' => 'umugabo usama ajugunya hejuru: ibara ry’uruhu rw’inzobe yirabura',
    '🤹🏿‍♂' => 'umugabo usama ajugunya hejuru: ibara ry’uruhu rwirabura',
    '🤹🏻‍♀' => 'umugore usama ajugunya hejuru: ibara ry’uruhu rwera',
    '🤹🏼‍♀' => 'umugore usama ajugunya hejuru: ibara ry’uruhu rwera gahoro',
    '🤹🏽‍♀' => 'umugore usama ajugunya hejuru: ibara ry’uruhu rw’inzobe',
    '🤹🏾‍♀' => 'umugore usama ajugunya hejuru: ibara ry’uruhu rw’inzobe yirabura',
    '🤹🏿‍♀' => 'umugore usama ajugunya hejuru: ibara ry’uruhu rwirabura',
    '🧘🏻‍♂' => 'umugabo wicaye ageretse akaguru ku kandi: ibara ry’uruhu rwera',
    '🧘🏼‍♂' => 'umugabo wicaye ageretse akaguru ku kandi: ibara ry’uruhu rwera gahoro',
    '🧘🏽‍♂' => 'umugabo wicaye ageretse akaguru ku kandi: ibara ry’uruhu rw’inzobe',
    '🧘🏾‍♂' => 'umugabo wicaye ageretse akaguru ku kandi: ibara ry’uruhu rw’inzobe yirabura',
    '🧘🏿‍♂' => 'umugabo wicaye ageretse akaguru ku kandi: ibara ry’uruhu rwirabura',
    '🧘🏻‍♀' => 'umugore wicaye ageretse akaguru ku kandi: ibara ry’uruhu rwera',
    '🧘🏼‍♀' => 'umugore wicaye ageretse akaguru ku kandi: ibara ry’uruhu rwera gahoro',
    '🧘🏽‍♀' => 'umugore wicaye ageretse akaguru ku kandi: ibara ry’uruhu rw’inzobe',
    '🧘🏾‍♀' => 'umugore wicaye ageretse akaguru ku kandi: ibara ry’uruhu rw’inzobe yirabura',
    '🧘🏿‍♀' => 'umugore wicaye ageretse akaguru ku kandi: ibara ry’uruhu rwirabura',
    '👨‍👦' => 'umuryango: umugabo, umuhungu',
    '👨‍👧' => 'umuryango: umugabo, umukobwa',
    '👩‍👦' => 'umuryango: umugore, umuhungu',
    '👩‍👧' => 'umuryango: umugore, umukobwa',
    '👁‍🗨' => 'ijisho riri mu kabaruni',
    '👱‍♂' => 'umugabo ufite imisatsi yera',
    '👱‍♀' => 'umugore ufite imisatsi yera',
    '🙍‍♂' => 'umugabo utishimye',
    '🙍‍♀' => 'umugore utishimye',
    '🙎‍♂' => 'umugabo urakaye',
    '🙎‍♀' => 'umugore urakaye',
    '🙅‍♂' => 'umugabo werekana ikimenyetso cya OYA',
    '🙅‍♀' => 'umugore werekana ikimenyetso cya OYA',
    '🙆‍♂' => 'umugabo werekana ikimenyetso cya Yego',
    '🙆‍♀' => 'umugore werekana ikimenyetso cya Yego',
    '💁‍♂' => 'umugabo uteze ikiganza',
    '💁‍♀' => 'umugore uteze ikiganza',
    '🙋‍♂' => 'umugabo uzamuye ikiganza',
    '🙋‍♀' => 'umugore uzamuye ikiganza',
    '🙇‍♂' => 'umugabo wunamye',
    '🙇‍♀' => 'umugore wunamye',
    '🤦‍♂' => 'umugabo ushyize ikiganza mu maso',
    '🤦‍♀' => 'umugore ushyize ikiganza mu maso',
    '🤷‍♂' => 'umugabo utigisa intugu',
    '🤷‍♀' => 'umugore utigisa intugu',
    '👨‍⚕' => 'umugabo muzima w’umukozi',
    '👩‍⚕' => 'umugore ukora mu by’ubuzima',
    '👨‍🎓' => 'umugabo w’umunyeshuri',
    '👩‍🎓' => 'umugore w’umunyeshuri',
    '👨‍🏫' => 'umugabo w’umwarimu',
    '👩‍🏫' => 'umwarimukazi',
    '👨‍⚖' => 'umugabo w’umucamanza',
    '👩‍⚖' => 'umugore w’umucamanza',
    '👨‍🌾' => 'umugabo w’umworozi',
    '👩‍🌾' => 'umworozikazi',
    '👨‍🍳' => 'umugabo w’umutetsi',
    '👩‍🍳' => 'umutetsikazi',
    '👨‍🔧' => 'umugabo w’umukanishi',
    '👩‍🔧' => 'umugore w’umukanishi',
    '👨‍🏭' => 'umugabo ukora mu ruganda',
    '👩‍🏭' => 'umugore ukora mu ruganda',
    '👨‍💼' => 'umugabo ukorera mu biro',
    '👩‍💼' => 'umugore ukorera mu biro',
    '👨‍🔬' => 'umugabo w’impuguke mu bya siyansi',
    '👩‍🔬' => 'impugukekazi mu bya siyansi',
    '👨‍💻' => 'umugabo w’impuguke mu by’ikoranabuhanga',
    '👩‍💻' => 'umugabo w’impuguke mu by’ikoranahanga',
    '👨‍🎤' => 'umugabo w’umuririmbyi',
    '👩‍🎤' => 'umuririmbyikazi',
    '👨‍🎨' => 'umugabo w’umunyabugeni',
    '👩‍🎨' => 'umunyabugenikazi',
    '👨‍✈' => 'umugabo w’umuderevu',
    '👩‍✈' => 'umupilotekazi',
    '👨‍🚀' => 'umugabo w’ impuguke mu by’ isanzure',
    '👩‍🚀' => 'umugore w’impuguke mu by’isanzure',
    '👨‍🚒' => 'umugabo uzimya umuriro',
    '👩‍🚒' => 'umugore uzimya umuriro',
    '👮‍♂' => 'umupolisi w’umugabo',
    '👮‍♀' => 'umupolisi w’umugore',
    '🕵‍♂' => 'umugenzuzi w’umugabo',
    '🕵‍♀' => 'umugenzuzi w’umugore',
    '💂‍♂' => 'umurinzi w’ umugabo',
    '💂‍♀' => 'umurinzi w’ umugore',
    '👷‍♂' => 'umufundi',
    '👷‍♀' => 'umugore ukora mu bwubatsi',
    '👳‍♂' => 'umugabo witeze igitambaro cyo mu mutwe',
    '👳‍♀' => 'umugore witeze igitambaro cyo mu mutwe',
    '🧙‍♂' => 'umumajigabo',
    '🧙‍♀' => 'umumajikazi',
    '🧚‍♂' => 'umuzimugabo',
    '🧚‍♀' => 'umuzimukazi',
    '🧛‍♂' => 'ivampayagabo',
    '🧛‍♀' => 'ivampayakazi',
    '🧜‍♂' => 'mugabosamaki',
    '🧜‍♀' => 'makobwasamaki',
    '🧝‍♂' => 'ishitanigabo',
    '🧝‍♀' => 'ishitanikazi',
    '🧞‍♂' => 'iginigabo',
    '🧞‍♀' => 'iginikazi',
    '🧟‍♂' => 'izombigabo',
    '🧟‍♀' => 'izombikazi',
    '💆‍♂' => 'umugabo wakirira ubutumwa',
    '💆‍♀' => 'umugore wakirira ubutumwa',
    '💇‍♂' => 'umugabo wiyogoshesha',
    '💇‍♀' => 'umugore wiyogoshesha',
    '🚶‍♂' => 'umugabo ugenda n’amaguru',
    '🚶‍♀' => 'umugore ugenda n’amaguru',
    '🏃‍♂' => 'umugabo wirukanka',
    '🏃‍♀' => 'umugore wirukanka',
    '👯‍♂' => 'abagabo bambaye amatwi y’urukwavu bakora umunsi mukuru',
    '👯‍♀' => 'abagore bambaye amatwi y’urukwavu bakora umunsi mukuru',
    '🧖‍♂' => 'umugabo uri muri sawuna',
    '🧖‍♀' => 'umugore uri muri sawuna',
    '🧗‍♂' => 'umugabo wurira',
    '🧗‍♀' => 'umugore wurira',
    '🏌‍♂' => 'abagabo bakina golufe',
    '🏌‍♀' => 'abagore bakina golufe',
    '🏄‍♂' => 'umugabo winyereza ku mazi',
    '🏄‍♀' => 'umugore winyereza ku mazi',
    '🚣‍♂' => 'umugabo utwaye ubwato agashya',
    '🚣‍♀' => 'umugore utwaye ubwato agashya',
    '🏊‍♂' => 'umugabo uri koga',
    '🏊‍♀' => 'umugore uri koga',
    '⛹‍♂' => 'umugabo uri gutera umupira',
    '⛹‍♀' => 'umugore uri gutera umupira',
    '🏋‍♂' => 'umugabo uterura ibyuma',
    '🏋‍♀' => 'umugore uterura ibyuma',
    '🚴‍♂' => 'umugabo utwara igare',
    '🚴‍♀' => 'umugore utwara igare',
    '🚵‍♂' => 'umugabo utwara igare ku musozi',
    '🚵‍♀' => 'umugore utwara igare ku musozi',
    '🤸‍♂' => 'umugabo umangamanga',
    '🤸‍♀' => 'umugore umangamanga',
    '🤼‍♂' => 'abagabo barushanwa',
    '🤼‍♀' => 'abagore barushanwa',
    '🤽‍♂' => 'umugabo ukina umukino wa polo wo mu mazi',
    '🤽‍♀' => 'umugore ukina umukino wa polo wo mu mazi',
    '🤾‍♂' => 'umugabo ukina handibali',
    '🤾‍♀' => 'umugore ukina handibali',
    '🤹‍♂' => 'umugabo usama ajugunya hejuru',
    '🤹‍♀' => 'umugore usama ajugunya hejuru',
    '🧘‍♂' => 'umugabo wicaye ageretse akaguru ku kandi',
    '🧘‍♀' => 'umugore wicaye ageretse akaguru ku kandi',
    '🏳‍🌈' => 'ibendera ry’amabara y’umukororombya',
    '👋🏻' => 'ikiganza gipepera: ibara ry’uruhu rwera',
    '👋🏼' => 'ikiganza gipepera: ibara ry’uruhu rwera gahoro',
    '👋🏽' => 'ikiganza gipepera: ibara ry’uruhu rw’inzobe',
    '👋🏾' => 'ikiganza gipepera: ibara ry’uruhu rw’inzobe yirabura',
    '👋🏿' => 'ikiganza gipepera: ibara ry’uruhu rwirabura',
    '🤚🏻' => 'inyuma y’ikiganza kizamuye: ibara ry’uruhu rwera',
    '🤚🏼' => 'inyuma y’ikiganza kizamuye: ibara ry’uruhu rwera gahoro',
    '🤚🏽' => 'inyuma y’ikiganza kizamuye: ibara ry’uruhu rw’inzobe',
    '🤚🏾' => 'inyuma y’ikiganza kizamuye: ibara ry’uruhu rw’inzobe yirabura',
    '🤚🏿' => 'inyuma y’ikiganza kizamuye: ibara ry’uruhu rwirabura',
    '🖐🏻' => 'ikiganza kizamuye intoki zitandukanyije: ibara ry’uruhu rwera',
    '🖐🏼' => 'ikiganza kizamuye intoki zitandukanyije: ibara ry’uruhu rwera gahoro',
    '🖐🏽' => 'ikiganza kizamuye intoki zitandukanyije: ibara ry’uruhu rw’inzobe',
    '🖐🏾' => 'ikiganza kizamuye intoki zitandukanyije: ibara ry’uruhu rw’inzobe yirabura',
    '🖐🏿' => 'ikiganza kizamuye intoki zitandukanyije: ibara ry’uruhu rwirabura',
    '✋🏻' => 'ikiganza kizamuye: ibara ry’uruhu rwera',
    '✋🏼' => 'ikiganza kizamuye: ibara ry’uruhu rwera gahoro',
    '✋🏽' => 'ikiganza kizamuye: ibara ry’uruhu rw’inzobe',
    '✋🏾' => 'ikiganza kizamuye: ibara ry’uruhu rw’inzobe yirabura',
    '✋🏿' => 'ikiganza kizamuye: ibara ry’uruhu rwirabura',
    '🖖🏻' => 'indamukanyo ya vulcan: ibara ry’uruhu rwera',
    '🖖🏼' => 'indamukanyo ya vulcan: ibara ry’uruhu rwera gahoro',
    '🖖🏽' => 'indamukanyo ya vulcan: ibara ry’uruhu rw’inzobe',
    '🖖🏾' => 'indamukanyo ya vulcan: ibara ry’uruhu rw’inzobe yirabura',
    '🖖🏿' => 'indamukanyo ya vulcan: ibara ry’uruhu rwirabura',
    '👌🏻' => 'ikiganza cyemeza: ibara ry’uruhu rwera',
    '👌🏼' => 'ikiganza cyemeza: ibara ry’uruhu rwera gahoro',
    '👌🏽' => 'ikiganza cyemeza: ibara ry’uruhu rw’inzobe',
    '👌🏾' => 'ikiganza cyemeza: ibara ry’uruhu rw’inzobe yirabura',
    '👌🏿' => 'ikiganza cyemeza: ibara ry’uruhu rwirabura',
    '✌🏻' => 'Ikiganza cy’intsinzi: ibara ry’uruhu rwera',
    '✌🏼' => 'Ikiganza cy’intsinzi: ibara ry’uruhu rwera gahoro',
    '✌🏽' => 'Ikiganza cy’intsinzi: ibara ry’uruhu rw’inzobe',
    '✌🏾' => 'Ikiganza cy’intsinzi: ibara ry’uruhu rw’inzobe yirabura',
    '✌🏿' => 'Ikiganza cy’intsinzi: ibara ry’uruhu rwirabura',
    '🤞🏻' => 'intoki zinyuranyemo: ibara ry’uruhu rwera',
    '🤞🏼' => 'intoki zinyuranyemo: ibara ry’uruhu rwera gahoro',
    '🤞🏽' => 'intoki zinyuranyemo: ibara ry’uruhu rw’inzobe',
    '🤞🏾' => 'intoki zinyuranyemo: ibara ry’uruhu rw’inzobe yirabura',
    '🤞🏿' => 'intoki zinyuranyemo: ibara ry’uruhu rwirabura',
    '🤟🏻' => 'ikimenyetso cya ndagukunda: ibara ry’uruhu rwera',
    '🤟🏼' => 'ikimenyetso cya ndagukunda: ibara ry’uruhu rwera gahoro',
    '🤟🏽' => 'ikimenyetso cya ndagukunda: ibara ry’uruhu rw’inzobe',
    '🤟🏾' => 'ikimenyetso cya ndagukunda: ibara ry’uruhu rw’inzobe yirabura',
    '🤟🏿' => 'ikimenyetso cya ndagukunda: ibara ry’uruhu rwirabura',
    '🤘🏻' => 'ikimenyetso cy’amahembe: ibara ry’uruhu rwera',
    '🤘🏼' => 'ikimenyetso cy’amahembe: ibara ry’uruhu rwera gahoro',
    '🤘🏽' => 'ikimenyetso cy’amahembe: ibara ry’uruhu rw’inzobe',
    '🤘🏾' => 'ikimenyetso cy’amahembe: ibara ry’uruhu rw’inzobe yirabura',
    '🤘🏿' => 'ikimenyetso cy’amahembe: ibara ry’uruhu rwirabura',
    '🤙🏻' => 'ikiganza gisaba guhamagarwa: ibara ry’uruhu rwera',
    '🤙🏼' => 'ikiganza gisaba guhamagarwa: ibara ry’uruhu rwera gahoro',
    '🤙🏽' => 'ikiganza gisaba guhamagarwa: ibara ry’uruhu rw’inzobe',
    '🤙🏾' => 'ikiganza gisaba guhamagarwa: ibara ry’uruhu rw’inzobe yirabura',
    '🤙🏿' => 'ikiganza gisaba guhamagarwa: ibara ry’uruhu rwirabura',
    '👈🏻' => 'urutoki rutunze ibumoso: ibara ry’uruhu rwera',
    '👈🏼' => 'urutoki rutunze ibumoso: ibara ry’uruhu rwera gahoro',
    '👈🏽' => 'urutoki rutunze ibumoso: ibara ry’uruhu rw’inzobe',
    '👈🏾' => 'urutoki rutunze ibumoso: ibara ry’uruhu rw’inzobe yirabura',
    '👈🏿' => 'urutoki rutunze ibumoso: ibara ry’uruhu rwirabura',
    '👉🏻' => 'urutoki rutunze iburyo: ibara ry’uruhu rwera',
    '👉🏼' => 'urutoki rutunze iburyo: ibara ry’uruhu rwera gahoro',
    '👉🏽' => 'urutoki rutunze iburyo: ibara ry’uruhu rw’inzobe',
    '👉🏾' => 'urutoki rutunze iburyo: ibara ry’uruhu rw’inzobe yirabura',
    '👉🏿' => 'urutoki rutunze iburyo: ibara ry’uruhu rwirabura',
    '👆🏻' => 'urutoki rutunze hejuru: ibara ry’uruhu rwera',
    '👆🏼' => 'urutoki rutunze hejuru: ibara ry’uruhu rwera gahoro',
    '👆🏽' => 'urutoki rutunze hejuru: ibara ry’uruhu rw’inzobe',
    '👆🏾' => 'urutoki rutunze hejuru: ibara ry’uruhu rw’inzobe yirabura',
    '👆🏿' => 'urutoki rutunze hejuru: ibara ry’uruhu rwirabura',
    '🖕🏻' => 'musumbazose: ibara ry’uruhu rwera',
    '🖕🏼' => 'musumbazose: ibara ry’uruhu rwera gahoro',
    '🖕🏽' => 'musumbazose: ibara ry’uruhu rw’inzobe',
    '🖕🏾' => 'musumbazose: ibara ry’uruhu rw’inzobe yirabura',
    '🖕🏿' => 'musumbazose: ibara ry’uruhu rwirabura',
    '👇🏻' => 'urutoki rutunze hasi: ibara ry’uruhu rwera',
    '👇🏼' => 'urutoki rutunze hasi: ibara ry’uruhu rwera gahoro',
    '👇🏽' => 'urutoki rutunze hasi: ibara ry’uruhu rw’inzobe',
    '👇🏾' => 'urutoki rutunze hasi: ibara ry’uruhu rw’inzobe yirabura',
    '👇🏿' => 'urutoki rutunze hasi: ibara ry’uruhu rwirabura',
    '☝🏻' => 'gutunga mukubitarukoko hejuru: ibara ry’uruhu rwera',
    '☝🏼' => 'gutunga mukubitarukoko hejuru: ibara ry’uruhu rwera gahoro',
    '☝🏽' => 'gutunga mukubitarukoko hejuru: ibara ry’uruhu rw’inzobe',
    '☝🏾' => 'gutunga mukubitarukoko hejuru: ibara ry’uruhu rw’inzobe yirabura',
    '☝🏿' => 'gutunga mukubitarukoko hejuru: ibara ry’uruhu rwirabura',
    '👍🏻' => 'ibikumwe bireba hejuru: ibara ry’uruhu rwera',
    '👍🏼' => 'ibikumwe bireba hejuru: ibara ry’uruhu rwera gahoro',
    '👍🏽' => 'ibikumwe bireba hejuru: ibara ry’uruhu rw’inzobe',
    '👍🏾' => 'ibikumwe bireba hejuru: ibara ry’uruhu rw’inzobe yirabura',
    '👍🏿' => 'ibikumwe bireba hejuru: ibara ry’uruhu rwirabura',
    '👎🏻' => 'ibikumwe bireba hasi: ibara ry’uruhu rwera',
    '👎🏼' => 'ibikumwe bireba hasi: ibara ry’uruhu rwera gahoro',
    '👎🏽' => 'ibikumwe bireba hasi: ibara ry’uruhu rw’inzobe',
    '👎🏾' => 'ibikumwe bireba hasi: ibara ry’uruhu rw’inzobe yirabura',
    '👎🏿' => 'ibikumwe bireba hasi: ibara ry’uruhu rwirabura',
    '✊🏻' => 'igipfunsi kizamuye: ibara ry’uruhu rwera',
    '✊🏼' => 'igipfunsi kizamuye: ibara ry’uruhu rwera gahoro',
    '✊🏽' => 'igipfunsi kizamuye: ibara ry’uruhu rw’inzobe',
    '✊🏾' => 'igipfunsi kizamuye: ibara ry’uruhu rw’inzobe yirabura',
    '✊🏿' => 'igipfunsi kizamuye: ibara ry’uruhu rwirabura',
    '👊🏻' => 'igipfunsi kikureba: ibara ry’uruhu rwera',
    '👊🏼' => 'igipfunsi kikureba: ibara ry’uruhu rwera gahoro',
    '👊🏽' => 'igipfunsi kikureba: ibara ry’uruhu rw’inzobe',
    '👊🏾' => 'igipfunsi kikureba: ibara ry’uruhu rw’inzobe yirabura',
    '👊🏿' => 'igipfunsi kikureba: ibara ry’uruhu rwirabura',
    '🤛🏻' => 'igipfunsi kireba ibumoso: ibara ry’uruhu rwera',
    '🤛🏼' => 'igipfunsi kireba ibumoso: ibara ry’uruhu rwera gahoro',
    '🤛🏽' => 'igipfunsi kireba ibumoso: ibara ry’uruhu rw’inzobe',
    '🤛🏾' => 'igipfunsi kireba ibumoso: ibara ry’uruhu rw’inzobe yirabura',
    '🤛🏿' => 'igipfunsi kireba ibumoso: ibara ry’uruhu rwirabura',
    '🤜🏻' => 'igipfunsi kireba iburyo: ibara ry’uruhu rwera',
    '🤜🏼' => 'igipfunsi kireba iburyo: ibara ry’uruhu rwera gahoro',
    '🤜🏽' => 'igipfunsi kireba iburyo: ibara ry’uruhu rw’inzobe',
    '🤜🏾' => 'igipfunsi kireba iburyo: ibara ry’uruhu rw’inzobe yirabura',
    '🤜🏿' => 'igipfunsi kireba iburyo: ibara ry’uruhu rwirabura',
    '👏🏻' => 'ibiganza bikoma amashyi: ibara ry’uruhu rwera',
    '👏🏼' => 'ibiganza bikoma amashyi: ibara ry’uruhu rwera gahoro',
    '👏🏽' => 'ibiganza bikoma amashyi: ibara ry’uruhu rw’inzobe',
    '👏🏾' => 'ibiganza bikoma amashyi: ibara ry’uruhu rw’inzobe yirabura',
    '👏🏿' => 'ibiganza bikoma amashyi: ibara ry’uruhu rwirabura',
    '🙌🏻' => 'ibiganza bizamuye: ibara ry’uruhu rwera',
    '🙌🏼' => 'ibiganza bizamuye: ibara ry’uruhu rwera gahoro',
    '🙌🏽' => 'ibiganza bizamuye: ibara ry’uruhu rw’inzobe',
    '🙌🏾' => 'ibiganza bizamuye: ibara ry’uruhu rw’inzobe yirabura',
    '🙌🏿' => 'ibiganza bizamuye: ibara ry’uruhu rwirabura',
    '👐🏻' => 'ikimenyetso cy’ibiganza bibumbuye: ibara ry’uruhu rwera',
    '👐🏼' => 'ikimenyetso cy’ibiganza bibumbuye: ibara ry’uruhu rwera gahoro',
    '👐🏽' => 'ikimenyetso cy’ibiganza bibumbuye: ibara ry’uruhu rw’inzobe',
    '👐🏾' => 'ikimenyetso cy’ibiganza bibumbuye: ibara ry’uruhu rw’inzobe yirabura',
    '👐🏿' => 'ikimenyetso cy’ibiganza bibumbuye: ibara ry’uruhu rwirabura',
    '🤲🏻' => 'ibiganza byombi hejuru: ibara ry’uruhu rwera',
    '🤲🏼' => 'ibiganza byombi hejuru: ibara ry’uruhu rwera gahoro',
    '🤲🏽' => 'ibiganza byombi hejuru: ibara ry’uruhu rw’inzobe',
    '🤲🏾' => 'ibiganza byombi hejuru: ibara ry’uruhu rw’inzobe yirabura',
    '🤲🏿' => 'ibiganza byombi hejuru: ibara ry’uruhu rwirabura',
    '🤝🏻' => 'gusuhuzanya: ibara ry’uruhu rwera',
    '🤝🏼' => 'gusuhuzanya: ibara ry’uruhu rwera gahoro',
    '🤝🏽' => 'gusuhuzanya: ibara ry’uruhu rw’inzobe',
    '🤝🏾' => 'gusuhuzanya: ibara ry’uruhu rw’inzobe yirabura',
    '🤝🏿' => 'gusuhuzanya: ibara ry’uruhu rwirabura',
    '🙏🏻' => 'ibiganza bifatanye: ibara ry’uruhu rwera',
    '🙏🏼' => 'ibiganza bifatanye: ibara ry’uruhu rwera gahoro',
    '🙏🏽' => 'ibiganza bifatanye: ibara ry’uruhu rw’inzobe',
    '🙏🏾' => 'ibiganza bifatanye: ibara ry’uruhu rw’inzobe yirabura',
    '🙏🏿' => 'ibiganza bifatanye: ibara ry’uruhu rwirabura',
    '✍🏻' => 'ikiganza cyandika: ibara ry’uruhu rwera',
    '✍🏼' => 'ikiganza cyandika: ibara ry’uruhu rwera gahoro',
    '✍🏽' => 'ikiganza cyandika: ibara ry’uruhu rw’inzobe',
    '✍🏾' => 'ikiganza cyandika: ibara ry’uruhu rw’inzobe yirabura',
    '✍🏿' => 'ikiganza cyandika: ibara ry’uruhu rwirabura',
    '💅🏻' => 'verini y’inzara: ibara ry’uruhu rwera',
    '💅🏼' => 'verini y’inzara: ibara ry’uruhu rwera gahoro',
    '💅🏽' => 'verini y’inzara: ibara ry’uruhu rw’inzobe',
    '💅🏾' => 'verini y’inzara: ibara ry’uruhu rw’inzobe yirabura',
    '💅🏿' => 'verini y’inzara: ibara ry’uruhu rwirabura',
    '🤳🏻' => 'serifi: ibara ry’uruhu rwera',
    '🤳🏼' => 'serifi: ibara ry’uruhu rwera gahoro',
    '🤳🏽' => 'serifi: ibara ry’uruhu rw’inzobe',
    '🤳🏾' => 'serifi: ibara ry’uruhu rw’inzobe yirabura',
    '🤳🏿' => 'serifi: ibara ry’uruhu rwirabura',
    '💪🏻' => 'amaboko ahinnye: ibara ry’uruhu rwera',
    '💪🏼' => 'amaboko ahinnye: ibara ry’uruhu rwera gahoro',
    '💪🏽' => 'amaboko ahinnye: ibara ry’uruhu rw’inzobe',
    '💪🏾' => 'amaboko ahinnye: ibara ry’uruhu rw’inzobe yirabura',
    '💪🏿' => 'amaboko ahinnye: ibara ry’uruhu rwirabura',
    '👂🏻' => 'ugutwi: ibara ry’uruhu rwera',
    '👂🏼' => 'ugutwi: ibara ry’uruhu rwera gahoro',
    '👂🏽' => 'ugutwi: ibara ry’uruhu rw’inzobe',
    '👂🏾' => 'ugutwi: ibara ry’uruhu rw’inzobe yirabura',
    '👂🏿' => 'ugutwi: ibara ry’uruhu rwirabura',
    '👃🏻' => 'izuru: ibara ry’uruhu rwera',
    '👃🏼' => 'izuru: ibara ry’uruhu rwera gahoro',
    '👃🏽' => 'izuru: ibara ry’uruhu rw’inzobe',
    '👃🏾' => 'izuru: ibara ry’uruhu rw’inzobe yirabura',
    '👃🏿' => 'izuru: ibara ry’uruhu rwirabura',
    '👶🏻' => 'uruhinja: ibara ry’uruhu rwera',
    '👶🏼' => 'uruhinja: ibara ry’uruhu rwera gahoro',
    '👶🏽' => 'uruhinja: ibara ry’uruhu rw’inzobe',
    '👶🏾' => 'uruhinja: ibara ry’uruhu rw’inzobe yirabura',
    '👶🏿' => 'uruhinja: ibara ry’uruhu rwirabura',
    '🧒🏻' => 'umwana: ibara ry’uruhu rwera',
    '🧒🏼' => 'umwana: ibara ry’uruhu rwera gahoro',
    '🧒🏽' => 'umwana: ibara ry’uruhu rw’inzobe',
    '🧒🏾' => 'umwana: ibara ry’uruhu rw’inzobe yirabura',
    '🧒🏿' => 'umwana: ibara ry’uruhu rwirabura',
    '👦🏻' => 'umuhungu: ibara ry’uruhu rwera',
    '👦🏼' => 'umuhungu: ibara ry’uruhu rwera gahoro',
    '👦🏽' => 'umuhungu: ibara ry’uruhu rw’inzobe',
    '👦🏾' => 'umuhungu: ibara ry’uruhu rw’inzobe yirabura',
    '👦🏿' => 'umuhungu: ibara ry’uruhu rwirabura',
    '👧🏻' => 'umukobwa: ibara ry’uruhu rwera',
    '👧🏼' => 'umukobwa: ibara ry’uruhu rwera gahoro',
    '👧🏽' => 'umukobwa: ibara ry’uruhu rw’inzobe',
    '👧🏾' => 'umukobwa: ibara ry’uruhu rw’inzobe yirabura',
    '👧🏿' => 'umukobwa: ibara ry’uruhu rwirabura',
    '🧑🏻' => 'umuntu mukuru: ibara ry’uruhu rwera',
    '🧑🏼' => 'umuntu mukuru: ibara ry’uruhu rwera gahoro',
    '🧑🏽' => 'umuntu mukuru: ibara ry’uruhu rw’inzobe',
    '🧑🏾' => 'umuntu mukuru: ibara ry’uruhu rw’inzobe yirabura',
    '🧑🏿' => 'umuntu mukuru: ibara ry’uruhu rwirabura',
    '👱🏻' => 'umuntu ufite imisatsi y’umweru: ibara ry’uruhu rwera',
    '👱🏼' => 'umuntu ufite imisatsi y’umweru: ibara ry’uruhu rwera gahoro',
    '👱🏽' => 'umuntu ufite imisatsi y’umweru: ibara ry’uruhu rw’inzobe',
    '👱🏾' => 'umuntu ufite imisatsi y’umweru: ibara ry’uruhu rw’inzobe yirabura',
    '👱🏿' => 'umuntu ufite imisatsi y’umweru: ibara ry’uruhu rwirabura',
    '👨🏻' => 'umugabo: ibara ry’uruhu rwera',
    '👨🏼' => 'umugabo: ibara ry’uruhu rwera gahoro',
    '👨🏽' => 'umugabo: ibara ry’uruhu rw’inzobe',
    '👨🏾' => 'umugabo: ibara ry’uruhu rw’inzobe yirabura',
    '👨🏿' => 'umugabo: ibara ry’uruhu rwirabura',
    '🧔🏻' => 'umuntu ufite ubwanwa: ibara ry’uruhu rwera',
    '🧔🏼' => 'umuntu ufite ubwanwa: ibara ry’uruhu rwera gahoro',
    '🧔🏽' => 'umuntu ufite ubwanwa: ibara ry’uruhu rw’inzobe',
    '🧔🏾' => 'umuntu ufite ubwanwa: ibara ry’uruhu rw’inzobe yirabura',
    '🧔🏿' => 'umuntu ufite ubwanwa: ibara ry’uruhu rwirabura',
    '👩🏻' => 'umugore: ibara ry’uruhu rwera',
    '👩🏼' => 'umugore: ibara ry’uruhu rwera gahoro',
    '👩🏽' => 'umugore: ibara ry’uruhu rw’inzobe',
    '👩🏾' => 'umugore: ibara ry’uruhu rw’inzobe yirabura',
    '👩🏿' => 'umugore: ibara ry’uruhu rwirabura',
    '🧓🏻' => 'umuntu mukuru ushaje: ibara ry’uruhu rwera',
    '🧓🏼' => 'umuntu mukuru ushaje: ibara ry’uruhu rwera gahoro',
    '🧓🏽' => 'umuntu mukuru ushaje: ibara ry’uruhu rw’inzobe',
    '🧓🏾' => 'umuntu mukuru ushaje: ibara ry’uruhu rw’inzobe yirabura',
    '🧓🏿' => 'umuntu mukuru ushaje: ibara ry’uruhu rwirabura',
    '👴🏻' => 'umusaza: ibara ry’uruhu rwera',
    '👴🏼' => 'umusaza: ibara ry’uruhu rwera gahoro',
    '👴🏽' => 'umusaza: ibara ry’uruhu rw’inzobe',
    '👴🏾' => 'umusaza: ibara ry’uruhu rw’inzobe yirabura',
    '👴🏿' => 'umusaza: ibara ry’uruhu rwirabura',
    '👵🏻' => 'umukecuru: ibara ry’uruhu rwera',
    '👵🏼' => 'umukecuru: ibara ry’uruhu rwera gahoro',
    '👵🏽' => 'umukecuru: ibara ry’uruhu rw’inzobe',
    '👵🏾' => 'umukecuru: ibara ry’uruhu rw’inzobe yirabura',
    '👵🏿' => 'umukecuru: ibara ry’uruhu rwirabura',
    '🙍🏻' => 'umuntu utishimye: ibara ry’uruhu rwera',
    '🙍🏼' => 'umuntu utishimye: ibara ry’uruhu rwera gahoro',
    '🙍🏽' => 'umuntu utishimye: ibara ry’uruhu rw’inzobe',
    '🙍🏾' => 'umuntu utishimye: ibara ry’uruhu rw’inzobe yirabura',
    '🙍🏿' => 'umuntu utishimye: ibara ry’uruhu rwirabura',
    '🙎🏻' => 'umuntu uhakana: ibara ry’uruhu rwera',
    '🙎🏼' => 'umuntu uhakana: ibara ry’uruhu rwera gahoro',
    '🙎🏽' => 'umuntu uhakana: ibara ry’uruhu rw’inzobe',
    '🙎🏾' => 'umuntu uhakana: ibara ry’uruhu rw’inzobe yirabura',
    '🙎🏿' => 'umuntu uhakana: ibara ry’uruhu rwirabura',
    '🙅🏻' => 'umuntu ugaragaza OYA: ibara ry’uruhu rwera',
    '🙅🏼' => 'umuntu ugaragaza OYA: ibara ry’uruhu rwera gahoro',
    '🙅🏽' => 'umuntu ugaragaza OYA: ibara ry’uruhu rw’inzobe',
    '🙅🏾' => 'umuntu ugaragaza OYA: ibara ry’uruhu rw’inzobe yirabura',
    '🙅🏿' => 'umuntu ugaragaza OYA: ibara ry’uruhu rwirabura',
    '🙆🏻' => 'umuntu ugaragaza Yego: ibara ry’uruhu rwera',
    '🙆🏼' => 'umuntu ugaragaza Yego: ibara ry’uruhu rwera gahoro',
    '🙆🏽' => 'umuntu ugaragaza Yego: ibara ry’uruhu rw’inzobe',
    '🙆🏾' => 'umuntu ugaragaza Yego: ibara ry’uruhu rw’inzobe yirabura',
    '🙆🏿' => 'umuntu ugaragaza Yego: ibara ry’uruhu rwirabura',
    '💁🏻' => 'umuntu wazamuye urutoki: ibara ry’uruhu rwera',
    '💁🏼' => 'umuntu wazamuye urutoki: ibara ry’uruhu rwera gahoro',
    '💁🏽' => 'umuntu wazamuye urutoki: ibara ry’uruhu rw’inzobe',
    '💁🏾' => 'umuntu wazamuye urutoki: ibara ry’uruhu rw’inzobe yirabura',
    '💁🏿' => 'umuntu wazamuye urutoki: ibara ry’uruhu rwirabura',
    '🙋🏻' => 'umuntu wazamuye ikiganza: ibara ry’uruhu rwera',
    '🙋🏼' => 'umuntu wazamuye ikiganza: ibara ry’uruhu rwera gahoro',
    '🙋🏽' => 'umuntu wazamuye ikiganza: ibara ry’uruhu rw’inzobe',
    '🙋🏾' => 'umuntu wazamuye ikiganza: ibara ry’uruhu rw’inzobe yirabura',
    '🙋🏿' => 'umuntu wazamuye ikiganza: ibara ry’uruhu rwirabura',
    '🙇🏻' => 'umuntu wunamye: ibara ry’uruhu rwera',
    '🙇🏼' => 'umuntu wunamye: ibara ry’uruhu rwera gahoro',
    '🙇🏽' => 'umuntu wunamye: ibara ry’uruhu rw’inzobe',
    '🙇🏾' => 'umuntu wunamye: ibara ry’uruhu rw’inzobe yirabura',
    '🙇🏿' => 'umuntu wunamye: ibara ry’uruhu rwirabura',
    '🤦🏻' => 'umuntu wifash mu maso: ibara ry’uruhu rwera',
    '🤦🏼' => 'umuntu wifash mu maso: ibara ry’uruhu rwera gahoro',
    '🤦🏽' => 'umuntu wifash mu maso: ibara ry’uruhu rw’inzobe',
    '🤦🏾' => 'umuntu wifash mu maso: ibara ry’uruhu rw’inzobe yirabura',
    '🤦🏿' => 'umuntu wifash mu maso: ibara ry’uruhu rwirabura',
    '🤷🏻' => 'umuntu wazamuye intugu: ibara ry’uruhu rwera',
    '🤷🏼' => 'umuntu wazamuye intugu: ibara ry’uruhu rwera gahoro',
    '🤷🏽' => 'umuntu wazamuye intugu: ibara ry’uruhu rw’inzobe',
    '🤷🏾' => 'umuntu wazamuye intugu: ibara ry’uruhu rw’inzobe yirabura',
    '🤷🏿' => 'umuntu wazamuye intugu: ibara ry’uruhu rwirabura',
    '👮🏻' => 'umupolisi: ibara ry’uruhu rwera',
    '👮🏼' => 'umupolisi: ibara ry’uruhu rwera gahoro',
    '👮🏽' => 'umupolisi: ibara ry’uruhu rw’inzobe',
    '👮🏾' => 'umupolisi: ibara ry’uruhu rw’inzobe yirabura',
    '👮🏿' => 'umupolisi: ibara ry’uruhu rwirabura',
    '🕵🏻' => 'umugenzuzi: ibara ry’uruhu rwera',
    '🕵🏼' => 'umugenzuzi: ibara ry’uruhu rwera gahoro',
    '🕵🏽' => 'umugenzuzi: ibara ry’uruhu rw’inzobe',
    '🕵🏾' => 'umugenzuzi: ibara ry’uruhu rw’inzobe yirabura',
    '🕵🏿' => 'umugenzuzi: ibara ry’uruhu rwirabura',
    '💂🏻' => 'umusuruveya: ibara ry’uruhu rwera',
    '💂🏼' => 'umusuruveya: ibara ry’uruhu rwera gahoro',
    '💂🏽' => 'umusuruveya: ibara ry’uruhu rw’inzobe',
    '💂🏾' => 'umusuruveya: ibara ry’uruhu rw’inzobe yirabura',
    '💂🏿' => 'umusuruveya: ibara ry’uruhu rwirabura',
    '👷🏻' => 'umwubatsi: ibara ry’uruhu rwera',
    '👷🏼' => 'umwubatsi: ibara ry’uruhu rwera gahoro',
    '👷🏽' => 'umwubatsi: ibara ry’uruhu rw’inzobe',
    '👷🏾' => 'umwubatsi: ibara ry’uruhu rw’inzobe yirabura',
    '👷🏿' => 'umwubatsi: ibara ry’uruhu rwirabura',
    '🤴🏻' => 'igikomangoma: ibara ry’uruhu rwera',
    '🤴🏼' => 'igikomangoma: ibara ry’uruhu rwera gahoro',
    '🤴🏽' => 'igikomangoma: ibara ry’uruhu rw’inzobe',
    '🤴🏾' => 'igikomangoma: ibara ry’uruhu rw’inzobe yirabura',
    '🤴🏿' => 'igikomangoma: ibara ry’uruhu rwirabura',
    '👸🏻' => 'igikomangomakazi: ibara ry’uruhu rwera',
    '👸🏼' => 'igikomangomakazi: ibara ry’uruhu rwera gahoro',
    '👸🏽' => 'igikomangomakazi: ibara ry’uruhu rw’inzobe',
    '👸🏾' => 'igikomangomakazi: ibara ry’uruhu rw’inzobe yirabura',
    '👸🏿' => 'igikomangomakazi: ibara ry’uruhu rwirabura',
    '👳🏻' => 'umuntu witandiye: ibara ry’uruhu rwera',
    '👳🏼' => 'umuntu witandiye: ibara ry’uruhu rwera gahoro',
    '👳🏽' => 'umuntu witandiye: ibara ry’uruhu rw’inzobe',
    '👳🏾' => 'umuntu witandiye: ibara ry’uruhu rw’inzobe yirabura',
    '👳🏿' => 'umuntu witandiye: ibara ry’uruhu rwirabura',
    '👲🏻' => 'umuntu wambaye ingofero y’abashinwa: ibara ry’uruhu rwera',
    '👲🏼' => 'umuntu wambaye ingofero y’abashinwa: ibara ry’uruhu rwera gahoro',
    '👲🏽' => 'umuntu wambaye ingofero y’abashinwa: ibara ry’uruhu rw’inzobe',
    '👲🏾' => 'umuntu wambaye ingofero y’abashinwa: ibara ry’uruhu rw’inzobe yirabura',
    '👲🏿' => 'umuntu wambaye ingofero y’abashinwa: ibara ry’uruhu rwirabura',
    '🧕🏻' => 'umugore wambaye igitambaro cyo mu mutwe: ibara ry’uruhu rwera',
    '🧕🏼' => 'umugore wambaye igitambaro cyo mu mutwe: ibara ry’uruhu rwera gahoro',
    '🧕🏽' => 'umugore wambaye igitambaro cyo mu mutwe: ibara ry’uruhu rw’inzobe',
    '🧕🏾' => 'umugore wambaye igitambaro cyo mu mutwe: ibara ry’uruhu rw’inzobe yirabura',
    '🧕🏿' => 'umugore wambaye igitambaro cyo mu mutwe: ibara ry’uruhu rwirabura',
    '🤵🏻' => 'umugabo wambaye ikoti: ibara ry’uruhu rwera',
    '🤵🏼' => 'umugabo wambaye ikoti: ibara ry’uruhu rwera gahoro',
    '🤵🏽' => 'umugabo wambaye ikoti: ibara ry’uruhu rw’inzobe',
    '🤵🏾' => 'umugabo wambaye ikoti: ibara ry’uruhu rw’inzobe yirabura',
    '🤵🏿' => 'umugabo wambaye ikoti: ibara ry’uruhu rwirabura',
    '👰🏻' => 'umugeni wambaye ivara: ibara ry’uruhu rwera',
    '👰🏼' => 'umugeni wambaye ivara: ibara ry’uruhu rwera gahoro',
    '👰🏽' => 'umugeni wambaye ivara: ibara ry’uruhu rw’inzobe',
    '👰🏾' => 'umugeni wambaye ivara: ibara ry’uruhu rw’inzobe yirabura',
    '👰🏿' => 'umugeni wambaye ivara: ibara ry’uruhu rwirabura',
    '🤰🏻' => 'umugore utwite: ibara ry’uruhu rwera',
    '🤰🏼' => 'umugore utwite: ibara ry’uruhu rwera gahoro',
    '🤰🏽' => 'umugore utwite: ibara ry’uruhu rw’inzobe',
    '🤰🏾' => 'umugore utwite: ibara ry’uruhu rw’inzobe yirabura',
    '🤰🏿' => 'umugore utwite: ibara ry’uruhu rwirabura',
    '🤱🏻' => 'konsa: ibara ry’uruhu rwera',
    '🤱🏼' => 'konsa: ibara ry’uruhu rwera gahoro',
    '🤱🏽' => 'konsa: ibara ry’uruhu rw’inzobe',
    '🤱🏾' => 'konsa: ibara ry’uruhu rw’inzobe yirabura',
    '🤱🏿' => 'konsa: ibara ry’uruhu rwirabura',
    '👼🏻' => 'akamalayika: ibara ry’uruhu rwera',
    '👼🏼' => 'akamalayika: ibara ry’uruhu rwera gahoro',
    '👼🏽' => 'akamalayika: ibara ry’uruhu rw’inzobe',
    '👼🏾' => 'akamalayika: ibara ry’uruhu rw’inzobe yirabura',
    '👼🏿' => 'akamalayika: ibara ry’uruhu rwirabura',
    '🎅🏻' => 'Papa Noheli: ibara ry’uruhu rwera',
    '🎅🏼' => 'Papa Noheli: ibara ry’uruhu rwera gahoro',
    '🎅🏽' => 'Papa Noheli: ibara ry’uruhu rw’inzobe',
    '🎅🏾' => 'Papa Noheli: ibara ry’uruhu rw’inzobe yirabura',
    '🎅🏿' => 'Papa Noheli: ibara ry’uruhu rwirabura',
    '🤶🏻' => 'Mama Noheli: ibara ry’uruhu rwera',
    '🤶🏼' => 'Mama Noheli: ibara ry’uruhu rwera gahoro',
    '🤶🏽' => 'Mama Noheli: ibara ry’uruhu rw’inzobe',
    '🤶🏾' => 'Mama Noheli: ibara ry’uruhu rw’inzobe yirabura',
    '🤶🏿' => 'Mama Noheli: ibara ry’uruhu rwirabura',
    '🧙🏻' => 'umumaji: ibara ry’uruhu rwera',
    '🧙🏼' => 'umumaji: ibara ry’uruhu rwera gahoro',
    '🧙🏽' => 'umumaji: ibara ry’uruhu rw’inzobe',
    '🧙🏾' => 'umumaji: ibara ry’uruhu rw’inzobe yirabura',
    '🧙🏿' => 'umumaji: ibara ry’uruhu rwirabura',
    '🧚🏻' => 'umuzimu: ibara ry’uruhu rwera',
    '🧚🏼' => 'umuzimu: ibara ry’uruhu rwera gahoro',
    '🧚🏽' => 'umuzimu: ibara ry’uruhu rw’inzobe',
    '🧚🏾' => 'umuzimu: ibara ry’uruhu rw’inzobe yirabura',
    '🧚🏿' => 'umuzimu: ibara ry’uruhu rwirabura',
    '🧛🏻' => 'ivampire: ibara ry’uruhu rwera',
    '🧛🏼' => 'ivampire: ibara ry’uruhu rwera gahoro',
    '🧛🏽' => 'ivampire: ibara ry’uruhu rw’inzobe',
    '🧛🏾' => 'ivampire: ibara ry’uruhu rw’inzobe yirabura',
    '🧛🏿' => 'ivampire: ibara ry’uruhu rwirabura',
    '🧜🏻' => 'muntusamaki: ibara ry’uruhu rwera',
    '🧜🏼' => 'muntusamaki: ibara ry’uruhu rwera gahoro',
    '🧜🏽' => 'muntusamaki: ibara ry’uruhu rw’inzobe',
    '🧜🏾' => 'muntusamaki: ibara ry’uruhu rw’inzobe yirabura',
    '🧜🏿' => 'muntusamaki: ibara ry’uruhu rwirabura',
    '🧝🏻' => 'ishitani: ibara ry’uruhu rwera',
    '🧝🏼' => 'ishitani: ibara ry’uruhu rwera gahoro',
    '🧝🏽' => 'ishitani: ibara ry’uruhu rw’inzobe',
    '🧝🏾' => 'ishitani: ibara ry’uruhu rw’inzobe yirabura',
    '🧝🏿' => 'ishitani: ibara ry’uruhu rwirabura',
    '💆🏻' => 'umuntu bari kumasa: ibara ry’uruhu rwera',
    '💆🏼' => 'umuntu bari kumasa: ibara ry’uruhu rwera gahoro',
    '💆🏽' => 'umuntu bari kumasa: ibara ry’uruhu rw’inzobe',
    '💆🏾' => 'umuntu bari kumasa: ibara ry’uruhu rw’inzobe yirabura',
    '💆🏿' => 'umuntu bari kumasa: ibara ry’uruhu rwirabura',
    '💇🏻' => 'umuntu bari kogosha: ibara ry’uruhu rwera',
    '💇🏼' => 'umuntu bari kogosha: ibara ry’uruhu rwera gahoro',
    '💇🏽' => 'umuntu bari kogosha: ibara ry’uruhu rw’inzobe',
    '💇🏾' => 'umuntu bari kogosha: ibara ry’uruhu rw’inzobe yirabura',
    '💇🏿' => 'umuntu bari kogosha: ibara ry’uruhu rwirabura',
    '🚶🏻' => 'umuntu uri kugenda: ibara ry’uruhu rwera',
    '🚶🏼' => 'umuntu uri kugenda: ibara ry’uruhu rwera gahoro',
    '🚶🏽' => 'umuntu uri kugenda: ibara ry’uruhu rw’inzobe',
    '🚶🏾' => 'umuntu uri kugenda: ibara ry’uruhu rw’inzobe yirabura',
    '🚶🏿' => 'umuntu uri kugenda: ibara ry’uruhu rwirabura',
    '🏃🏻' => 'umuntu uri kwiruka: ibara ry’uruhu rwera',
    '🏃🏼' => 'umuntu uri kwiruka: ibara ry’uruhu rwera gahoro',
    '🏃🏽' => 'umuntu uri kwiruka: ibara ry’uruhu rw’inzobe',
    '🏃🏾' => 'umuntu uri kwiruka: ibara ry’uruhu rw’inzobe yirabura',
    '🏃🏿' => 'umuntu uri kwiruka: ibara ry’uruhu rwirabura',
    '💃🏻' => 'umugore uri kubyina: ibara ry’uruhu rwera',
    '💃🏼' => 'umugore uri kubyina: ibara ry’uruhu rwera gahoro',
    '💃🏽' => 'umugore uri kubyina: ibara ry’uruhu rw’inzobe',
    '💃🏾' => 'umugore uri kubyina: ibara ry’uruhu rw’inzobe yirabura',
    '💃🏿' => 'umugore uri kubyina: ibara ry’uruhu rwirabura',
    '🕺🏻' => 'umugabo uri kubyina: ibara ry’uruhu rwera',
    '🕺🏼' => 'umugabo uri kubyina: ibara ry’uruhu rwera gahoro',
    '🕺🏽' => 'umugabo uri kubyina: ibara ry’uruhu rw’inzobe',
    '🕺🏾' => 'umugabo uri kubyina: ibara ry’uruhu rw’inzobe yirabura',
    '🕺🏿' => 'umugabo uri kubyina: ibara ry’uruhu rwirabura',
    '🕴🏻' => 'umuntu wambaye ikositimu uzamuye: ibara ry’uruhu rwera',
    '🕴🏼' => 'umuntu wambaye ikositimu uzamuye: ibara ry’uruhu rwera gahoro',
    '🕴🏽' => 'umuntu wambaye ikositimu uzamuye: ibara ry’uruhu rw’inzobe',
    '🕴🏾' => 'umuntu wambaye ikositimu uzamuye: ibara ry’uruhu rw’inzobe yirabura',
    '🕴🏿' => 'umuntu wambaye ikositimu uzamuye: ibara ry’uruhu rwirabura',
    '👯🏻' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rwera',
    '👯🏼' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rwera gahoro',
    '👯🏽' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rw’inzobe',
    '👯🏾' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rw’inzobe yirabura',
    '👯🏿' => 'abantu bambaye amatwi y’urukwavu bari mu birori: ibara ry’uruhu rwirabura',
    '🧖🏻' => 'umuntu uri muri sawuna: ibara ry’uruhu rwera',
    '🧖🏼' => 'umuntu uri muri sawuna: ibara ry’uruhu rwera gahoro',
    '🧖🏽' => 'umuntu uri muri sawuna: ibara ry’uruhu rw’inzobe',
    '🧖🏾' => 'umuntu uri muri sawuna: ibara ry’uruhu rw’inzobe yirabura',
    '🧖🏿' => 'umuntu uri muri sawuna: ibara ry’uruhu rwirabura',
    '🧗🏻' => 'umuntu wurira: ibara ry’uruhu rwera',
    '🧗🏼' => 'umuntu wurira: ibara ry’uruhu rwera gahoro',
    '🧗🏽' => 'umuntu wurira: ibara ry’uruhu rw’inzobe',
    '🧗🏾' => 'umuntu wurira: ibara ry’uruhu rw’inzobe yirabura',
    '🧗🏿' => 'umuntu wurira: ibara ry’uruhu rwirabura',
    '🏇🏻' => 'gusiganwa ku ifarasi: ibara ry’uruhu rwera',
    '🏇🏼' => 'gusiganwa ku ifarasi: ibara ry’uruhu rwera gahoro',
    '🏇🏽' => 'gusiganwa ku ifarasi: ibara ry’uruhu rw’inzobe',
    '🏇🏾' => 'gusiganwa ku ifarasi: ibara ry’uruhu rw’inzobe yirabura',
    '🏇🏿' => 'gusiganwa ku ifarasi: ibara ry’uruhu rwirabura',
    '🏂🏻' => 'umukinnyi unyerera kuri siki: ibara ry’uruhu rwera',
    '🏂🏼' => 'umukinnyi unyerera kuri siki: ibara ry’uruhu rwera gahoro',
    '🏂🏽' => 'umukinnyi unyerera kuri siki: ibara ry’uruhu rw’inzobe',
    '🏂🏾' => 'umukinnyi unyerera kuri siki: ibara ry’uruhu rw’inzobe yirabura',
    '🏂🏿' => 'umukinnyi unyerera kuri siki: ibara ry’uruhu rwirabura',
    '🏌🏻' => 'gukina golufe ku giti cyawe: ibara ry’uruhu rwera',
    '🏌🏼' => 'gukina golufe ku giti cyawe: ibara ry’uruhu rwera gahoro',
    '🏌🏽' => 'gukina golufe ku giti cyawe: ibara ry’uruhu rw’inzobe',
    '🏌🏾' => 'gukina golufe ku giti cyawe: ibara ry’uruhu rw’inzobe yirabura',
    '🏌🏿' => 'gukina golufe ku giti cyawe: ibara ry’uruhu rwirabura',
    '🏄🏻' => 'umuntu ugendera hejuru y’amazi: ibara ry’uruhu rwera',
    '🏄🏼' => 'umuntu ugendera hejuru y’amazi: ibara ry’uruhu rwera gahoro',
    '🏄🏽' => 'umuntu ugendera hejuru y’amazi: ibara ry’uruhu rw’inzobe',
    '🏄🏾' => 'umuntu ugendera hejuru y’amazi: ibara ry’uruhu rw’inzobe yirabura',
    '🏄🏿' => 'umuntu ugendera hejuru y’amazi: ibara ry’uruhu rwirabura',
    '🚣🏻' => 'umuntu uri kugashya: ibara ry’uruhu rwera',
    '🚣🏼' => 'umuntu uri kugashya: ibara ry’uruhu rwera gahoro',
    '🚣🏽' => 'umuntu uri kugashya: ibara ry’uruhu rw’inzobe',
    '🚣🏾' => 'umuntu uri kugashya: ibara ry’uruhu rw’inzobe yirabura',
    '🚣🏿' => 'umuntu uri kugashya: ibara ry’uruhu rwirabura',
    '🏊🏻' => 'umuntu uri koga: ibara ry’uruhu rwera',
    '🏊🏼' => 'umuntu uri koga: ibara ry’uruhu rwera gahoro',
    '🏊🏽' => 'umuntu uri koga: ibara ry’uruhu rw’inzobe',
    '🏊🏾' => 'umuntu uri koga: ibara ry’uruhu rw’inzobe yirabura',
    '🏊🏿' => 'umuntu uri koga: ibara ry’uruhu rwirabura',
    '⛹🏻' => 'umuntu uri gutera umupira: ibara ry’uruhu rwera',
    '⛹🏼' => 'umuntu uri gutera umupira: ibara ry’uruhu rwera gahoro',
    '⛹🏽' => 'umuntu uri gutera umupira: ibara ry’uruhu rw’inzobe',
    '⛹🏾' => 'umuntu uri gutera umupira: ibara ry’uruhu rw’inzobe yirabura',
    '⛹🏿' => 'umuntu uri gutera umupira: ibara ry’uruhu rwirabura',
    '🏋🏻' => 'umuntu uterura ibyuma: ibara ry’uruhu rwera',
    '🏋🏼' => 'umuntu uterura ibyuma: ibara ry’uruhu rwera gahoro',
    '🏋🏽' => 'umuntu uterura ibyuma: ibara ry’uruhu rw’inzobe',
    '🏋🏾' => 'umuntu uterura ibyuma: ibara ry’uruhu rw’inzobe yirabura',
    '🏋🏿' => 'umuntu uterura ibyuma: ibara ry’uruhu rwirabura',
    '🚴🏻' => 'umuntu utwaye igare: ibara ry’uruhu rwera',
    '🚴🏼' => 'umuntu utwaye igare: ibara ry’uruhu rwera gahoro',
    '🚴🏽' => 'umuntu utwaye igare: ibara ry’uruhu rw’inzobe',
    '🚴🏾' => 'umuntu utwaye igare: ibara ry’uruhu rw’inzobe yirabura',
    '🚴🏿' => 'umuntu utwaye igare: ibara ry’uruhu rwirabura',
    '🚵🏻' => 'umuntu utwaye igare mu misozi: ibara ry’uruhu rwera',
    '🚵🏼' => 'umuntu utwaye igare mu misozi: ibara ry’uruhu rwera gahoro',
    '🚵🏽' => 'umuntu utwaye igare mu misozi: ibara ry’uruhu rw’inzobe',
    '🚵🏾' => 'umuntu utwaye igare mu misozi: ibara ry’uruhu rw’inzobe yirabura',
    '🚵🏿' => 'umuntu utwaye igare mu misozi: ibara ry’uruhu rwirabura',
    '🤸🏻' => 'umuntu uri kumangamanga: ibara ry’uruhu rwera',
    '🤸🏼' => 'umuntu uri kumangamanga: ibara ry’uruhu rwera gahoro',
    '🤸🏽' => 'umuntu uri kumangamanga: ibara ry’uruhu rw’inzobe',
    '🤸🏾' => 'umuntu uri kumangamanga: ibara ry’uruhu rw’inzobe yirabura',
    '🤸🏿' => 'umuntu uri kumangamanga: ibara ry’uruhu rwirabura',
    '🤼🏻' => 'umuntu uri gukirana: ibara ry’uruhu rwera',
    '🤼🏼' => 'umuntu uri gukirana: ibara ry’uruhu rwera gahoro',
    '🤼🏽' => 'umuntu uri gukirana: ibara ry’uruhu rw’inzobe',
    '🤼🏾' => 'umuntu uri gukirana: ibara ry’uruhu rw’inzobe yirabura',
    '🤼🏿' => 'umuntu uri gukirana: ibara ry’uruhu rwirabura',
    '🤽🏻' => 'umuntu uri gukina umukino wa water polo: ibara ry’uruhu rwera',
    '🤽🏼' => 'umuntu uri gukina umukino wa water polo: ibara ry’uruhu rwera gahoro',
    '🤽🏽' => 'umuntu uri gukina umukino wa water polo: ibara ry’uruhu rw’inzobe',
    '🤽🏾' => 'umuntu uri gukina umukino wa water polo: ibara ry’uruhu rw’inzobe yirabura',
    '🤽🏿' => 'umuntu uri gukina umukino wa water polo: ibara ry’uruhu rwirabura',
    '🤾🏻' => 'umuntu uri gukina handball: ibara ry’uruhu rwera',
    '🤾🏼' => 'umuntu uri gukina handball: ibara ry’uruhu rwera gahoro',
    '🤾🏽' => 'umuntu uri gukina handball: ibara ry’uruhu rw’inzobe',
    '🤾🏾' => 'umuntu uri gukina handball: ibara ry’uruhu rw’inzobe yirabura',
    '🤾🏿' => 'umuntu uri gukina handball: ibara ry’uruhu rwirabura',
    '🤹🏻' => 'umuntu uri gukina jongere: ibara ry’uruhu rwera',
    '🤹🏼' => 'umuntu uri gukina jongere: ibara ry’uruhu rwera gahoro',
    '🤹🏽' => 'umuntu uri gukina jongere: ibara ry’uruhu rw’inzobe',
    '🤹🏾' => 'umuntu uri gukina jongere: ibara ry’uruhu rw’inzobe yirabura',
    '🤹🏿' => 'umuntu uri gukina jongere: ibara ry’uruhu rwirabura',
    '🧘🏻' => 'umuntu wicaye ageretse akaguru ku kandi: ibara ry’uruhu rwera',
    '🧘🏼' => 'umuntu wicaye ageretse akaguru ku kandi: ibara ry’uruhu rwera gahoro',
    '🧘🏽' => 'umuntu wicaye ageretse akaguru ku kandi: ibara ry’uruhu rw’inzobe',
    '🧘🏾' => 'umuntu wicaye ageretse akaguru ku kandi: ibara ry’uruhu rw’inzobe yirabura',
    '🧘🏿' => 'umuntu wicaye ageretse akaguru ku kandi: ibara ry’uruhu rwirabura',
    '🛀🏻' => 'umuntu uri kwiyuhagira: ibara ry’uruhu rwera',
    '🛀🏼' => 'umuntu uri kwiyuhagira: ibara ry’uruhu rwera gahoro',
    '🛀🏽' => 'umuntu uri kwiyuhagira: ibara ry’uruhu rw’inzobe',
    '🛀🏾' => 'umuntu uri kwiyuhagira: ibara ry’uruhu rw’inzobe yirabura',
    '🛀🏿' => 'umuntu uri kwiyuhagira: ibara ry’uruhu rwirabura',
    '🛌🏻' => 'umuntu uryamye: ibara ry’uruhu rwera',
    '🛌🏼' => 'umuntu uryamye: ibara ry’uruhu rwera gahoro',
    '🛌🏽' => 'umuntu uryamye: ibara ry’uruhu rw’inzobe',
    '🛌🏾' => 'umuntu uryamye: ibara ry’uruhu rw’inzobe yirabura',
    '🛌🏿' => 'umuntu uryamye: ibara ry’uruhu rwirabura',
    '👭🏻' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rwera',
    '👭🏼' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rwera gahoro',
    '👭🏽' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe',
    '👭🏾' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe yirabura',
    '👭🏿' => 'abagore babiri bafatanye ibigaza: ibara ry’uruhu rwirabura',
    '👫🏻' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rwera',
    '👫🏼' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rwera gahoro',
    '👫🏽' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rw’inzobe',
    '👫🏾' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rw’inzobe yirabura',
    '👫🏿' => 'umugabo n’umugore bafatanye ibiganza: ibara ry’uruhu rwirabura',
    '👬🏻' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rwera',
    '👬🏼' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rwera gahoro',
    '👬🏽' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe',
    '👬🏾' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rw’inzobe yirabura',
    '👬🏿' => 'abagabo babiri bafatanye ibigaza: ibara ry’uruhu rwirabura',
    '💏🏻' => 'gusomana: ibara ry’uruhu rwera',
    '💏🏼' => 'gusomana: ibara ry’uruhu rwera gahoro',
    '💏🏽' => 'gusomana: ibara ry’uruhu rw’inzobe',
    '💏🏾' => 'gusomana: ibara ry’uruhu rw’inzobe yirabura',
    '💏🏿' => 'gusomana: ibara ry’uruhu rwirabura',
    '💑🏻' => 'ikupule n’umutima: ibara ry’uruhu rwera',
    '💑🏼' => 'ikupule n’umutima: ibara ry’uruhu rwera gahoro',
    '💑🏽' => 'ikupule n’umutima: ibara ry’uruhu rw’inzobe',
    '💑🏾' => 'ikupule n’umutima: ibara ry’uruhu rw’inzobe yirabura',
    '💑🏿' => 'ikupule n’umutima: ibara ry’uruhu rwirabura',
    '🏻' => 'ibara ry’uruhu rwera',
    '🏼' => 'ibara ry’uruhu rwera gahoro',
    '🏽' => 'ibara ry’uruhu rw’inzobe',
    '🏾' => 'ibara ry’uruhu rw’inzobe yirabura',
    '🏿' => 'ibara ry’uruhu rwirabura',
    '😀' => 'isura imwenyura',
    '😃' => 'isura iseka ifite umunwa wasamye',
    '😄' => 'isura iseka n’umunwa wasamye n’amaso afunguye',
    '😁' => 'isura imwenyura n’amaso yuje inseko',
    '😆' => 'isura iseka n’umunwa wasamye n’amaso ahumirije',
    '😅' => 'isura iseka n’umunwa wasamye n’ibyuya by’ubwoba',
    '🤣' => 'yigaragura ku butaka aseka',
    '😂' => 'isura ifite amarira y’ibyishimo',
    '🙂' => 'isura iseka gahoro',
    '🙃' => 'isura-icuritse',
    '😉' => 'isura yica akajisho',
    '😊' => 'isura y’amaso yo guseka',
    '😇' => 'isura igaragaza inseko na halo',
    '😍' => 'isura iseka n’amaso agaragara mu ishusho y’umutima',
    '🤩' => 'umuntu ukunda ibyamamare',
    '😘' => 'isura y’umuntu ushaka gusomana',
    '😗' => 'isura y’umuntu usomana',
    '☺' => 'Indoro imwenyura',
    '😚' => 'isura y’umuntu usomana unahumirije',
    '😙' => 'isura y’umuntu usomana n’amaso yo guseka',
    '😋' => 'isura ifitiye amerwe ibiryo biryoshye',
    '😛' => 'isura igaragaza ururimi rwasohotse',
    '😜' => 'isura igaragaza ururimi rwasohotse no kwica akajisho',
    '🤪' => 'isura y’umuntu ubabaye',
    '😝' => 'isura igaragaza ururimi rwasohotse n’amaso ahumirije',
    '🤑' => 'isura-igaragaza umunwa urimo amafaranga',
    '🤗' => 'isura igaragaza guhoberana',
    '🤭' => 'isura y’umuntu wifashe ku munwa',
    '🤫' => 'isura y’umuntu utuje',
    '🤔' => 'isura irimo gutekereza',
    '🤐' => 'isura-igaragaza lisani ku munwa',
    '🤨' => 'isura ifite ibitsike bihagaze',
    '😐' => 'isura itinjirirwa',
    '😑' => 'isura nta marangamutima',
    '😶' => 'isura idafite umunwa',
    '😏' => 'isura iseka idasetse',
    '😒' => 'isura igaragaza kutishima',
    '🙄' => 'isura ikanuye amaso',
    '😬' => 'isura igaragaza amenyo',
    '🤥' => 'isura igaragaza kubeshya',
    '😌' => 'isura ituje',
    '😔' => 'isura yibaza',
    '😪' => 'isura ifite ibitotsi',
    '🤤' => 'isura igaragaza guta inkonda',
    '😴' => 'isura isinzira',
    '😷' => 'isura yambaye masike yo kwa muganga',
    '🤒' => 'isura ifite terimometere',
    '🤕' => 'isura ipfutse ku mutwe',
    '🤢' => 'isura ifite isesemi',
    '🤮' => 'isura y’umuntu uri kuruka',
    '🤧' => 'isura yitsamura',
    '😵' => 'isura igaragaza isereri',
    '🤯' => 'umutwe w’umuntu waturitse',
    '🤠' => 'isura yambaye ingofero z’abakoboyi',
    '😎' => 'isura iseka n’amataratara y’izuba',
    '🤓' => 'isura ya kanyuguti',
    '🧐' => 'isura y’umuntu wambaye idarubindi',
    '😕' => 'isura yashobewe',
    '😟' => 'isura ihangayitse',
    '🙁' => 'isura itishimye bitari cyane',
    '☹' => 'isura irakaye',
    '😮' => 'isura igaragaza umunwa wasamye',
    '😯' => 'isura igaragaza uwacecetse',
    '😲' => 'isura yatangaye',
    '😳' => 'isura yatukuye',
    '😦' => 'isura igaragaza kutishima n’umunwa wasamye',
    '😧' => 'isura igaragaza inkeke',
    '😨' => 'isura igaragaza kugira ubwoba',
    '😰' => 'isura igaragaza umunwa wasamye n’ibyuya by’ubwoba',
    '😥' => 'isura igaragaza guhemukirwa ariko ukaruhuka ku mutima',
    '😢' => 'isura igaragaza kurira',
    '😭' => 'isura igaragaza kurira cyane',
    '😱' => 'isura isakuza kubera ubwoba',
    '😖' => 'isura igaragaza kwitiranya',
    '😣' => 'isura igaragaza kutava ku izima',
    '😞' => 'isura igaragaza guhemukirwa',
    '😓' => 'isura igaragaza ibyuya by’ubwoba',
    '😩' => 'isura igaragaza umunaniro',
    '😫' => 'isura inaniwe',
    '😤' => 'isura igaragaza umwuka uva mu mazuru',
    '😡' => 'isura igaragaza guhakana',
    '😠' => 'isura igaragaza uburakari',
    '🤬' => 'isura y’umuntu ufite ibimenyetso ku munwa',
    '😈' => 'isura igaragaza inseko n’amahembe',
    '👿' => 'isura igaragaza uburakari n’amahembe',
    '💀' => 'igikanka',
    '☠' => 'igihanga n’amagufamusaraba',
    '💩' => 'icyuto',
    '🤡' => 'isura ya jokeri',
    '👹' => 'igishitani',
    '👺' => 'ikigini',
    '👻' => 'umweru baringa',
    '👽' => 'ikimanuka',
    '👾' => 'igikoko kidasanzwe',
    '🤖' => 'isura y’irobo',
    '😺' => 'isura y’injangwe iseka n’umunwa wasamye',
    '😸' => 'isura y’injangwe igaragaza amenyo n’amaso yo guseka',
    '😹' => 'isura y’injangwe n’amarira y’ibyishimo',
    '😻' => 'isura y’injangwe iseka n’amaso agaragara mu ishusho y’umutima',
    '😼' => 'isura y’injangwe igaragaza inseko y’uburyarya',
    '😽' => 'isura y’injangwe isoma inahumirije',
    '🙀' => 'isura y’injangwe y’indyarya',
    '😿' => 'isura y’injangwe irira',
    '😾' => 'isura y’injangwe igaragaza guhakana',
    '🙈' => 'inkende itareba',
    '🙉' => 'inkende itumva',
    '🙊' => 'inkende itavuga',
    '💌' => 'ibahasha y’urukundo',
    '💘' => 'umutima n’akambi',
    '💝' => 'umutima uriho riba',
    '💖' => 'umutima ubengerana',
    '💗' => 'umutima ukura',
    '💓' => 'umutima utera',
    '💞' => 'imitima izenguruka',
    '💕' => 'imitima ibiri',
    '💟' => 'umuteguro w’imitima',
    '❣' => 'akamenyetso k’umutima gatangara',
    '💔' => 'umutima umenetse',
    '❤' => 'umutima utukura',
    '🧡' => 'umutima wa oranje',
    '💛' => 'umutima w’umuhondo',
    '💚' => 'umutima w’icyatsi',
    '💙' => 'umutima w’ubururu',
    '💜' => 'umutima wa move',
    '🖤' => 'imitima yirabura',
    '💋' => 'ikimenyetso cyo gusomana',
    '💯' => 'amanota ijana',
    '💢' => 'ikimenyetso cy’uburakari',
    '💥' => 'igongana',
    '💫' => 'ufite isereri',
    '💦' => 'udutonyanga tw’ibyuya',
    '💨' => 'ikimenyetso cy’ibinyaruka',
    '🕳' => 'umwobo',
    '💬' => 'igipurizomvugo',
    '🗨' => 'ikiganiro cy’akabaruni k’ibumoso',
    '🗯' => 'akabaruni gasongoye k’iburyo',
    '💭' => 'akazu kagaragaza gutekereza',
    '💤' => 'zzz',
    '👋' => 'ikiganza gipepera',
    '🤚' => 'inyuma y’ikiganza kizamuye',
    '🖐' => 'ikiganza kizamuye intoki zitandukanyije',
    '✋' => 'ikiganza kizamuye',
    '🖖' => 'indamukanyo ya vulcan',
    '👌' => 'ikiganza cyemeza',
    '✌' => 'Ikiganza cy’intsinzi',
    '🤞' => 'intoki zinyuranyemo',
    '🤟' => 'ikimenyetso cya ndagukunda',
    '🤘' => 'ikimenyetso cy’amahembe',
    '🤙' => 'ikiganza gisaba guhamagarwa',
    '👈' => 'urutoki rutunze ibumoso',
    '👉' => 'urutoki rutunze iburyo',
    '👆' => 'urutoki rutunze hejuru',
    '🖕' => 'musumbazose',
    '👇' => 'urutoki rutunze hasi',
    '☝' => 'gutunga mukubitarukoko hejuru',
    '👍' => 'ibikumwe bireba hejuru',
    '👎' => 'ibikumwe bireba hasi',
    '✊' => 'igipfunsi kizamuye',
    '👊' => 'igipfunsi kikureba',
    '🤛' => 'igipfunsi kireba ibumoso',
    '🤜' => 'igipfunsi kireba iburyo',
    '👏' => 'ibiganza bikoma amashyi',
    '🙌' => 'ibiganza bizamuye',
    '👐' => 'ikimenyetso cy’ibiganza bibumbuye',
    '🤲' => 'ibiganza byombi hejuru',
    '🤝' => 'gusuhuzanya',
    '🙏' => 'ibiganza bifatanye',
    '✍' => 'ikiganza cyandika',
    '💅' => 'verini y’inzara',
    '🤳' => 'serifi',
    '💪' => 'amaboko ahinnye',
    '👂' => 'ugutwi',
    '👃' => 'izuru',
    '🧠' => 'mutwe:',
    '👀' => 'amaso',
    '👁' => 'ijisho',
    '👅' => 'ururimi',
    '👄' => 'umunwa',
    '👶' => 'uruhinja',
    '🧒' => 'umwana',
    '👦' => 'umuhungu',
    '👧' => 'umukobwa',
    '🧑' => 'umuntu mukuru',
    '👱' => 'umuntu ufite imisatsi y’umweru',
    '👨' => 'umugabo',
    '🧔' => 'umuntu ufite ubwanwa',
    '👩' => 'umugore',
    '🧓' => 'umuntu mukuru ushaje',
    '👴' => 'umusaza',
    '👵' => 'umukecuru',
    '🙍' => 'umuntu utishimye',
    '🙎' => 'umuntu uhakana',
    '🙅' => 'umuntu ugaragaza OYA',
    '🙆' => 'umuntu ugaragaza Yego',
    '💁' => 'umuntu wazamuye urutoki',
    '🙋' => 'umuntu wazamuye ikiganza',
    '🙇' => 'umuntu wunamye',
    '🤦' => 'umuntu wifash mu maso',
    '🤷' => 'umuntu wazamuye intugu',
    '👮' => 'umupolisi',
    '🕵' => 'umugenzuzi',
    '💂' => 'umusuruveya',
    '👷' => 'umwubatsi',
    '🤴' => 'igikomangoma',
    '👸' => 'igikomangomakazi',
    '👳' => 'umuntu witandiye',
    '👲' => 'umuntu wambaye ingofero y’abashinwa',
    '🧕' => 'umugore wambaye igitambaro cyo mu mutwe',
    '🤵' => 'umugabo wambaye ikoti',
    '👰' => 'umugeni wambaye ivara',
    '🤰' => 'umugore utwite',
    '🤱' => 'konsa',
    '👼' => 'akamalayika',
    '🎅' => 'Papa Noheli',
    '🤶' => 'Mama Noheli',
    '🧙' => 'umumaji',
    '🧚' => 'umuzimu',
    '🧛' => 'ivampire',
    '🧜' => 'muntusamaki',
    '🧝' => 'ishitani',
    '🧞' => 'igini',
    '🧟' => 'izombi',
    '💆' => 'umuntu bari kumasa',
    '💇' => 'umuntu bari kogosha',
    '🚶' => 'umuntu uri kugenda',
    '🏃' => 'umuntu uri kwiruka',
    '💃' => 'umugore uri kubyina',
    '🕺' => 'umugabo uri kubyina',
    '🕴' => 'umuntu wambaye ikositimu uzamuye',
    '👯' => 'abantu bambaye amatwi y’urukwavu bari mu birori',
    '🧖' => 'umuntu uri muri sawuna',
    '🧗' => 'umuntu wurira',
    '🤺' => 'umuntu uri gukina umukino w’inkota',
    '🏇' => 'gusiganwa ku ifarasi',
    '⛷' => 'ugendera kuri siki',
    '🏂' => 'umukinnyi unyerera kuri siki',
    '🏌' => 'gukina golufe ku giti cyawe',
    '🏄' => 'umuntu ugendera hejuru y’amazi',
    '🚣' => 'umuntu uri kugashya',
    '🏊' => 'umuntu uri koga',
    '⛹' => 'umuntu uri gutera umupira',
    '🏋' => 'umuntu uterura ibyuma',
    '🚴' => 'umuntu utwaye igare',
    '🚵' => 'umuntu utwaye igare mu misozi',
    '🤸' => 'umuntu uri kumangamanga',
    '🤼' => 'umuntu uri gukirana',
    '🤽' => 'umuntu uri gukina umukino wa water polo',
    '🤾' => 'umuntu uri gukina handball',
    '🤹' => 'umuntu uri gukina jongere',
    '🧘' => 'umuntu wicaye ageretse akaguru ku kandi',
    '🛀' => 'umuntu uri kwiyuhagira',
    '🛌' => 'umuntu uryamye',
    '👭' => 'abagore babiri bafatanye ibigaza',
    '👫' => 'umugabo n’umugore bafatanye ibiganza',
    '👬' => 'abagabo babiri bafatanye ibigaza',
    '💏' => 'gusomana',
    '💑' => 'ikupule n’umutima',
    '🗣' => 'umutwe uvuga',
    '👤' => 'ishusho y’igihimba cy’umuntu',
    '👥' => 'amashusho y’igihimba cy’umuntu',
    '👪' => 'umuryango',
    '👣' => 'ahakandagiye ibirenge',
    '🐵' => 'isura y’inkende',
    '🐒' => 'inguge',
    '🦍' => 'ingagi',
    '🐶' => 'indoro y’imbwa',
    '🐕' => 'imbwa',
    '🐩' => 'imbwa nini y’impigi',
    '🐺' => 'isura y’ikirura',
    '🦊' => 'isura y’umuhari',
    '🐱' => 'indoro y’injangwe',
    '🐈' => 'injangwe',
    '🦁' => 'isura y’intare',
    '🐯' => 'isura y’igisamagwe',
    '🐅' => 'igisamagwe',
    '🐆' => 'ingwe',
    '🐴' => 'isura y’ifarasi',
    '🐎' => 'indogobe',
    '🦄' => 'isura y’umunyana',
    '🦓' => 'imparage',
    '🦌' => 'isha',
    '🐮' => 'isura y’inka',
    '🐂' => 'ikimasa',
    '🐃' => 'imbogo yo mu mazi',
    '🐄' => 'inka',
    '🐷' => 'isura y’ingurube',
    '🐖' => 'ingurube',
    '🐗' => 'ingurube y’ishyamba',
    '🐽' => 'ikizuru cy’ingurube',
    '🐏' => 'rugeyo',
    '🐑' => 'intama',
    '🐐' => 'ihene',
    '🐪' => 'ingamiya',
    '🐫' => 'ingamiya y’amapfupfu abiri',
    '🦒' => 'twiga',
    '🐘' => 'inzovu',
    '🦏' => 'inkura',
    '🐭' => 'isura y’imbeba',
    '🐁' => 'mushushwe',
    '🐀' => 'imbeba',
    '🐹' => 'isura y’akabeba',
    '🐰' => 'isura y’urukwavu',
    '🐇' => 'urukwavu',
    '🐿' => 'inkima',
    '🦔' => 'ikinyogote',
    '🦇' => 'agacurama',
    '🐻' => 'isura y’ikirura kinini',
    '🐨' => 'akaruragato',
    '🐼' => 'isura y’akarura gato',
    '🐾' => 'ahanyuze amajanja',
    '🦃' => 'turukiya',
    '🐔' => 'inkoko',
    '🐓' => 'isake',
    '🐣' => 'umushwi uri guturagwa',
    '🐤' => 'umushwi',
    '🐥' => 'umushwi ukureba',
    '🐦' => 'inyoni',
    '🐧' => 'pingwini',
    '🕊' => 'inuma',
    '🦅' => 'kagoma',
    '🦆' => 'igishuhe',
    '🦉' => 'igihunyira',
    '🐸' => 'isura y’igikeri',
    '🐊' => 'ingona',
    '🐢' => 'akanyamasyo',
    '🦎' => 'umuserebanya',
    '🐍' => 'inzoka',
    '🐲' => 'isura ya darago',
    '🐉' => 'darago',
    '🦕' => 'Dinozoro yo mu bwoko bwa Sauropod',
    '🦖' => 'Dinozoro yo mu bwoko bwa T-Rex',
    '🐳' => 'balene ihumeka',
    '🐋' => 'barene',
    '🐬' => 'igifi kinini',
    '🐟' => 'ifi',
    '🐠' => 'ifi yo muri toropike',
    '🐡' => 'ifi imeze nka balo',
    '🦈' => 'roke',
    '🐙' => 'igikoko cyo mumazi',
    '🐚' => 'igikonoshwa',
    '🦀' => 'karabu',
    '🦐' => 'kerevete',
    '🦑' => 'sikwidi',
    '🐌' => 'ikinyamunjonjorerwa',
    '🦋' => 'ikinyugunyugu',
    '🐛' => 'kemura ibibazo',
    '🐜' => 'umuswa',
    '🐝' => 'uruyuki',
    '🐞' => 'akanyenyeri',
    '🦗' => 'kiriketi',
    '🕷' => 'igitagangurirwa',
    '🕸' => 'umugozi w’igitagangurirwa',
    '🦂' => 'sikorupiyo',
    '💐' => 'umufungo w’indabyo',
    '🌸' => 'igiti gifite imbuto z’umutuku',
    '💮' => 'ururabo rw’umweru',
    '🏵' => 'rozete',
    '🌹' => 'iroza',
    '🥀' => 'ururabo rwenda kuvunika',
    '🌺' => 'ibisikisi',
    '🌻' => 'igihwagari',
    '🌼' => 'ururabyo',
    '🌷' => 'ururabyo rwa tulipu',
    '🌱' => 'urugemwe',
    '🌲' => 'igiti gihora gitoshye',
    '🌳' => 'igiti gita amababi',
    '🌴' => 'igiti cy’umukindo',
    '🌵' => 'kagitusi',
    '🌾' => 'ikibabi cy’umuceri',
    '🌿' => 'icyatsi',
    '☘' => 'ubwoko bw’ikibabi',
    '🍀' => 'igiti gifite amababi ane',
    '🍁' => 'ikibabi cy’igiti cya maple',
    '🍂' => 'ikibabi cyaguye',
    '🍃' => 'ikibabi gihuhwa n’umuyaga',
    '🍄' => 'igihumyo',
    '🍇' => 'imizabibu',
    '🍈' => 'melo',
    '🍉' => 'pasiteke',
    '🍊' => 'mandarine',
    '🍋' => 'indimu yijimye',
    '🍌' => 'umuneke',
    '🍍' => 'inanasi',
    '🍎' => 'pome itukura',
    '🍏' => 'pome y’icyatsi',
    '🍐' => 'puware',
    '🍑' => 'peshe',
    '🍒' => 'serize',
    '🍓' => 'inkeri',
    '🥝' => 'urubuto rwa kiwi',
    '🍅' => 'urunyanya',
    '🥥' => 'kokonatit',
    '🥑' => 'avoka',
    '🍆' => 'ikibiringanya',
    '🥔' => 'ikirayi',
    '🥕' => 'karoti',
    '🌽' => 'ikibabi cy’ikigori',
    '🌶' => 'urusenda',
    '🥒' => 'kokombure',
    '🥦' => 'udushu',
    '🥜' => 'urunyobwa',
    '🌰' => 'igiti cya shatenye',
    '🍞' => 'umugati',
    '🥐' => 'kuruwasa',
    '🥖' => 'umugati wa bagete',
    '🥨' => 'ibisukuti',
    '🥞' => 'panikeke',
    '🧀' => 'igisate cya foromaje',
    '🍖' => 'inyama y’igufwa',
    '🍗' => 'ukuguru kw’inkoko',
    '🥩' => 'intongo ’inyama',
    '🥓' => 'inyama y’ingurube',
    '🍔' => 'hambaga',
    '🍟' => 'amafiriti',
    '🍕' => 'piza',
    '🌭' => 'hoti dogi',
    '🥪' => 'sanduwici',
    '🌮' => 'tako',
    '🌯' => 'burito',
    '🥙' => 'umugati wapakiwemo ibiryo imbere',
    '🥚' => 'igi',
    '🍳' => 'guteka',
    '🥘' => 'agapanu k’ibiryo',
    '🍲' => 'icyungo cy’ibiryo',
    '🥣' => 'imbehe n’ikiyiko',
    '🥗' => 'salade y’imboga',
    '🍿' => 'injugu',
    '🥫' => 'ibiryo byo mu bikopo',
    '🍱' => 'agakarito k’isahani',
    '🍘' => 'koroka ikoze mu muceri',
    '🍙' => 'ikibumbe cy’umuceri',
    '🍚' => 'umuceri utetse',
    '🍛' => 'umuceri n’isosi',
    '🍜' => 'inkono icumbamo umwotsi',
    '🍝' => 'sipageti',
    '🍠' => 'ikijumba cyokeje',
    '🍢' => 'odeni',
    '🍣' => 'sushi',
    '🍤' => 'inunda zakaranzwe mu mavuta',
    '🍥' => 'gato iri mu ishusho y’ifi izengurutse',
    '🍡' => 'dango',
    '🥟' => 'umugati wokeje',
    '🥠' => 'igisuguti',
    '🥡' => 'agakarito batwaramo ibiryo',
    '🍦' => 'ayisikirimu yoroheje',
    '🍧' => 'urubura rusennye neza',
    '🍨' => 'ayisikirimu',
    '🍩' => 'uruziga',
    '🍪' => 'biswi',
    '🎂' => 'gato y’isabukuru y’amavuko',
    '🍰' => 'keke nto',
    '🥧' => 'imbonerahamwe',
    '🍫' => 'shokola',
    '🍬' => 'bombo',
    '🍭' => 'bombo yo ku giti',
    '🍮' => 'kereme',
    '🍯' => 'ikibindi cy’ubuki',
    '🍼' => 'bibero',
    '🥛' => 'ikirahuri cy’amata',
    '☕' => 'ikinyobwa gishyushye',
    '🍵' => 'agakombe k’icyayi kadafite umukondo',
    '🍶' => 'seyiki',
    '🍾' => 'icupa rifite umufuniko uri kuvaho',
    '🍷' => 'ikirahure cya divayi',
    '🍸' => 'ikirahure cy’uruvange rw’inzoga',
    '🍹' => 'ikinyobwa kidasindisha',
    '🍺' => 'ikirahure cy’inzoga',
    '🍻' => 'ibirahure by’inzoga bikocorana',
    '🥂' => 'ibirahuri bikocorana',
    '🥃' => 'ikirahuri kitagira umukondo',
    '🥤' => 'igikombe n’umuheha',
    '🥢' => 'uduti barisha',
    '🍽' => 'ikanya n’icyuma hamwe n’iparato',
    '🍴' => 'ikanya n’icyuma',
    '🥄' => 'akayiko',
    '🔪' => 'icyuma cyo mu gikoni',
    '🏺' => 'urwabya',
    '🌍' => 'umubumbe w’isi werekana Uburayi n’Afurika',
    '🌎' => 'umubumbe w’isi werekana Amerika zombi',
    '🌏' => 'umubumbe w’isi werekana Aziya na Ositarariya',
    '🌐' => 'umubumbe w’isi werekana imirongo miganda',
    '🗺' => 'Ikarita y’isi',
    '🗾' => 'ikarita y’ubuyapani',
    '🏔' => 'umusozi utwikiriwe n’urubura',
    '⛰' => 'umusozi',
    '🌋' => 'ikirunga',
    '🗻' => 'umusozi wa fuji',
    '🏕' => 'ingando',
    '🏖' => 'ahantu ku mucanga hari umutaka',
    '🏜' => 'ubutayu',
    '🏝' => 'ikirwa cy’ubutayu',
    '🏞' => 'parike y’igihugu',
    '🏟' => 'sitade',
    '🏛' => 'inyubako za cyera',
    '🏗' => 'icyubakwa',
    '🏘' => 'amazu',
    '🏚' => 'inzu itakibabwamo',
    '🏠' => 'inyumba',
    '🏡' => 'inzu ifite n’ubusitani',
    '🏢' => 'inyubako y’ibiro',
    '🏣' => 'ibiro by’iposita by’ubuyapani',
    '🏤' => 'iposita',
    '🏥' => 'ibitaro',
    '🏦' => 'banki',
    '🏨' => 'hoteli',
    '🏩' => 'ihoteli y’urukundo',
    '🏪' => 'iduka rigurisha iby’ibanze',
    '🏫' => 'ishuri',
    '🏬' => 'amaduka rutura',
    '🏭' => 'uruganda',
    '🏯' => 'inzu nini y’abayapani',
    '🏰' => 'ingoro',
    '💒' => 'ubukwe',
    '🗼' => 'umunara wa Tokiyo',
    '🗽' => 'ishusho y’ubwigenge',
    '⛪' => 'kiliziya',
    '🕌' => 'umusigiti',
    '🕍' => 'isinagogi',
    '⛩' => 'aho bashengerera h’idini ya shinto',
    '🕋' => 'akaba',
    '⛲' => 'umugezi',
    '⛺' => 'ihema',
    '🌁' => 'kiganjemo igihu',
    '🌃' => 'ijoro ririmo inyenyeri',
    '🏙' => 'uko umujyi ugaragara',
    '🌄' => 'izuba rirasiye ku misozi',
    '🌅' => 'kurasa kw’izuba',
    '🌆' => 'igice cy’umujyi kirengeweho n’izuba',
    '🌇' => 'kurenga kw’izuba',
    '🌉' => 'ikiraro kigaragara mu ijoro',
    '♨' => 'amashyuza',
    '🎠' => 'ifarasi y’igikorano',
    '🎡' => 'ipine rinini',
    '🎢' => 'umwicungo',
    '💈' => 'icyapa cy’aho bogoshera',
    '🎪' => 'ihema ry’uruziga',
    '🚂' => 'rokomotive',
    '🚃' => 'vago',
    '🚄' => 'gariyamoshi y’umuvuduko munini',
    '🚅' => 'gariyamoshi y’umuvuduko munini n’imbere hasongoye',
    '🚆' => 'gariyamoshi',
    '🚇' => 'metiro',
    '🚈' => 'gariyamoshi yoroheje',
    '🚉' => 'sitasiyo',
    '🚊' => 'taramu',
    '🚝' => 'gariyamoshi inyura ku muhanda umwe',
    '🚞' => 'gariyamoshi inyura mu misozi',
    '🚋' => 'gariyamoshi ya taramu',
    '🚌' => 'bisi',
    '🚍' => 'bisi iza igusanga',
    '🚎' => 'bisi ikoreshwa n’amashanyarazi',
    '🚐' => 'minibisi',
    '🚑' => 'imbangukiragutabara',
    '🚒' => 'kizimyamoto',
    '🚓' => 'imodoka ya polisi',
    '🚔' => 'imodoka ya polisi iza igusanga',
    '🚕' => 'tagisi',
    '🚖' => 'tagisi iza igusanga',
    '🚗' => 'imodoka',
    '🚘' => 'imodoka iza igusanga',
    '🚙' => 'ijipe ya siporo',
    '🚚' => 'ikamyo ipakira ibintu',
    '🚛' => 'makuzungu',
    '🚜' => 'imashiniihinga',
    '🏎' => 'imodoka y’isiganwa',
    '🏍' => 'Ipikipiki',
    '🛵' => 'sikuteri ya moto',
    '🚲' => 'igare',
    '🛴' => 'moto y’umugeri',
    '🚏' => 'aho bisi zihagara',
    '🛣' => 'inzira ya moto',
    '🛤' => 'inzira ya gari ya moshi',
    '🛢' => 'Akagunguru ka peteroli',
    '⛽' => 'ipompe ya lisansi',
    '🚨' => 'amatara y’imodoka ya polisi',
    '🚥' => 'ibimenyetso bimurika bitambitse',
    '🚦' => 'ibimenyetso bimurika bihagaritse',
    '🛑' => 'icyapa cyo guhagarara',
    '🚧' => 'ubwubatsi',
    '⚓' => 'inshyigikizi',
    '⛵' => 'ubwato bwo gutembera',
    '🛶' => 'ubwato buto',
    '🚤' => 'icyombo',
    '🛳' => 'ubwato bw’umugenzi',
    '⛴' => 'Ubwato butwara abantu',
    '🛥' => 'ubato bwa moteri',
    '🚢' => 'ubwato',
    '✈' => 'indege',
    '🛩' => 'indege ntoya',
    '🛫' => 'indege iri guhaguruka',
    '🛬' => 'indege iri kugwa',
    '💺' => 'intebe',
    '🚁' => 'kajugujugu',
    '🚟' => 'imihanda ya gariyamoshi iri mu kirere',
    '🚠' => 'utumodoka two ku migozi two mu misozi',
    '🚡' => 'taramu inyura mu kirere',
    '🛰' => 'saterite',
    '🚀' => 'icyogajuru',
    '🛸' => 'isahani iguruka',
    '🛎' => 'inzogera y’uwo batuma',
    '⌛' => 'impimasaha',
    '⏳' => 'impimasaha n’umucanga umeneka',
    '⌚' => 'reba',
    '⏰' => 'isaha yo kubyutsa',
    '⏱' => 'koronometere',
    '⏲' => 'isaha y’imbaragihe',
    '🕰' => 'isha bamanika',
    '🕛' => 'saa sita',
    '🕧' => 'saa sita n’igice',
    '🕐' => 'saa saba',
    '🕜' => 'saa saba n’igice',
    '🕑' => 'saa munani',
    '🕝' => 'saa munani n’igice',
    '🕒' => 'saa cyenda',
    '🕞' => 'saa cyenda n’igice',
    '🕓' => 'saa kumi',
    '🕟' => 'saa kumi n’igice',
    '🕔' => 'saa kumi n’imwe',
    '🕠' => 'saa kumi n’imwe n’igice',
    '🕕' => 'saa kumi n’ebyiri',
    '🕡' => 'saa kumi n’ebyiri n’igice',
    '🕖' => 'saa moya',
    '🕢' => 'saa moya n’igice',
    '🕗' => 'saa mbili',
    '🕣' => 'saa mbili n’igice',
    '🕘' => 'saa tatu',
    '🕤' => 'saa tatu n’igice',
    '🕙' => 'saa yine',
    '🕥' => 'saa yine n’igice',
    '🕚' => 'saa tanu',
    '🕦' => 'saa tanu n’igice',
    '🌑' => 'ukwezi gushya',
    '🌒' => 'bitutu bya kane by’ukwezi',
    '🌓' => 'icya kane cya mbere cy’ukwezi',
    '🌔' => 'ukwezi kuri muri bitatu bya kane',
    '🌕' => 'inzora y’ukwezi',
    '🌖' => 'ukwezi kwikubye nk’inyonjo',
    '🌗' => 'icya kane cya nyuma cy’ukwezi',
    '🌘' => 'kimwe cya kane cy’ukwezi',
    '🌙' => 'ukwezi kugenda gukura',
    '🌚' => 'isura y’ukwezi gushya',
    '🌛' => 'icya kane cya mbere cy’ukwezi gifite isura',
    '🌜' => 'icya kane cya nyuma cy’ukwezi gifite isura',
    '🌡' => 'igipimo cy’ubushyuhe',
    '☀' => 'cyu',
    '🌝' => 'inzora y’ukwezi ifite isura',
    '🌞' => 'izuba rifite isura',
    '⭐' => 'inyenyeri iringaniye y’umweru',
    '🌟' => 'inyenyeri ishashagirana',
    '🌠' => 'kibonumwe',
    '🌌' => 'inzira nyamata',
    '☁' => 'karawudi',
    '⛅' => 'izuba ryihishe inyuma y’igicu',
    '⛈' => 'ibicu byiganjemo imirabyo n’imvura',
    '🌤' => 'izuba inyuma y’igicu gito',
    '🌥' => 'izuba inyuma y’igicu kinini',
    '🌦' => 'izuba inyuma y’igicu kirimo imvura',
    '🌧' => 'ibicu birimo',
    '🌨' => 'ibicu birimo urubura',
    '🌩' => 'ibicu birimo imirabyo',
    '🌪' => 'umuyaga ukaze',
    '🌫' => 'ibihu',
    '🌬' => 'isura yahushywe n’umuyaga',
    '🌀' => 'serwakira',
    '🌈' => 'umukororombya',
    '🌂' => 'umutaka ufunze',
    '☂' => 'umuyaga',
    '☔' => 'umutaka uriho ibitonyanga by’imvura',
    '⛱' => 'umutaka ku butaka',
    '⚡' => 'tansiyo y’umuriro yo hejuru',
    '❄' => 'akabumbe k’urubura',
    '☃' => 'umugabo wo mu rubura',
    '⛄' => 'umuntu ukoze mu rubura udafite urubura',
    '☄' => 'komete',
    '🔥' => 'umuriro',
    '💧' => 'igitonyanga',
    '🌊' => 'umuvumba w’amazi',
    '🎃' => 'itara rya jack-o',
    '🎄' => 'igiti cya Noheli',
    '🎆' => 'imiriro y’ibyishimo',
    '🎇' => 'igishashagizo',
    '✨' => 'ibishashi',
    '🎈' => 'akabaruni',
    '🎉' => 'igikoresho gituritsa mu birori',
    '🎊' => 'udupapuro tw’amabara',
    '🎋' => 'igiti cya tanabata',
    '🎍' => 'umuteguro w’igiti cya pine',
    '🎎' => 'ibipupe byo mu buyapani',
    '🎏' => 'igitambaro ndanga',
    '🎐' => 'inzogera muyaga',
    '🎑' => 'ibirori byo kureba ukwezi',
    '🎀' => 'riba',
    '🎁' => 'impano ifunitse',
    '🎗' => 'riba y’inyibutsa',
    '🎟' => 'amatike yo kwemererwa',
    '🎫' => 'itike',
    '🎖' => 'umudari wa gisirakare',
    '🏆' => 'igikombe',
    '🏅' => 'umudari wo muri siporo',
    '🥇' => 'umudari w’umwanya wa 1',
    '🥈' => 'umudari w’umwanya wa 2',
    '🥉' => 'umudari w’umwanya wa 3',
    '⚽' => 'umupira w’amaguru',
    '⚾' => 'beziboro',
    '🏀' => 'basiketiboro',
    '🏐' => 'voreboro',
    '🏈' => 'umupira w’amaguru w’abanyamerika',
    '🏉' => 'rugibi',
    '🎾' => 'tenisi',
    '🎳' => 'bowuringi',
    '🏏' => 'umukino wa kirike',
    '🏑' => 'hoki yo mu kibuga',
    '🏒' => 'isihoki',
    '🏓' => 'pingi pongo',
    '🏸' => 'badimintone',
    '🥊' => 'uturindantoki two mu iteramakofi',
    '🥋' => 'impuzankano z’imikino njyarugamba',
    '🥅' => 'inshundura',
    '⛳' => 'ibendera riri mu mwobo',
    '⛸' => 'sketi yo ku rubura',
    '🎣' => 'indobani',
    '🎽' => 'umupira wo kwirukankana',
    '🎿' => 'siki',
    '🛷' => 'agatebe kanyerera ku rubuga',
    '🥌' => 'ibuye rya curling',
    '🎯' => 'gukubita ako kanya',
    '🔫' => 'masotera',
    '🎱' => 'umupira wa biyari wa nomero 8',
    '🔮' => 'ikibumbe cy’urubura',
    '🎮' => 'videwo y’umukino',
    '🕹' => 'agakonimukino',
    '🎰' => 'akamashini gatanga amatike',
    '🎲' => 'utwo bakinisha biyari',
    '♠' => 'ikimenyeso cy’ipiki',
    '♥' => 'ikimenyetso cy’umutima',
    '♦' => 'ikimenyetso cya diyama',
    '♣' => 'ikimenyetso cyo ku ikarita cy’umusaraba',
    '🃏' => 'jokeri',
    '🀄' => 'ikaro itukura y’umukino wa mahjong',
    '🎴' => 'amakarita yo gukina ashushanyijeho indabyo',
    '🎭' => 'imyiyereko',
    '🖼' => 'ifoto iri mu ikadiri',
    '🎨' => 'akadirishya nderembyi k’abahanzi',
    '👓' => 'amadarubindi',
    '🕶' => 'fime',
    '👔' => 'karuvati',
    '👕' => 'umupira wo kwambara',
    '👖' => 'ikoboyi',
    '🧣' => 'furari',
    '🧤' => 'udupfukantoki',
    '🧥' => 'ikoti',
    '🧦' => 'amasogisi',
    '👗' => 'ikanzu',
    '👘' => 'imyenda bakinana karate',
    '👙' => 'utwenda two ku mazi',
    '👚' => 'imyenda y’abagore',
    '👛' => 'ikofi',
    '👜' => 'isakoshi',
    '👝' => 'agasakoshi',
    '🛍' => 'ibikapu bahahiramo',
    '🎒' => 'igikapu cy’umunyeshuri',
    '👞' => 'urukweto rw’abagabo',
    '👟' => 'urukweto rwo kwirukankana',
    '👠' => 'urukweto rufite taro ndende',
    '👡' => 'sandale z’abagore',
    '👢' => 'bote z’abagore',
    '👑' => 'ikamba',
    '👒' => 'ingofero y’abagore',
    '🎩' => 'ingofero ireba hejuru',
    '🎓' => 'ingofero yo gusoza kaminuza',
    '🧢' => 'ingofero ifite ibigara bibiri',
    '⛑' => 'kasike itabara abakozi',
    '📿' => 'amasaro y’ishapure',
    '💄' => 'amavuta basiga ku minwa',
    '💍' => 'impeta',
    '💎' => 'ibuye ry’agaciro',
    '🔇' => 'indangururamajwi yacecekeshejwe',
    '🔈' => 'indangururamajwi ifite ubwirangire buri hasi',
    '🔉' => 'indangururamajwi ifite ubwirangire buringaniye',
    '🔊' => 'indangururamajwi ifite ubwirangire bwo hejuru',
    '📢' => 'indangururamajwi',
    '📣' => 'megafone',
    '📯' => 'ikondera',
    '🔔' => 'inzogera',
    '🔕' => 'inzogera inyujemo akarongo',
    '🎼' => 'akarango k’umuziki',
    '🎵' => 'inota ry’umuziki',
    '🎶' => 'amanota y’umuziki',
    '🎙' => 'indangururamajwi ya sitidiyo',
    '🎚' => 'akagaragazarugero',
    '🎛' => 'buto zo kugenzura',
    '🎤' => 'mikoro',
    '🎧' => 'ekuteri',
    '📻' => 'radiyo',
    '🎷' => 'umwirongi',
    '🎺' => 'umuduri',
    '🎸' => 'gitari',
    '🎹' => 'sentetizeri',
    '🎻' => 'inanga',
    '🥁' => 'ingoma',
    '📱' => 'telefone igendanwa',
    '📲' => 'telefoni igendanwa n’akambi',
    '☎' => 'telefone',
    '📞' => 'inyakira ya telefoni',
    '📟' => 'pajeri',
    '📠' => 'imashini ya fagisi',
    '🔋' => 'batiri',
    '🔌' => 'purize',
    '💻' => 'mudasobwa igendanwa',
    '🖥' => 'mudasobwa iterekwa ku meza',
    '🖨' => 'mucapyi',
    '⌨' => 'mwandikisho',
    '🖱' => 'imbeba ya mudasobwa',
    '🖲' => 'Akayoborandanga',
    '💽' => 'disiki ya mudasobwa',
    '💾' => 'disikete',
    '💿' => 'disiki',
    '📀' => 'dvd',
    '🎥' => 'kamera ifata videwo',
    '🎞' => 'amakadiri ya filime',
    '📽' => 'porojegiteri ya filimi',
    '🎬' => 'akabaho bifashisha bakina filimi',
    '📺' => 'televiziyo',
    '📷' => 'kamera',
    '📸' => 'kamera ifite umurabyo',
    '📹' => 'kamera ya videwo',
    '📼' => 'kasete videwo',
    '🔍' => 'rupe ireba ibumoso',
    '🔎' => 'rupe ireba iburyo',
    '🕯' => 'buji',
    '💡' => 'ampule',
    '🔦' => 'itoroshi',
    '🏮' => 'itara ry’umutuku',
    '📔' => 'ikayi ifite igifuniko gitatse',
    '📕' => 'igitabo gifunze',
    '📖' => 'igitabo gifunguye',
    '📗' => 'igitabo cy’icyatsi',
    '📘' => 'igitabo cy’ubururu',
    '📙' => 'igitabo cya oranje',
    '📚' => 'ibitabo',
    '📓' => 'mudasobwa nini',
    '📒' => 'igitabo',
    '📃' => 'paji yihinnye',
    '📜' => 'kunyereza',
    '📄' => 'paji itangiriye hejuru',
    '📰' => 'ikinyamakuru',
    '🗞' => 'ikinyamakuru kizingazinze',
    '📑' => 'utudirishya tw’ubushyinguropaji',
    '🔖' => 'ubushyinguropaji',
    '🏷' => 'akarango',
    '💰' => 'agakapu k’amafaranga',
    '💴' => 'iyeni',
    '💵' => 'idolari',
    '💶' => 'iyero',
    '💷' => 'ipawundi',
    '💸' => 'amafaranga afite amababa',
    '💳' => 'ikarita ya keredi',
    '💹' => 'imbonerahamwe igaragaza iyeni rizamuka',
    '✉' => 'ibahasha',
    '📧' => 'imeyiri',
    '📨' => 'ibahasha ije',
    '📩' => 'ibahasha ifite akambi',
    '📤' => 'ahajya ubutumwa bwoherejwe',
    '📥' => 'ahajya ubutumwa bwakiriwe',
    '📦' => 'ipaki',
    '📫' => 'agasanduku k’ubutumwa gafunze kariho ibendera rizamuye',
    '📪' => 'agasanduku k’ubutumwa gafunze kariho ibendera rimanuye',
    '📬' => 'agasanduku k’ubutumwa gafunguye kariho ibendera rizamuye',
    '📭' => 'agasanduku k’ubutumwa gafunguye kariho ibendera rimanuye',
    '📮' => 'agasanduku k’iposita',
    '🗳' => 'agasanduku k’itora karimo impapuro batoreyeho',
    '✏' => 'ikaramu y’igiti',
    '✒' => 'umutwe w’ikaramu y’umukara',
    '🖋' => 'ikaramu y’umuti',
    '🖊' => 'ikaramu',
    '🖌' => 'uburoso bw’irangi',
    '🖍' => 'kereyo',
    '📝' => 'akandiko',
    '💼' => 'mutwaranyandiko',
    '📁' => 'ububiko bwa dosiye',
    '📂' => 'gufungura ububiko bwa dosiye',
    '🗂' => 'urugabano rw’urutonde rw’amakarita',
    '📅' => 'karendari',
    '📆' => 'gukuraho kalendari',
    '🗒' => 'Ikayi iteranyije akuma kigondoye',
    '🗓' => 'karendari iteranyije akuma kigondoye',
    '📇' => 'ifishi',
    '📈' => 'imbonerahamwe y’ibizamuka',
    '📉' => 'imbonerahamwe y’ibimanuka',
    '📊' => 'imbonerahamwe y’umurongo',
    '📋' => 'ububikogateganyo',
    '📌' => 'pushipini',
    '📍' => 'agafashi kazengurutse',
    '📎' => 'atashe y’impapuro',
    '🖇' => 'udufatampapuro dufatanye',
    '📏' => 'agacamurongo kagororotse',
    '📐' => 'agacampandeshatu',
    '✂' => 'Imakasi',
    '🗃' => 'agasanduku babikamo amadosiye',
    '🗄' => 'dosiye zo mu biro',
    '🗑' => 'agatebo k’imyanda',
    '🔒' => 'irafunze',
    '🔓' => 'birafunguye',
    '🔏' => 'ingufuri n’ikaramu',
    '🔐' => 'ingufuri ifunze n’urufunguzo',
    '🔑' => 'urufunguzo',
    '🗝' => 'urufunguzo rwa kera',
    '🔨' => 'inyundo',
    '⛏' => 'ipiki',
    '⚒' => 'inyundo n’ipiki',
    '🛠' => 'inyundo na kasuku',
    '🗡' => 'daga',
    '⚔' => 'inkota zisobekeranye',
    '💣' => 'ibombe',
    '🏹' => 'umuheto n’umwambi',
    '🛡' => 'ingabo',
    '🔧' => 'gushikuza',
    '🔩' => 'iburo n’agafungisho',
    '⚙' => 'ishusho ringi',
    '🗜' => 'ipensi',
    '⚖' => 'umunzani',
    '🔗' => 'ihuza',
    '⛓' => 'umunyururu',
    '⚗' => 'agacupa bayungururisha',
    '🔬' => 'mikorosikope',
    '🔭' => 'telesikope',
    '📡' => 'anteni y’icyogajuru',
    '💉' => 'urushinge rwo kwa muganga',
    '💊' => 'ikinini',
    '🚪' => 'urugi',
    '🛏' => 'uburiri',
    '🛋' => 'ifoteyi n’itara',
    '🚽' => 'umusarane',
    '🚿' => 'dushe',
    '🛁' => 'urwogero',
    '🛒' => 'akagare babahiramo',
    '🚬' => 'isegereti',
    '⚰' => 'isanduku y’umupfu',
    '⚱' => 'agasanduku kabikwamo ivu ry’umurambo watwitswe',
    '🗿' => 'mowayi',
    '🏧' => 'icyapa cy’imashini ya ATM',
    '🚮' => 'icyapa kigaragaza ahashyirwa imyanda',
    '🚰' => 'amazi meza',
    '♿' => 'ikimenyetso cy’akagare k’abafite ubumuga',
    '🚹' => 'ubwiherero bw’abagabo',
    '🚺' => 'ubwiherero bw’abagore',
    '🚻' => 'ubwiherero',
    '🚼' => 'ikimenyetso cy’umwana',
    '🚾' => 'wese',
    '🛂' => 'ahagenzurirwa pasiporo',
    '🛃' => 'gasutamo',
    '🛄' => 'aho bafatira ibikapu',
    '🛅' => 'ibikapu byabuze ba nyirabyo',
    '⚠' => 'iburira',
    '🚸' => 'aho abana bambukira',
    '⛔' => 'nta nzira ihari',
    '🚫' => 'birabujijwe',
    '🚳' => 'amagare ntiyemewe',
    '🚭' => 'birabujijwe kunywa itabi',
    '🚯' => 'birabujijwe guta imyanda',
    '🚱' => 'amazi atari meza',
    '🚷' => 'nta banyamaguru bemerewe kuhanyura',
    '📵' => 'telefoni zigendanwa ntizemewe',
    '🔞' => 'nta muntu uri munsi y’imyaka cumi n’umunani wemerewe',
    '☢' => 'gyanduza',
    '☣' => 'gifite ingaruka ku buzima',
    '⬆' => 'akambi kazamuka',
    '↗' => 'umwambi w’ahagana ejuru iburyo',
    '➡' => 'akambi k’iburyo',
    '↘' => 'umwambi wo hasi ugana iburyo',
    '⬇' => 'akambi kamanura',
    '↙' => 'umwambi wo hasi ahagana ibumoso',
    '⬅' => 'akambi k’ibumoso',
    '↖' => 'umwambi wo hejuru ugana ibumoso',
    '↕' => 'akambi kazamuka-kamanuka',
    '↔' => 'akambi kava ibumoso kajya iburyo',
    '↩' => 'umwambi w’iburyo uhetamiye ibumoso',
    '↪' => 'umwambi w’ibumoso uhetamiye iburyo',
    '⤴' => 'umwambi w’iburyo uhetamiye hejuru',
    '⤵' => 'umwambi w’iburyo uhetamiye hasi',
    '🔃' => 'utwambi duhagaritse tureba mu cyerekezo cy’inshinge z’isaha',
    '🔄' => 'utwambi duhagaritse tutareba mu cyerekezo cy’inshinge z’isaha',
    '🔙' => 'akambi ka BACK',
    '🔚' => 'akambi ka END',
    '🔛' => 'akambi ka BIRAFUNGUYE!',
    '🔜' => 'akambi ka SOON',
    '🔝' => 'akambi ka TOP',
    '🛐' => 'aho bashengerera',
    '⚛' => 'ikimenyetso cya atome',
    '🕉' => 'om',
    '✡' => 'Inyenyeri ya Dawudi',
    '☸' => 'uruziga rwa daharama',
    '☯' => 'yini yangi',
    '✝' => 'umusaraba w’abalatini',
    '☦' => 'umusaraba w’aba-orthodox',
    '☪' => 'inyenyeri n’ukwezi kw’imboneka',
    '☮' => 'ikimenyetso cy’amahoro',
    '🕎' => 'menora',
    '🔯' => 'inyenyeri ifite amaguru atandatu',
    '♈' => 'Isekurume y’intama',
    '♉' => 'ikimenyesto cya Torisi',
    '♊' => 'Jemini',
    '♋' => 'Kanseri',
    '♌' => 'Lewo',
    '♍' => 'Virigo',
    '♎' => 'Libura',
    '♏' => 'Sikorupiyusi',
    '♐' => 'sajitariyusi',
    '♑' => 'Kapurikorune',
    '♒' => 'akwariyusi',
    '♓' => 'Pisikesi',
    '⛎' => 'Ofiyukusi',
    '🔀' => 'buto yo kuvangavanga imiziki',
    '🔁' => 'buto yo gusubiramo',
    '🔂' => 'buto yo gusubiramo indirimbo imwe',
    '▶' => 'buto yo gukina',
    '⏩' => 'buto yo kwihutisha cyane',
    '⏭' => 'buto y’indirimbo ikurikira',
    '⏯' => 'buto yo gukina cyangwa guhagarika gato',
    '◀' => 'ibuto yo gusubiza inyuma',
    '⏪' => 'buto yo gusubiza inyuma cyane',
    '⏮' => 'ibuto y’indirimbo ya nyuma',
    '🔼' => 'buto yo hejuru',
    '⏫' => 'buto yo kuzamura cyane',
    '🔽' => 'buto yo hasi',
    '⏬' => 'buto yo hasi cyane',
    '⏸' => 'buto yo guhagarika gato',
    '⏹' => 'buto yo guhagarika',
    '⏺' => 'buto yo gufata amajwi',
    '⏏' => 'buto yo gusohora',
    '🎦' => 'sinema',
    '🔅' => 'buto yo kugabanya urumuri',
    '🔆' => 'buto yo kongera urumuri',
    '📶' => 'udukoni tw’antene',
    '📳' => 'uburyo bwo kuvibura',
    '📴' => 'telefoni igendanwa ifunze',
    '♀' => 'ikimenyetso cy’umugore',
    '♂' => 'ikimenyetso cy’umugabo',
    '✖' => 'Ikimenyetso cya x kinini cyo gukuba',
    '➕' => 'ikimenyetso kinini cyo guteranya',
    '➖' => 'ikimenyetso kinini cyo gukuramo',
    '➗' => 'ikimenyetso kinini cyo kugabanya',
    '‼' => 'udutangaro tubiri',
    '⁉' => 'agatangaro n’akabazo',
    '❓' => 'akabazo gacuritse',
    '❔' => 'ikimenyetso cy’akabazo k’umweru',
    '❕' => 'ikimenyetso cy’agatangaro k’umweru',
    '❗' => 'agatangaro gacuritse',
    '〰' => 'akanyerezo - muvumba',
    '💱' => 'kuvunja amafaranga',
    '💲' => 'ikimenyetso kinini cy’idolari',
    '⚕' => 'ikimenyetso cy’ubuvuzi',
    '♻' => 'ikimenyetso cyo kongera gutunganywa',
    '⚜' => 'ururabo rwa lili',
    '🔱' => 'tirida',
    '📛' => 'ibaje ndangazina',
    '🔰' => 'ikimenyetso cy’ikiyapani cy’umutangizi',
    '⭕' => 'uruziga runini rutsitse',
    '✅' => 'ikimenyetso kinini cy’umweru cyo kuvivura',
    '☑' => 'Agasanduku k’amatora bifashisha mu kubara amajwi',
    '✔' => 'Ikimenyetso kinini cya bihwanye',
    '❌' => 'akamenyetso k’umusaraba',
    '❎' => 'buto y’akamenyetso y’umusaraba',
    '➰' => 'uruziga rutsitse',
    '➿' => 'inziga ebyiri zitsitse',
    '〽' => 'akarango k’igice cy’ihinduranya',
    '✳' => 'akanyenyeri kagizwe n’imitwe umunani',
    '✴' => 'inyenyeri igizwe n’imitwe umunani',
    '❇' => 'igishashi',
    '™' => 'ikirango',
    '🔠' => 'inyuguti nkuru z’ikilatini',
    '🔡' => 'inyuguti nko z’ikilatini',
    '🔢' => 'nomero z’ibyanditswe',
    '🔣' => 'ibimenyetso byinjizwa',
    '🔤' => 'inyuguti z’ikilatini',
    '🅰' => 'buto ya A (ubwoko bw’amaraso)',
    '🆎' => 'buto ya AB (ubwoko bw’amaraso)',
    '🅱' => 'buto ya B (ubwoko bw’amaraso)',
    '🆑' => 'buto ya CL',
    '🆒' => 'buto ya COOL',
    '🆓' => 'buto ya FREE',
    'ℹ' => 'amakuru',
    '🆔' => 'buto ya ID',
    'Ⓜ' => 'M iri mu ruziga',
    '🆕' => 'buto ya NEW',
    '🆖' => 'buto ya',
    '🅾' => 'buto ya O (ubwoko bw’amaraso)',
    '🆗' => 'buto ya Yego',
    '🅿' => 'ibuto ya P',
    '🆘' => 'buto ya SOS',
    '🆙' => 'buto ya UP!',
    '🆚' => 'buto ya VS',
    '🈁' => 'buto ya ’hano’ mu kiyapani',
    '🈂' => 'Ibuto y’ "amafaranga ya serivisi" y’Abayapani',
    '🈷' => 'Ibuto y’"amafaranga ya buri kwezi" y’Abayapani',
    '🈶' => 'buto ya ’not free of charge’ mu kiyapani',
    '🈯' => 'buto ya ’reserved’ mu kiyapani',
    '🉐' => 'buto ya ’bargain’ mu kiyapani',
    '🈹' => 'buto ya ’discount’ mu kiyapani',
    '🈚' => 'buto ya ’free Of Charge’ mu kiyapani',
    '🈲' => 'buto ya ’prohibited’ mu kiyapani',
    '🉑' => 'buto ya ’acceptable’ mu kiyapani',
    '🈸' => 'buto ya ’application’ mu kiyapani',
    '🈴' => 'buto ya ’passing grade’ mu kiyapani',
    '🈳' => 'buto ya ’vacancy’ mu kiyapani',
    '㊗' => 'Ibuto ya "ni uko ni uko" y’Abayapani',
    '㊙' => 'Ibuto y’"ibanga" y’Abayapani',
    '🈺' => 'buto ya ’open for business’ mu kiyapani',
    '🈵' => 'buto ya ’no vacancy’ mu kiyapani',
    '🔴' => 'uruziga rutukura',
    '🔵' => 'uruziga rw’ubururu',
    '⚫' => 'uruziga rw’umukara',
    '⚪' => 'uruziga rw’umweru',
    '⬛' => 'kare nini y’umukara',
    '⬜' => 'kare nini y’umweru',
    '◼' => 'kare y’umukara iringaniye',
    '◻' => 'kare y’umweru iringaniye',
    '◾' => 'kare ntoya iringaniye y’umukara',
    '◽' => 'kare ntoya iringaniye y’umweru',
    '▪' => 'kare ntoya y’umukara',
    '▫' => 'kare ntoya y’umweru',
    '🔶' => 'ikaro nini ya oranje',
    '🔷' => 'ikaro nini y’ubururu',
    '🔸' => 'ikaro nto ya oranje',
    '🔹' => 'ikaro nto y’ubururu',
    '🔺' => 'mpandeshatu itukura ireba hejuru',
    '🔻' => 'mpandeshatu itukura ireba hasi',
    '💠' => 'ikaro ifite akadomo',
    '🔘' => 'buto ya radiyo',
    '🔳' => 'buto ya kare y’umweru',
    '🔲' => 'buto ya kare y’umukara',
    '🏁' => 'ibendera rigizwe n’udukaro',
    '🚩' => 'ibendera rya mpandeshatu',
    '🎌' => 'amadarapo anyuranamo',
    '🏴' => 'ibendera ry’umukara',
    '🏳' => 'ibendera ryera',
];
